<?php
/**
 * @package            Joomla
 * @subpackage         Event Booking
 * @author             Tuan Pham Ngoc
 * @copyright          Copyright (C) 2010 - 2023 Ossolution Team
 * @license            GNU/GPL, see LICENSE.php
 */

defined('_JEXEC') or die;

use Joomla\CMS\Application\ApplicationHelper;
use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Uri\Uri;
use Joomla\Utilities\ArrayHelper;
use MBWC\Component\MBWC\Site\Helper\MBWCHelper;
use Joomla\CMS\Log\Log;

class EventbookingControllerOverrideEvent extends EventbookingControllerEvent
{
	/**
	 * Publish the selected events
	 */
	public function publish()
	{
        $app = Factory::getApplication();
        $isSuperUser = MBWCHelper::isSuperUser();
		$id = $this->input->getInt('id', 0);

		if ($id)
		{
			$cid = [$id];
		}
		else
		{
			$cid = $this->input->get('cid', [], 'array');
			$cid = array_filter(ArrayHelper::toInteger($cid));
		}
		$task = $this->getTask();
        $db = Factory::getDbo();

		// Check permission
		foreach ($cid as $id)
		{
			if (!MBWCHelper::canChangeEventStatus($id))
			{
				$msg = Text::_('EB_NO_PUBLISH_PERMISSION');
				$this->setRedirect(Route::_(EventbookingHelperRoute::getViewRoute('events', $this->input->getInt('Itemid', 0)), false), $msg);

				return;
			}
    		$sql = "select 1 from jos_mbwc_tripreports where event_id=".$id;
    		$db->setQuery($sql);
    		$hasTripReport = $db->loadResult();
    		$sql = "select event_date, title from jos_eb_events where id=".$id;
    		$db->setQuery($sql);
    		$event = $db->loadObject();
            $dateParts = explode(' ', $event->event_end_date) ;
		    $endDate = strtotime($dateParts[0]) ;

            if ($task == 'unpublish' && !$isSuperUser && ($hasTripReport || $endDate < strtotime(date('d-m-Y'). ' - 3 days')))
            {
				$msg = "You cannot Unpublish Event ".$event->title." after you have submitted the Trip Report or if the event was over 3 days ago";
                $app->enqueueMessage($msg, 'Warning');
                $app->redirect(Route::_(EventbookingHelperRoute::getViewRoute('events', $this->input->getInt('Itemid', 0)), false));

				return;
            }
		}

		//OK, enough permission checked. Change status of the event
		
		// Check for duplicate leader
		if ($task == 'publish')
		{
    		foreach ($cid as $id)
    		{
    		    
    			$error=MBWCHelper::checkDuplicateLeader($this->input,$id);
    			if ($error)
    			{
    				$msg = $error;
    				$this->setRedirect(Route::_(EventbookingHelperRoute::getViewRoute('events', $this->input->getInt('Itemid', 0)), false), $msg);
    
    				return;
    			}
    			$error=MBWCHelper::checkDuplicateRegistrant($this->input,$id);
    			if ($error)
    			{
    				$msg = $error;
    				$this->setRedirect(Route::_(EventbookingHelperRoute::getViewRoute('events', $this->input->getInt('Itemid', 0)), false), $msg);
    
    				return;
    			}
    		}
		}

		if ($task == 'publish')
		{
			$msg   = Text::_('EB_PUBLISH_SUCCESS');
			$state = 1;
		}
		else
		{
			$msg   = Text::_('EB_UNPUBLISH_SUCCESS');
			$state = 0;
		}

		/* @var EventbookingModelEvent $model */
		$model = $this->getModel('event');

		foreach ($cid as $id)
		{
			$model->publish($id, $state);
            Log::add('Publish Event '.$id, Log::ERROR, 'com_mbwc');
		}

		$return = base64_decode($this->input->getBase64('return'));

		if ($return && Uri::isInternal($return))
		{
			$this->setRedirect($return);
		}
		else
		{
			$this->setRedirect(Route::_(EventbookingHelperRoute::getViewRoute('events', $this->input->getInt('Itemid', 0)), false), $msg);
		}
	}
	/**
	 * Method to delete an event
	 */
	public function delete()
	{
		$this->csrfProtection();

		$cid = $this->input->get('cid', [], 'array');
		$cid = array_filter(ArrayHelper::toInteger($cid));
        $app = Factory::getApplication();
        $isSuperUser = MBWCHelper::isSuperUser();
        $db = Factory::getDbo();

		// Check permission
		foreach ($cid as $id)
		{
			if (!MBWCHelper::canDeleteEvent($id))
			{
				$msg = Text::sprintf('EB_NO_DELETE_EVENT_PERMISSION_PERMISSION', $id);
				$this->setRedirect(Route::_(EventbookingHelperRoute::getViewRoute('events', $this->input->getInt('Itemid', 0)), false), $msg);

				return;
			}
     		$sql = "select 1 from jos_mbwc_tripreports where event_id=".$id;
    		$db->setQuery($sql);
    		$hasTripReport = $db->loadResult();
    		$sql = "select event_date, title, published from jos_eb_events where id=".$id;
    		$db->setQuery($sql);
    		$event = $db->loadObject();
            $dateParts = explode(' ', $event->event_end_date) ;
		    $endDate = strtotime($dateParts[0]) ;

            if (!$isSuperUser && $event->published ==2)
            {
				$msg = "You cannot Delete Event ".$event->title." as it is cancelled.";
                $app->enqueueMessage($msg, 'Warning');
                $app->redirect(Route::_(EventbookingHelperRoute::getViewRoute('events', $this->input->getInt('Itemid', 0)), false));

				return;
                
            }
            else if (!$isSuperUser && ($hasTripReport || $endDate < strtotime(date('d-m-Y'). ' - 3 days')))
            {
				$msg = "You cannot Delete Event ".$event->title." after you have submitted the Trip Report or if the event was over 3 days ago";
                $app->enqueueMessage($msg, 'Warning');
                $app->redirect(Route::_(EventbookingHelperRoute::getViewRoute('events', $this->input->getInt('Itemid', 0)), false));

				return;
            }
 		}

		// Permission is OK, perform deleting the selected events

		/* @var EventbookingModelEvent $model */
		$model = $this->getModel('event');
		$model->delete($cid);
        Log::add('Delete Events '.json_encode($cid), Log::ERROR, 'com_mbwc');

		$msg = Text::_('EB_DELETE_EVENTS_SUCCESS');

		$return = base64_decode($this->input->getBase64('return'));

		if ($return && Uri::isInternal($return))
		{
			$this->setRedirect($return);
		}
		else
		{
			$this->setRedirect(Route::_(EventbookingHelperRoute::getViewRoute('events', $this->input->getInt('Itemid', 0)), false), $msg);
		}
	}
	
}
