<?php
namespace MBWC\Component\MBWC\Site\Controller;

use Joomla\CMS\MVC\Controller\BaseController;
use Joomla\CMS\Factory;
use MBWC\Component\MBWC\Site\Helper\MBWCHelper;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Log\Log;
use Joomla\CMS\Filesystem\File;
use Joomla\CMS\Filesystem\Folder;

require_once JPATH_ADMINISTRATOR . '/components/com_eventbooking/libraries/rad/bootstrap.php';
require_once JPATH_SITE . '/components/com_jtg/helpers/gpsClass.php';
require_once JPATH_SITE . '/components/com_jtg/helpers/helper.php';

class TripreportController extends BaseController
{
	public static function saveFileFromTripReport ($title, $desc, $file, $cat)
	{
		$app = Factory::getApplication();

		$db = Factory::getDBO();
		$user = Factory::getUser();
		$cache = Factory::getCache('com_jtg');

		// Get the post data
		$catid = $cat;
		$level = 0;
		
		$terrain = null;
		$uid = $user->get('id');
		$date = date("Y-m-d");
		$access = 0;
		$hidden = 0;
		$published = 1;

		// Upload the file
		$upload_dir = JPATH_SITE . '/images/jtrackgallery/uploaded_tracks/';
		$filename = strtolower(File::makeSafe($file['name']));
		$newfile = $upload_dir . strtolower($filename);

		if (strlen($filename) > 45)
		{
            $app->enqueueMessage('Filename too long. Please shorten and try again.', 'warning');
            return false;
		}

		if (File::exists($newfile))
		{
            $app->enqueueMessage('GPX File already exists. Please upload manually', 'warning');
            return false;
		}

		if (! File::upload($file['tmp_name'], $newfile))
		{
            $app->enqueueMessage('File upload failed', 'error');
            return false;
		}
		else
		{
			chmod($newfile, 0777);
		}

		// Get the start coordinates..

		// Default unit
		$gpsData = new \GpsDataClass("Kilometer");
		$gpsData = $cache->get(
				array($gpsData,
						'loadFileAndData'
				), array(
						$newfile,
						strtolower($filename)
				), "Kilometer");
		$errors = $gpsData->displayErrors();

		if ($errors)
		{
			$map = "";
			$coords = "";
			$distance_float = 0;
			$distance = 0;

			// Try to delete the file
			if (File::exists($upload_dir . strtolower($filename)))
			{
				File::delete($upload_dir . strtolower($filename));
			}

            $app->enqueueMessage('JTG No Support '.json_encode($errors), 'error');
            return false;
		}

		$start_n = $gpsData->start[1];
		$start_e = $gpsData->start[0];
		$coords = $gpsData->allCoords;
		$isTrack = $gpsData->isTrack;
		$isWaypoint = $gpsData->isWaypoint;
		$isRoute = 0;
		$isCache = 0;
		$distance = $gpsData->distance;

		$query = "INSERT INTO #__jtg_files SET"
		. "\n uid='" . $uid . "',"
		. "\n submitter_id='" . $uid . "',"
		. "\n catid='" . $catid . "',"
		. "\n title='" . $title . "',"
		. "\n file='" .	strtolower($filename) . "',"
		. "\n terrain='" . $terrain . "',"
		. "\n description='" . str_replace("'", '', $desc) . "',"
		. "\n published='" . $published . "',"
		. "\n date='" . $date . "',"
		. "\n start_n='" . $start_n . "',"
		. "\n start_e='" . $start_e . "',"
		. "\n distance='" . $distance . "',"
		. "\n ele_asc='" . round($gpsData->totalAscent, 0) . "',"
		. "\n ele_desc='" . round($gpsData->totalDescent, 0) . "',"
		. "\n level='" . $level . "',"
		. "\n access='" . $access . "',"
		. "\n hidden='" . $hidden . "',"
		. "\n istrack='" . $isTrack . "',"
		. "\n iswp='" . $isWaypoint . "',"
		. "\n isroute='" . $isRoute . "',"
		. "\n iscache='" . $isCache . "'";
        try
        {
        		$db->setQuery($query);
        		$db->execute();
        }
        catch (RuntimeException $e)
        {
            echo $e->getMessage();
            return false;
        }

		$query = "SELECT id FROM #__jtg_files WHERE file='" . strtolower($filename) . "'";

		$db->setQuery($query);
		$rows = $db->loadObject();

		// Images upload part
		$cfg = \JtgHelper::getConfig();
		$types = explode(',', $cfg->type);

		if (count($images) > 0)
		{
			foreach ($images as $image)
			{
				if ($image['name'] != "")
				{
    				$ext = File::getExt($image['name']);
    				$imgfilename = File::makesafe($image['name']);
    				$name = File::stripExt($imgfilename);
    				if (strlen($name)>45)
    				{
    				    $name=substr($name,0,45);
    				}
    				$imgfilename=$name.".".$ext;

					if (in_array(strtolower($ext), $types))
					{
						\JtgHelper::createimageandthumbs($rows->id,$image['tmp_name'], $ext, $imgfilename);
					}
				}
			}
		}

		return true;
	}


	public function send_trip_report()
    {
		$app = Factory::getApplication() ;
		$db = Factory::getDbo();
		$user = Factory::getUser() ;
		$grade = $app->input->getVar('grade','','string');
		$event_name = $app->input->getVar('event_name','','string');
		$leader = $app->input->getVar('leader','','string');
		$leader_id = $app->input->getVar('leader_id','','string');
		$distance = $app->input->getVar('distance','','string');
		$num_members = $app->input->getVar('num_members','','string');
		if (!$num_members) $num_members=0;
		$num_cancellations = $app->input->getVar('num_cancellations','','string');
		if (!$num_cancellations) $num_cancellations=0;
		$comment = $app->input->getVar('comment','','string');
		$event_date = $app->input->getVar('event_date','','string');
		$event_date_minute = $app->input->getVar('event_date_minute','','string');
		$event_date_hour = $app->input->getVar('event_date_hour','','string');
		$event_end_date = $app->input->getVar('event_end_date','','string');
		$event_end_date_minute = $app->input->getVar('event_end_date_minute','','string');
		$event_end_date_hour = $app->input->getVar('event_end_date_hour','','string');
		$accident = $app->input->getVar('accident','','string');
		$behaviour = $app->input->getVar('behaviour','','string');
		$first_name = $app->input->getVar('first_name','','array');
		$last_name = $app->input->getVar('last_name','','array');
		$phone = $app->input->getVar('phone','','array');
		$description = $app->input->getVar('description','','raw');
		$file = $app->input->files->get('file');
		$event_id = $app->input->getInt('event_id');
		$id = $app->input->getInt('id');
		$db = Factory::getDbo();
		$sql = "SELECT id FROM #__jtg_cats WHERE title='".$grade."'" ;
		$db->setQuery($sql) ;
		$categoryId = (int) $db->loadResult();
		$config = \EventbookingHelper::getConfig() ;
		$num_visitors = 0;
		$return =  $app->input->getVar('return') ;
		// remove duplicates
		if (count($first_name) > 1)
		{
            for ($i=1;$i<count($first_name);$i++)
            {
                for ($j=0;$j<$i;$j++)
                {
                    if ($first_name[$i] && $first_name[$i]===$first_name[$j] && $last_name[$i]===$last_name[$j])
                    {
                        unset($first_name[$i]);
                        unset($last_name[$i]);
                        unset($phone[$i]);
                    }
                }
            }
		}
        for ($i=0;$i<count($first_name);$i++)
        {
            if ($first_name[$i])
            {
                $num_visitors=$num_visitors+1;
            }
        }
        $total_number=$num_members+$num_visitors;

		$sql = "SELECT a.*,concat_ws(',',
		(select name from jos_users as c where c.id=JSON_UNQUOTE(JSON_EXTRACT(a.custom_fields,'$.field_leader_id1'))),
		(select name from jos_users as c where c.id=JSON_UNQUOTE(JSON_EXTRACT(a.custom_fields,'$.field_leader_id2'))),
		(select name from jos_users as c where c.id=JSON_UNQUOTE(JSON_EXTRACT(a.custom_fields,'$.field_leader_id3')))) as leader_name FROM #__eb_events as a WHERE a.id='".$event_id."'" ;
		$db->setQuery($sql) ;
		$event = $db->loadObject();
		$leader_name = $event->leader_name;
		if ($event_name && $event_name != "something")
		{
		    $multi=1;
		    $title=$event->title.' - '.$event_name;
		    $my_event_date = $event_date.' '.$event_date_hour.':'.str_pad($event_date_minute,2,'0').':00';
		    if ($event_end_date && $event_end_date != "something")
		    {
		        $my_event_end_date = $event_end_date;
		        if ($event_end_date_hour || $event_end_date_minute )
		        {
		            $my_event_end_date = $my_event_end_date.' '.$event_end_date_hour.':'.str_pad($event_end_date_minute,2,'0').':00';
		        }
		    }
		    else
		    {
		        $my_event_end_date=$my_event_date;
		        if ($event_end_date_hour || $event_end_date_minute )
		        {
		            $my_event_end_date = $event_date.' '.$event_end_date_hour.':'.str_pad($event_end_date_minute,2,'0').':00';
		        }
		    }
		    $sql = "select name,email from #__users as c where c.id=".$leader_id ;
		    $db->setQuery($sql) ;
	    	$leaderObj = $db->loadObject();
	    	$leader=$leaderObj->name;
		}
		else
		{
		    $multi=0;
		    $title=$event->title;
		    $my_event_date = $event->event_date;
		    $my_event_end_date = $event->event_end_date;
		}
		
        Log::add($user->get('name').' Trip Report: '.$title, Log::INFO, 'com_mbwc');		

		if ($file['name'] && $categoryId)
		{
            if (self::saveFileFromTripReport($title, $description, $file,$categoryId))
            {
                $app->enqueueMessage('GPX File uploaded successfully', 'info');
            }
		}
        
		$replyName = $user->get('name');
		$replyEmail = $user->get('email');
		
		$content = 
		"<h1 style='text-align: center'>Maroondah Bushwalking Club Inc</h1>" .
		"<div style='text-align: center'>www.mbwc.org.au</div>" .
"<h2>FORM L2 TRIP REPORT</h2>" .
"<b>The Trip Report</b> provides data required for statistics.<br>" .
"If you were handed a Temporary Member Form M3 you can either email membsec@mbwc.org.au, post  PO Box 575, Ringwood, 3134 or
hand it to the Club Secretary at the Club meetings.<br><br>";
        $content = $content .
        "<table style='border: 1px solid #000000;border-collapse: collapse;'>" .
        "<tr><tdstyle='border: 1px solid #000000;border-collapse: collapse;' ><b>Activity:</b>&nbsp;" . $title . "</td><td  colspan='2' style='border: 1px solid #000000;border-collapse: collapse;'><b>Grade:</b>&nbsp;".$grade."</td></tr>" .
        "<tr><td style='border: 1px solid #000000;border-collapse: collapse;'><b>Day:</b>&nbsp;" . date("l", strtotime($my_event_date)) . "</td><td style='border: 1px solid #000000;border-collapse: collapse;'><b>Start Date:</b>&nbsp;" . $my_event_date . "</td><td style='border: 1px solid #000000;border-collapse: collapse;'><b>End Date:</b>&nbsp;" . $my_event_end_date . "</td></tr>" .
        "<tr><td style='border: 1px solid #000000;border-collapse: collapse;'><b>Leader:</b>&nbsp;" . $leader . "</td><td style='border: 1px solid #000000;border-collapse: collapse;'><b>Distance:</b>&nbsp;" . $distance . "</td><td><b>No of Participants:</b>&nbsp;" . $total_number . "</td></tr>" .
        "<tr><td style='border: 1px solid #000000;border-collapse: collapse;'><b>Members:</b>&nbsp;" . $num_members . "</td><td style='border: 1px solid #000000;border-collapse: collapse;'><b>Visitors:</b>&nbsp;".$num_visitors."</td><td style='border: 1px solid #000000;border-collapse: collapse;'><b>Cancellations:</b>&nbsp;" . $num_cancellations . "</td></tr>" .
        "<tr><td colspan='3' style='border: 1px solid #000000;border-collapse: collapse;' ><b>Comment:</b>&nbsp;" . $comment . "</td></tr>" .
        "<tr><td style='border: 1px solid #000000;border-collapse: collapse;'><b>Any accident or incident on the activity?</b></td><td style='border: 1px solid #000000;border-collapse: collapse;'><b>Yes</b>&nbsp;<input type='checkbox'";
        if ($accident === "Yes") $content = $content . " checked";
        $content = $content .
        " disabled></td><td style='border: 1px solid #000000;border-collapse: collapse;'><b>No</b>&nbsp;<input type='checkbox'";
        if ($accident === "No") $content = $content . " checked";
        $content = $content .
        " disabled></td></tr>" .        
        "<tr><td style='border: 1px solid #000000;border-collapse: collapse;'><b>Did any behaviour bother you?</b><br>e.g. Did anyone fail to follow your directions/requests?</td><td colspan = '2' style='border: 1px solid #000000;border-collapse: collapse;'><b>Describe:</b>&nbsp;".$behaviour."</td></tr>" .        
        "</table>";

        if (count($first_name) > 0)
        {
            $content = $content . "<br><br><table style='border: 1px solid #000000;border-collapse: collapse;'>" .
            "<th style='border: 1px solid #000000;border-collapse: collapse;'>Visitors Name</th><th style='border: 1px solid #000000;border-collapse: collapse;'>Phone No</th>";
        }

        for ($i=0;$i<count($first_name);$i++)
        {
            if ($first_name[$i])
            {
                $content = $content . "<tr><td style='border: 1px solid #000000;border-collapse: collapse;'><b>" . ($i+1) . "</b>&nbsp;" . $first_name[$i]." ".$last_name[$i] . "</td><td style='border: 1px solid #000000;border-collapse: collapse;'>" . $phone[$i] . "</td></tr>";
                
                $name=$first_name[$i]." ".$last_name[$i];
        		$sql = "SELECT * FROM #__eb_registrants WHERE event_id='".$event_id."' and first_name='".$first_name[$i]."' and last_name='".$last_name[$i]."' and published in (1,3,4,5)" ;
        		$db->setQuery($sql) ;
        		$registrant = $db->loadObject();
        		if (!$registrant)
        		{
                    Log::add($user->get('name').' New Visitor '.$name .' detected in trip report for event '.$event->title.'. Adding them to the event.', Log::INFO, 'visitors');		      
                    
                    //if visitors haven't registered, add them
            		$sql = "INSERT INTO #__eb_registrants (number_registrants, published, event_id, user_id, first_name, last_name, email, phone, register_date) values(1,1, ".$event_id.",0, '" . $first_name[$i] ."', '" . str_replace("'", "\'", $last_name[$i]) ."', '','" . $phone[$i] . "', '" . $my_event_date . "' )";
            
            		$db->setQuery($sql) ;
            		$db->execute();			
            		
            		$newid = $db->insertid();
            		
            		if (strlen($phone[$i]) > 0)
            		{
                    	$sql =  "INSERT INTO #__eb_field_values (registrant_id, field_id, field_value) values (" . $newid  . ", 1,'"  . $phone[$i]. "')";
                    	$db->setQuery($sql) ;
                    	$db->execute();	
            		}			
                    $info_content = "<p>Hi Information Officer,</p><p>The following <b>unregistered</b> Visitor was <b>added</b> to the event in the trip report <b>".$title."</b> on <b>".date('l jS F Y', strtotime($my_event_date))."</b><p><b>Name:</b>&nbsp;".$name."</p><p><b>Phone Number:</b>&nbsp;".$phone[$i]."</p>";
               
                    MBWCHelper::mail_info($first_name[$i], $last_name[$i], null, $title, $info_content);
   
        		}
				else
				{
					if ($registrant->published>2)
					{
						Log::add($user->get('name').' Pending Visitor '.$name .' detected in trip report for event '.$title.'. Marking them as registered.', Log::INFO, 'visitors');		      
						//if visitors are still pending, mark them as registered
						$sql = "UPDATE #__eb_registrants set published=1 where id=".$registrant->id;
						$db->setQuery($sql) ;
						$db->execute();
                        $info_content = "<p>Hi Information Officer,</p><p>The following <b>unapproved</b> Visitor was <b>added</b> to the event in the trip report <b>".$title."</b> on <b>".date('l jS F Y',  strtotime($my_event_date))."</b><p><b>Name:</b>&nbsp;".$name."</p><p><b>Phone Number:</b>&nbsp;".$phone[$i]."</p><p><b>Email:</b>&nbsp;".$registrant->email."</p>";
                   
                        MBWCHelper::mail_info($first_name[$i], $last_name[$i], $registrant->email, $title, $info_content);
					
					}
				}
            }
        }

        // don't cancel visitors for multi day events
        if (!$multi)
        {
            //if visitors are registered or pending but are not in the trip report, email info and mark visitor as cancelled
            $sql = "SELECT a.id, a.first_name, a.last_name, a.email, b.field_value as phone, a.published FROM #__eb_registrants as a left join #__eb_field_values as b on b.registrant_id=a.id WHERE a.event_id=" . $event_id .' AND a.is_group_billing=0 AND (published=1 or published=4) and (a.user_id = 0 or a.user_id is null) and b.field_id=21 ';
    	    $db->setQuery($sql) ;
    		$visitors = $db->loadObjectList();
    	    for ($i=0; $i<count($visitors);$i++)
    	    {
    	        $found=false;
                for ($j=0;$j<count($first_name);$j++)
                {
                    if ($first_name[$j])
                    {
                        if ($first_name[$j] === $visitors[$i]->first_name && $last_name[$j] === $visitors[$i]->last_name)
                        {
                            $found=true;
                            break;
                        }
                    }
                }
                if (!$found)
                {
                    $name=$visitors[$i]->first_name.' '.$visitors[$i]->last_name;
    
                    //mark them as cancelled
                    $sql = "UPDATE #__eb_registrants set published=2 where id=".$visitors[$i]->id;
                    $db->setQuery($sql) ;
                    $db->execute();
                    
                    if ($visitors[$i]->published == 1)
                    {
                        Log::add($user->get('name').' Registered Visitor '.$name.' not found in trip report for event '.$title.'. Cancelling their registration.', Log::INFO, 'visitors');		           
                        
                        $info_content = "<p>Hi Information Officer,</p><p>The following Visitor had registered for the event <b>".$event->title."</b> on <b>".date('l jS F Y', strtotime($my_event_date))."</b> but was <b>not</b> included in the trip report.</p><p>Please follow up.</p><p><b>Name:</b>&nbsp;".$name."</p><p><b>Phone Number:</b>&nbsp;".$visitors[$i]->phone."</p><p><b>Email:</b>&nbsp;".$visitors[$i]->email."</p>";
                       
                        MBWCHelper::mail_info($visitors[$i]->first_name, $visitors[$i]->last_name, $visitors[$i]->email, $title, $info_content);
                    }
                    else
                    {
                       Log::add($user->get('name').' Pending Visitor '.$name.' not found in trip report for event '.$title.'. Cancelling their registration.', Log::INFO, 'visitors');
                       
                        $info_content = "<p>Hi Information Officer,</p><p>The following Visitor was pending for the event <b>".$title."</b> on <b>".date('l jS F Y', strtotime($my_event_date))."</b> but was <b>not</b> included in the trip report.</p><p>Please follow up.</p><p><b>Name:</b>&nbsp;".$name."</p><p><b>Phone Number:</b>&nbsp;".$visitors[$i]->phone."</p><p><b>Email:</b>&nbsp;".$visitors[$i]->email."</p>";
                       
                        MBWCHelper::mail_info($visitors[$i]->first_name, $visitors[$i]->last_name, $visitors[$i]->email, $title, $info_content);
                    }
                }
    	    }
        }
        if (count($first_name) > 0)
        {

            $content = $content . "</table>";
        }
		$accident_num=0; 
		if ($accident==="Yes")
		{
		    $accident_num=1;
		}
		if ($multi) 
		{
		    $custom_fields='field_distance="'.$distance.'"\nfield_leader_id1="'.str_replace("'", "\'", $leader_id).'"';
		    $sql = "INSERT INTO jos_eb_events (title, parent_id, access, registration_access, max_group_number, enable_cancel_registration, custom_fields,event_date, event_end_date, description, event_capacity, created_by, cut_off_date, registration_type, cancel_before_date,notification_emails, published, created_date) VALUES 
		    ('".str_replace("'", "\'", $title)."',".$event_id.",2,2,3,1,'".$custom_fields."','".$my_event_date."','".$my_event_end_date."','".str_replace("'", "\'", $comment)."',".$total_number.",".$leader_id.",'".$my_event_date."',0,'".$my_event_date."','".$leaderObj->email."',1,'".$my_event_date."')";

            $db->setQuery($sql) ;
            $db->execute();
            $sql="SELECT LAST_INSERT_ID();";
            $db->setQuery($sql) ;
            $new_event_id=$db->loadResult();
            
    		$sql = "SELECT id FROM #__eb_categories where name='".$grade."'";
    		$db->setQuery($sql);
    		$cat_id = $db->loadResult();
            
            $sql = "INSERT INTO #__eb_event_categories(event_id, category_id) VALUES($new_event_id, $cat_id)";
			$db->setQuery($sql);
			$db->execute();

		}
		else
		{
		    $new_event_id=$event_id;
		}
		if (!$id)
		{
            $sql = "INSERT INTO jos_mbwc_tripreports (event_id, trip_report_date, actual_distance, num_participants, num_visitors, num_members, num_cancellations, comment, behaviour, incident,leader, event_date, event_end_date, grade, event_name) 
            VALUES (".$new_event_id.",'".date('Y-m-d H:i:s')."',".$distance.",".$total_number.",".$num_visitors.",".$num_members.",".$num_cancellations.",'".str_replace("'", "\'", $comment)."','".str_replace("'", "\'", $behaviour)."',".$accident_num.",'".str_replace("'", "\'", $leader)."','".$my_event_date."','".$my_event_end_date."','".$grade."','".str_replace("'", "\'", $title)."')";
            $db->setQuery($sql) ;
            $db->execute();
		}
		else
		{
            $sql = "REPLACE INTO jos_mbwc_tripreports (id,event_id, trip_report_date, actual_distance, num_participants, num_visitors, num_members, num_cancellations, comment, behaviour, incident,leader, event_date, event_end_date, grade, event_name) 
            VALUES (".$id.",".$new_event_id.",'".date('Y-m-d H:i:s')."',".$distance.",".$total_number.",".$num_visitors.",".$num_members.",".$num_cancellations.",'".str_replace("'", "\'", $comment)."','".str_replace("'", "\'", $behaviour)."',".$accident_num.",'".str_replace("'", "\'", $leader)."','".$my_event_date."','".$my_event_end_date."','".$grade."','".str_replace("'", "\'", $title)."')";
            $db->setQuery($sql) ;
            $db->execute();
		    
		}

        $sql = "SELECT a.* FROM #__eb_registrants as a WHERE a.event_id=" . $event_id .' AND a.is_group_billing=0 AND (published=1) and (a.user_id = 0 or a.user_id is null)';
	    $db->setQuery($sql) ;
		$visitors = $db->loadObjectList();
	    for ($i=0; $i<count($visitors);$i++)
	    {
        	MBWCHelper::checkAndSendMembershipMail($visitors[$i], $config);
	    }
         
        //email info with visitors that have done the walk, running totals of walks done and pending walks


        if (strpos(strtolower($event->title),"test")===false)
        {
            $recipients = array( 'tripreports@mbwc.org.au' );
            $recipients[]=$user->email;
        }
        else
        {
            $recipients[]=$user->email;
        }

		if (MBWCHelper::sendMail($recipients, "Trip Report for ".$title, $content, 1, $replyEmail, null, null, $replyEmail, $replyName))
		{
 	        $msg = "Trip Report Sent";
		}
		else
		{
		    $msg = "Error sending Trip Report";
		}
		if ($accident==="Yes")
		{
			$this->setRedirect(Route::_('index.php?option=com_mbwc&view=incidentreport&event_id='.$app->input->getInt('event_id'),false) , $msg);
		}
		else
		{
      		if ($return && $return === "event")
    		{
    			$this->setRedirect( Route::_(
    				'index.php?option=com_eventbooking&view=event&id=' . $event->id . '&Itemid=' . $app->input->getInt('Itemid'),
    				false),$msg);
    		}
    		else
    		{
                $this->setRedirect(Route::_(\EventbookingHelperRoute::getViewRoute('events', $app->input->getInt('Itemid')), false), $msg);	
    		}
		}
 
    }

}
?>