<?php
namespace MBWC\Component\MBWC\Site\Helper;

use Joomla\CMS\Factory;
use \Joomla\CMS\MVC\Model\BaseDatabaseModel;
require_once JPATH_ADMINISTRATOR . '/components/com_eventbooking/libraries/rad/bootstrap.php';
use DateTime;
use Joomla\CMS\Log\Log;
use Joomla\Registry\Registry;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Environment\Browser;
use Joomla\CMS\Mail\MailHelper;
use Joomla\CMS\Application\ApplicationHelper;
use Joomla\CMS\Component\ComponentHelper;
use Joomla\CMS\Language\Multilanguage;
use Joomla\CMS\Menu\MenuItem;
use Joomla\Utilities\ArrayHelper;

class MBWCHelper
{
	public static function canChangeEventStatus($eventId)
	{
		$user = Factory::getUser();

		if ($user->guest)
		{
			return false;
		}

		if ($user->authorise('core.admin', 'com_eventbooking'))
		{
			return true;
		}

		if ($user->authorise('core.edit.state', 'com_eventbooking'))
		{
			if (empty($eventId))
			{
				return true;
			}

    		$event = \EventbookingHelperDatabase::getEvent($eventId);
            $fieldextras = new Registry($event->custom_fields);

		    if ($event->created_by > 0 && ($event->created_by == $user->id || $fieldextras['field_leader_id1'] == $user->id || $fieldextras['field_leader_id2'] == $user->id || $fieldextras['field_leader_id3'] == $user->id))
			{
				return true;
			}
		}

		return false;
	}

    public static function canDeleteEvent($id = 0)
	{
		$config = \EventbookingHelper::getConfig();

		// If frontend event deletion is not enabled, return false
		if (!$config->get('enable_delete_events'))
		{
			return false;
		}

		$user = Factory::getUser();

		// User with core.admin permission will be allowed to delete any events
		if (!$id || $user->authorise('core.admin', 'com_eventbooking'))
		{
			return true;
		}

		// Event's owner is allowed to delete own event

		$event = \EventbookingHelperDatabase::getEvent($id);
        $fieldextras = new Registry($event->custom_fields);
			
		if ($event->created_by > 0 && ($event->created_by == $user->id || $fieldextras['field_leader_id1'] == $user->id || $fieldextras['field_leader_id2'] == $user->id || $fieldextras['field_leader_id3'] == $user->id))
		{
			return true;
		}

		return false;
	}

    public static function hasCategoryPermissions($input)
    {
 		$user = Factory::getUser();
		$db = Factory::getDbo();
    	$category_id = $input->get('main_category_id');
		$categoryIds = $input->get('category_id') ?? [];
		$categoryIds = array_filter(ArrayHelper::toInteger($categoryIds, 0));

        if ($input->get('id'))
        {
            //make sure the we are not changing category from non-basecamp to base-camp.
    		$sql = 'SELECT main_category_id FROM #__eb_events WHERE id=' . $input->get('id');
    		$db->setQuery($sql);
    		$main_cat = $db->loadResult();
    		if ($main_cat != $category_id)
    		{
        		$sql = 'SELECT submit_event_access, name FROM #__eb_categories WHERE id=' . $category_id;
        		$db->setQuery($sql);
        		$access = $db->loadObject();
                if ($access && !in_array($access->submit_event_access, $user->getAuthorisedViewLevels()))
                {
                    return "You are not authorised to submit/edit events with category: ".$access->name;
                }
    		}
    		$sql = 'SELECT category_id FROM #__eb_event_categories WHERE main_category!=1 and event_id=' . $input->get('id');
    		$db->setQuery($sql);
    		$additionalCats = $db->loadColumn();
   		    $newcats = array_diff($categoryIds,$additionalCats);
     		foreach ($newcats as $categoryId)
     		{
         		$sql = 'SELECT submit_event_access, name FROM #__eb_categories WHERE id=' . $categoryId;
        		$db->setQuery($sql);
        		$access = $db->loadObject();
                if ($access && !in_array($access->submit_event_access, $user->getAuthorisedViewLevels()))
                {
                    return "You are not authorised to submit/edit events with category: ".$access->name;
                }
    		}
        }
        else
        {
    		$sql = 'SELECT submit_event_access, name FROM #__eb_categories WHERE id=' . $category_id;
    		$db->setQuery($sql);
    		$access = $db->loadObject();
            if ($access && !in_array($access->submit_event_access, $user->getAuthorisedViewLevels()))
            {
                return "You are not authorised to submit/edit events with category: ".$access->name;
            }
    		
     		foreach ($categoryIds as $categoryId)
     		{
         		$sql = 'SELECT submit_event_access, name FROM #__eb_categories WHERE id=' . $categoryId;
        		$db->setQuery($sql);
        		$access = $db->loadObject();
                if ($access && !in_array($access->submit_event_access, $user->getAuthorisedViewLevels()))
                {
                    return "You are not authorised to submit/edit events with category: ".$access->name;
                }
    		}
        }
        return;
    }
	public static function canCancelGroupRegistration($eventId)
	{
		$db = Factory::getDbo();
		$user = Factory::getUser();
		$userId = $user->get('id');
		$email = $user->get('email');
		if (!$userId)
			return false;
		$sql = 'SELECT id FROM #__eb_registrants WHERE event_id=' . $eventId . ' AND user_id=' . $userId .
			 ' AND is_group_billing=1 AND published=1';
		$db->setQuery($sql);
		$registrantId = $db->loadResult();
		if (!$registrantId)
			return false;

		$sql = 'SELECT COUNT(*) FROM #__eb_events WHERE id=' . $eventId .
			 ' AND enable_cancel_registration = 1 AND (DATEDIFF(ifnull(cancel_before_date,NOW()), NOW()) >=0) ';
		$db->setQuery($sql);
		$total = $db->loadResult();
		
		if (!$total)
			return false;
			
		$sql = 'SELECT custom_fields FROM #__eb_events WHERE id=' . $eventId;
		$db->setQuery($sql);
		$custom_fields = $db->loadResult();
        $fieldextras = new Registry($custom_fields);
			
		// You can't cancel registration if you are the last leader
		if (($fieldextras->get('field_leader_id1')==$userId && !$fieldextras->get('field_leader_id2') && !$fieldextras->get('field_leader_id3')) ||
		    ($fieldextras->get('field_leader_id2')==$userId && !$fieldextras->get('field_leader_id1') && !$fieldextras->get('field_leader_id3')) ||
		    ($fieldextras->get('field_leader_id3')==$userId && !$fieldextras->get('field_leader_id2') && !$fieldextras->get('field_leader_id1')))
		    return false;

		
		return $registrantId;
	}
	public static function canUnCancelRegistration($regId)
	{
		$db = Factory::getDbo();
		$user = Factory::getUser();
		$userId = $user->get('id');
		$email = $user->get('email');
		if (!$userId)
			return false;
		$sql = 'SELECT * FROM #__eb_registrants WHERE id=' . $regId;
		$db->setQuery($sql);
 		$registrant = $db->loadObject();
		if (!$registrant)
			return false;

        if ($registrant->user_id)
        {
 		    $sql = 'SELECT count(*) FROM #__eb_registrants WHERE event_id=' . $registrant->event_id . ' and published=1 and user_id='.$registrant->user_id;
 		    $db->setQuery($sql);
 		    $hasPublished = $db->loadResult();
 		    if ($hasPublished)
 		        return false;
        }
        else
        {
 		    $sql = 'SELECT count(*) FROM #__eb_registrants WHERE event_id=' . $registrant->event_id . ' and published=1 and first_name="'.$registrant->first_name.'" and last_name="'.$registrant->last_name.'"';
		    $db->setQuery($sql);
 		    $hasPublished = $db->loadResult();
 		    if ($hasPublished)
 		        return false;
        }
        return true;
	}

	/**
	 * Check to see whether the users can cancel registration
	 * 
	 * @param int $eventId
	 */
	public static function canCancelRegistration($eventId)
	{
		$db = Factory::getDbo();
		$user = Factory::getUser();
		$userId = $user->get('id');
		$email = $user->get('email');
		if (!$userId)
			return false;
		$sql = 'SELECT id FROM #__eb_registrants WHERE event_id=' . $eventId . ' AND user_id=' . $userId .
			 ' AND is_group_billing=0 AND published in (1,3)';
		$db->setQuery($sql);
		$registrantId = $db->loadResult();
		if (!$registrantId)
			return false;

		$sql = 'SELECT COUNT(*) FROM #__eb_events WHERE id=' . $eventId .
			 ' AND enable_cancel_registration = 1 AND (DATEDIFF(ifnull(cancel_before_date,NOW()), NOW()) >=0) ';
		$db->setQuery($sql);
		$total = $db->loadResult();

		if (!$total)
			return false;
			
		$sql = 'SELECT custom_fields FROM #__eb_events WHERE id=' . $eventId;
		$db->setQuery($sql);
		$custom_fields = $db->loadResult();
        $fieldextras = new Registry($custom_fields);

		// You can't cancel registration if you are the last leader
		if (($fieldextras->get('field_leader_id1')==$userId && !$fieldextras->get('field_leader_id2') && !$fieldextras->get('field_leader_id3')) ||
		    ($fieldextras->get('field_leader_id2')==$userId && !$fieldextras->get('field_leader_id1') && !$fieldextras->get('field_leader_id3')) ||
		    ($fieldextras->get('field_leader_id3')==$userId && !$fieldextras->get('field_leader_id2') && !$fieldextras->get('field_leader_id1')))
		    return false;

		return $registrantId;
	}
	
	public static function checkDuplicateRegistrant($input, $use_id)
	{
        $user   = Factory::getUser();
		if ($use_id)
 		{
 		    $id=$use_id;
 		    $sql="select * from jos_eb_events where id=".$id;
 		    $db->setQuery($sql);
 		    $event=$db->loadObject();
 		    $fieldextras=new Registry($event->custom_fields);
            $event_date=$event->event_date;
            $event_date_hour='';
            $event_date_minute='';
            $event_end_date=$event->event_end_date;
            $event_end_date_hour='';
            $event_end_date_minute='';
            $event_date_string=$event_date;
            $event_end_date_string=$event_end_date;
		}
 		else
 		{
  		    $id     = $input->getInt('id', 0);
    		$params = $input->getString('params');
            $fieldextras = new Registry($params);
            $event_date=$input->getString('event_date');
            $event_date_hour=$input->getString('event_date_hour');
            $event_date_minute=$input->getString('event_date_minute');
            $event_end_date=$input->getString('event_end_date');
            $event_end_date_hour=$input->getString('event_end_date_hour');
            $event_end_date_minute=$input->getString('event_end_date_minute');
            $event_date_string=$event_date." ".$event_date_hour.":".$event_date_minute;
            $event_end_date_string=$event_end_date." ".$event_end_date_hour.":".$event_end_date_minute;
		}
		$db = Factory::getDbo();

        if ($id)
        {
            // this only looks at members currently
    		$sql = "SELECT * FROM #__eb_registrants WHERE published=1 and is_group_billing=0 and user_id != 0 and event_id=" . $id;
    		$db->setQuery($sql);
    		$rowMembers = $db->loadObjectList();
    		
            $registrantArray = array() ;
    		for ($i = 0, $n = count($rowMembers); $i < $n; $i++)
    		{
    		    $sql = "SELECT a.first_name, a.last_name, b.title FROM #__eb_registrants as a left join #__eb_events as b on b.id = a.event_id WHERE b.published=1 and a.published=1 and a.user_id=".$rowMembers[$i]->user_id." and a.is_group_billing=0 
    		    and date(b.event_date)='".$event_date."' and b.id != ".$id. ' limit 1';
        		Log::add($sql, Log::INFO, 'com_eventbooking');
    
    		    $db->setQuery($sql) ;
    		    $dupreg=0;
    		    $dupreg=$db->loadObject();
    		    if ($dupreg)
    		    {
                    $error="Registrant ".$dupreg->first_name.' '.$dupreg->last_name." on this Event has a date conflict with another published event: ".$dupreg->title.". Please change the start and/or end dates.";
                    Log::add($user->get('name').' '.$error, Log::INFO, 'com_mbwc');
                    return $error;
                }
     		}
        }
	    return;
	}
    public static function checkDuplicateLeader($input, $use_id)
    {
        $user   = Factory::getUser();
		$db = Factory::getDbo();
 		if ($use_id)
 		{
 		    $id=$use_id;
 		    $sql="select * from jos_eb_events where id=".$id;
 		    $db->setQuery($sql);
 		    $event=$db->loadObject();
 		    $fieldextras=new Registry($event->custom_fields);
            $event_date=$event->event_date;
            $event_date_hour='';
            $event_date_minute='';
            $event_end_date=$event->event_end_date;
            $event_end_date_hour='';
            $event_end_date_minute='';
            $event_date_string=$event_date;
            $event_end_date_string=$event_end_date;
		}
 		else
 		{
  		    $id     = $input->getInt('id', 0);
    		$params = $input->getString('params');
            $fieldextras = new Registry($params);
            $event_date=$input->getString('event_date');
            $event_date_hour=$input->getString('event_date_hour');
            $event_date_minute=$input->getString('event_date_minute');
            $event_end_date=$input->getString('event_end_date');
            $event_end_date_hour=$input->getString('event_end_date_hour');
            $event_end_date_minute=$input->getString('event_end_date_minute');
            $event_date_string=$event_date." ".$event_date_hour.":".$event_date_minute;
            $event_end_date_string=$event_end_date." ".$event_end_date_hour.":".$event_end_date_minute;
		}

        $error="";

        $sql="select title from jos_eb_events where (parent_id is null or parent_id=0) and (json_unquote(json_extract(custom_fields,'$.field_leader_id1'))=".$fieldextras->get('field_leader_id1')." or 
        json_unquote(json_extract(custom_fields,'$.field_leader_id2'))=".$fieldextras->get('field_leader_id1')." or 
        json_unquote(json_extract(custom_fields,'$.field_leader_id3'))=".$fieldextras->get('field_leader_id1');
        if ($fieldextras->get('field_leader_id2'))
        {
          $sql = $sql . " or json_unquote(json_extract(custom_fields,'$.field_leader_id1'))=".$fieldextras->get('field_leader_id2')." or 
          json_unquote(json_extract(custom_fields,'$.field_leader_id2'))=".$fieldextras->get('field_leader_id2')." or 
          json_unquote(json_extract(custom_fields,'$.field_leader_id3'))=".$fieldextras->get('field_leader_id2');
        }
        if ($fieldextras->get('field_leader_id3'))
        {
          $sql = $sql . " or json_unquote(json_extract(custom_fields,'$.field_leader_id1'))=".$fieldextras->get('field_leader_id3')." or 
          json_unquote(json_extract(custom_fields,'$.field_leader_id2'))=".$fieldextras->get('field_leader_id3')." or 
          json_unquote(json_extract(custom_fields,'$.field_leader_id3'))=".$fieldextras->get('field_leader_id3');
        }
        $sql = $sql . ") and published =1 and event_date <='".$event_end_date_string."' and 
        event_end_date >= '".$event_date_string."'";
        if ($id)
        {
            $sql = $sql . " and id != ".$id;
        }
        $db->setQuery($sql);
        $duplicate = $db->loadResult();
        if (!$duplicate)
        {
            //check if leader is already registered on an event also
            $sql="select c.title from jos_eb_registrants as b join jos_eb_events as c on c.id=b.event_id where (b.user_id=".$fieldextras->get('field_leader_id1');
            if ($fieldextras->get('field_leader_id2'))
            {
              $sql = $sql . " or b.user_id=".$fieldextras->get('field_leader_id2');
            }
            if ($fieldextras->get('field_leader_id3'))
            {
              $sql = $sql . " or b.user_id=".$fieldextras->get('field_leader_id3');
            }
            
            $sql = $sql . ") and b.published=1 and b.is_group_billing=0 and c.published=1 and (c.parent_id is null or c.parent_id=0) and c.event_date <='".$event_end_date_string."' 
            and c.event_end_date >= '".$event_date_string."'";
            if ($id)
            {
                $sql = $sql . " and c.id != ".$id;
            }
            $sql = $sql . " limit 1";
            $db->setQuery($sql);
            $duplicate = $db->loadResult();
        }
        if ($duplicate)
        {
            $error="One of the leaders on this Event has a date conflict with a published event: ".$duplicate." that they are a leader or a registrant. Please change the start and/or end dates";
            Log::add($user->get('name').' '.$error, Log::INFO, 'com_mbwc');
        }

        return $error;
    }
    
	public static function isTripLeaderOnEvent($event_id)
	{
		$db = Factory::getDbo();
		$user = Factory::getUser();
		$userId = $user->get('id');
		$sql = "select 1 from jos_user_usergroup_map as a left join jos_eb_registrants as b on b.user_id = a.user_id where (a.group_id = 9) and b.published=1 and b.is_group_billing=0 and b.event_id = ".$event_id." and a.user_id = " .$userId;
		$db->setQuery($sql);
		$isTripLeader = $db->loadResult();
		
        return $isTripLeader;
	}
    public static function generateMail($row, $subject_name,$body_name, $waitlist, $manual_visitor=0)
    {
		$db = Factory::getDbo();
		$message = \EventbookingHelper::getMessages();
		if ($message->__isset($subject_name))
        {
		    $emailSubject = $message->{$subject_name};
        }
        else
        {
            $emailSubject = $subject_name;
        }
		$emailBody = $message->{$body_name};

		$replaces = \EventbookingHelperRegistration::getRegistrationReplaces($row);

		foreach ($replaces as $key => $value)
		{
			$key          = strtoupper($key);
			$value        = (string) $value;
			$emailSubject = str_replace("[$key]", $value, $emailSubject);
			$emailBody    = str_replace("[$key]", $value, $emailBody);
		}
    	$leaderName=MBWCHelper::getLeaderName($row->event_id);
   	    $emailBody = str_replace('[FIELD_LEADER_NAME]', $leaderName, $emailBody);
   	    
		$leaderPh = MBWCHelper::getLeaderPhone($row->event_id);
    	$emailBody = str_replace('[FIELD_MOBILE_PH]', $leaderPh, $emailBody);
  	    
		if ($waitlist)
		{
		    $emailSubject = str_replace('[REGISTERED_WAITLISTED]', "Waitlisted", $emailSubject);
		    $emailBody = str_replace('[REGISTERED_WAITLISTED]', "waitlisted", $emailBody);
		    $emailSubject = str_replace('[REGISTER_WAITLIST]', "Waitlist", $emailSubject);
		    $emailBody = str_replace('[REGISTER_WAITLIST]', "waitlisted", $emailBody);
		    $emailSubject = str_replace('[REGISTRATION_WAITLIST]', "Waitlist", $emailSubject);
		    $emailBody = str_replace('[REGISTRATION_WAITLIST]', "waitlist", $emailBody);
		    $emailSubject = str_replace('[REGISTRANTS_WAITLISTS]', "Waitlists", $emailSubject);
		    $emailBody = str_replace('[REGISTRANTS_WAITLISTS]', "waitlists", $emailBody);
		}
		else
		{
		    $emailSubject = str_replace('[REGISTERED_WAITLISTED]', "Registered", $emailSubject);
		    $emailBody = str_replace('[REGISTERED_WAITLISTED]', "registered", $emailBody);
		    $emailSubject = str_replace('[REGISTER_WAITLIST]', "Registration", $emailSubject);
		    $emailBody = str_replace('[REGISTER_WAITLIST]', "registered", $emailBody);
		    $emailSubject = str_replace('[REGISTRATION_WAITLIST]', "Registration", $emailSubject);
		    $emailBody = str_replace('[REGISTRATION_WAITLIST]', "registration", $emailBody);
		    $emailSubject = str_replace('[REGISTRANTS_WAITLISTS]', "Registrants", $emailSubject);
		    $emailBody = str_replace('[REGISTRANTS_WAITLISTS]', "registrants", $emailBody);
		}
        $db = Factory::getDbo();
   		$sql = 'SELECT SUM(number_registrants) AS total_registrants FROM #__eb_registrants WHERE event_id=' . $row->event_id .
                ' AND group_id=0 AND (published=1 OR published=4)';
        $db->setQuery($sql);
        $numberRegistrants = $db->loadResult();
    	$emailBody = str_replace('[NUM_REGISTRANTS]', $numberRegistrants, $emailBody);
    	
		$sql = "select a.name, b.cb_mobphone from jos_users a, jos_comprofiler b where a.id in (select user_id from jos_user_usergroup_map where group_id in (select id from jos_usergroups where title='Trip Emergency Contact')) and b.user_id=a.id";
   	    $db->setQuery($sql);
		$club_contacts = $db->loadObjectList();
    	
		$check="<p><strong>CHECK:</strong> Make sure you have your completed&nbsp;<a href='".Route::_("index.php?option=com_content&view=article&id=151",true,-1)."'>M6 EMERGENCY INFORMATION FORM</a> in your backpack, <strong style='color:red';>and let someone know before you go.</strong></p>
		<p style='color:blue;'>Concerned family / personal contacts should ring the Leader, if no response then contact one of the Trip Emergency Contacts:";
	    for ($i=0;$i<count($club_contacts);$i++)
	    {
	      $check=$check.$club_contacts[$i]->name.' '.$club_contacts[$i]->cb_mobphone;
	      if ($i != (count($club_contacts) -1))
	      {
	          $check=$check.", ";
	      }
	    }
		
		$check=$check."</p>";
		if (!$row->user_id && $manual_visitor)
		{
		    $check=$check."<p><b>BRING:</b> Make sure you bring the completed <a href='".Route::_("index.php?option=com_content&view=article&id=152",true,-1)."'>M3 ACTIVITY PARTICIPATION TEMPORARY MEMBER</a> form and give it to the leader at the start of the activity.<p>";
		}
		$emailBody = str_replace('[CHECK_BRING]', $check, $emailBody);
    	
		$emailBody = \EventbookingHelper::convertImgTags($emailBody);
        $emailBody = \EventbookingHelperHtml::loadSharedLayout('emailtemplates/tmpl/email.php', ['body' => $emailBody, 'subject' => $emailSubject]);
        return array($emailSubject,$emailBody);
    }
    public static function sendCancelVisitorRegistrationEmail($row, $reason, $waitlist)
    {
		//Send notification email to administrator
        $app = Factory::getApplication();
		if ($row->first_name)
		{
		    $replyName = $row->first_name . " ". $row->last_name;
		}
		if ($row->email)
		{
		    $replyEmail = $row->email;
		}
		
        list($subject,$body) = MBWCHelper::generateMail($row, 'registration_cancel_email_subject', 'invitation_form_message', $waitlist);
		
		if ($reason)
		{
		    $body = str_replace('[REASON]', 'Reason: '.$reason, $body);
		}
		else if ($waitlist)
		{
		    $body = str_replace('[REASON]', '', $body);
		}
		else
		{
		    $body = str_replace('[REASON]', 'Reason: None given', $body);
		}
		$notificationEmails = MBWCHelper::getLeaderEmail($row->event_id);
   		MBWCHelper::sendMail($notificationEmails, $subject, $body, 1, null, null, null,$replyEmail,$replyName);
        
    }
    public static function sendCancelRegistrationEmail($row, $reason, $waitlist)
    {
		//Send notification email to administrator
        $app = Factory::getApplication();
		if ($row->first_name)
		{
		    $replyName = $row->first_name . " ". $row->last_name;
		}
		if ($row->email)
		{
		    $replyEmail = $row->email;
		}
		
        list($subject,$body) = MBWCHelper::generateMail($row, 'registration_cancel_email_subject', 'registration_cancel_email_body', $waitlist);
		
		if ($reason)
		{
		    $body = str_replace('[REASON]', 'Reason: '.$reason, $body);
		}
		else if ($waitlist)
		{
		    $body = str_replace('[REASON]', '', $body);
		}
		else
		{
		    $body = str_replace('[REASON]', 'Reason: None given', $body);
		}
		$notificationEmails = MBWCHelper::getLeaderEmail($row->event_id);
   		MBWCHelper::sendMail($notificationEmails, $subject, $body, 1, null, null, null,$replyEmail,$replyName);
        
    }
	public static function sendWaitinglistPromotionEmail($row, $config, $position,$replyEmail,$replyName)
	{
        $app = Factory::getApplication();
        $db = Factory::getDbo();

        list($subject,$body) = MBWCHelper::generateMail($row, 'Waiting list change for [EVENT_TITLE]', 'waitinglist_form_message', 1);

		$body = \EventbookingHelper::convertImgTags($body);
		$body = str_replace('[WAITLIST_POSITION]', $position, $body);
		$email=MBWCHelper::getRegistrantEmail($row);
        $recipients[]=$email;
		$notificationEmails = MBWCHelper::getLeaderEmail($row->event_id);
        if ($notificationEmails)
        {
            array_merge($recipients,explode(',', $notificationEmails));
        }
		MBWCHelper::sendMail($recipients, $subject, $body, 1);
	}
    
	public static function sendWaitinglistCancelEmail($row, $config, $title)
	{
        $app = Factory::getApplication();
        $db = Factory::getDbo();

        list($subject,$body) = MBWCHelper::generateMail($row, 'registration_approved_email_subject', 'registration_approved_email_body', 1);
		$body = str_replace('[EVENT_TITLE_BOOKED]', $title, $body);

		$body = \EventbookingHelper::convertImgTags($body);
		$email=MBWCHelper::getRegistrantEmail($row);
        $recipients[]=$email;
		$notificationEmails = MBWCHelper::getLeaderEmail($row->event_id);
        if ($notificationEmails)
        {
            array_merge($recipients,explode(',', $notificationEmails));
        }
		MBWCHelper::sendMail($recipients, $subject, $body, 1);
	}
	//Delete registrant from other waitlists on events on the same day
 	public static function deleteFromWaitlists($userId, $eventId,$config) 
	{
		$db = Factory::getDbo();
		
		$sql = 'SELECT event_date, event_end_date, title FROM #__eb_events WHERE id=' . $eventId;
		$db->setQuery($sql);
		$event=$db->loadObject();

		$sql = 'SELECT a.*, b.title FROM #__eb_registrants as a left join #__eb_events as b on b.id = a.event_id WHERE (a.published=3 or a.published=5) and a.user_id='.$userId." and b.event_date<='".$event->event_end_date."' and b.event_end_date>='".$event->event_date."' and b.id != ".$eventId ;
        Log::add('deleteFromWaitlists '.$sql, Log::INFO, 'com_mbwc');

		$db->setQuery($sql) ;				
		$registrantList = $db->loadObjectList() ;
		
        foreach ($registrantList as $row)
        {
            Log::add("Deleting user ".$userId." from other waitlists ".$row->title, Log::INFO, 'com_mbwc');
		    $sql = 'DELETE FROM #__eb_field_values WHERE registrant_id ='.$row->id;
			$db->setQuery($sql) ;
			$db->execute() ; 
			$sql = 'DELETE FROM #__eb_registrants WHERE id ='.$row->id;
			$db->setQuery($sql) ;
			$db->execute() ;
			MBWCHelper::sendWaitinglistCancelEmail($row, $config, $event->title);
		}
    }
	public static function acceptRegistration($eventId)
	{
		$db = Factory::getDbo();
		$user = Factory::getUser();
		$gid = $user->get('aid');
		if (!$eventId)
			return false;
		$sql = 'SELECT * FROM #__eb_events WHERE id=' . $eventId . ' AND published=1 ';
		$db->setQuery($sql);
		$row = $db->loadObject();
		if (!$row)
			return false;
		if ($row->registration_type == 3)
			return false;
		
		if ($row->cut_off_date == $db->getNullDate())
		{
		    // if cutoffdate is null, assume 24h
			$sql = 'SELECT TIMESTAMPDIFF(HOUR,NOW(), event_date) AS number_hours FROM #__eb_events WHERE id=' . $eventId;
    		$db->setQuery($sql);
    		$numberHours = $db->loadResult();
    		if ($numberHours < 24)
    		{
    			return false;
    		}
		}
		else
		{
			$sql = 'SELECT TIMESTAMPDIFF(HOUR,NOW(), cut_off_date) AS number_hours FROM #__eb_events WHERE id=' . $eventId;
    		$db->setQuery($sql);
    		$numberHours = $db->loadResult();
    		if ($numberHours < 0)
    		{
    			return false;
    		}
		}
		if ($row->event_capacity)
		{
			//Get total registrants for this event
			$sql = 'SELECT SUM(number_registrants) AS total_registrants FROM #__eb_registrants WHERE event_id=' . $eventId .
				 ' AND group_id=0 AND (published=1 OR published=4)';
			$db->setQuery($sql);
			$numberRegistrants = (int) $db->loadResult();
			if ($numberRegistrants >= $row->event_capacity)
			{
				return false;

			}
		}
		//Check to see whether the current user has registered for the event
		if ($user->get('id'))
		{
			$sql = 'SELECT COUNT(id) FROM #__eb_registrants WHERE event_id=' . $eventId . ' AND user_id=' . $user->get('id') .
				 ' AND (published=1 OR published=4)';
			$db->setQuery($sql);
			$total = $db->loadResult();
			if ($total)
			{
				return false;
			}
		}
		return true;
	}
	public static function sendTemporaryMemberForm($registrant, $config)
    {
		$app = Factory::getApplication() ;
		$db = Factory::getDbo();
		$user = Factory::getUser() ;
	    $sql = "SELECT * from #__eb_events WHERE id=" . $registrant->event_id;
		$db->setQuery($sql);
		$event = $db->loadObject();
		$event->leaders_name = MBWCHelper::getLeaderName($event->id);
		$email=MBWCHelper::getRegistrantEmail($registrant);
		
    	$sql =  "select field_value from  #__eb_field_values where field_id=21 and registrant_id=".$registrant->id;
		$db->setQuery($sql) ;
		$mobile_phone=$db->loadResult();			

        Log::add($user->get('name').' Sending Temporary Membership Form for event: '.$event->title. ' to '.$registrant->first_name.' '.$registrant->last_name, Log::INFO, 'com_mbwc');		

		$replyName = $user->get('name');
		$replyEmail = $user->get('email');
		$fieldextras = new Registry($event->custom_fields);
		
		$content = 
		"<h1 style='text-align: center'>Maroondah Bushwalking Club Inc</h1>" .
		"<div style='text-align: center'>www.mbwc.org.au</div>" .
"<h1>ACTIVITY PARTICIPATION</h1>" .
"<h1>TEMPORARY MEMBER (Adult)</h1>" .
"<p>Temporary Membership is granted and valid for this activity only (limited to 3 activities in any 12-month period).</p>".
"<h2>Activity</h2>";
        $content = $content .
        "<table>" .
        "<tr><td><b>Leader Name:</b>&nbsp;" . $event->leaders_name . "</td></tr>" .
        "<tr><td><b>Description of Activity:</b>&nbsp;" . $event->title . "</td></tr>" .
        "<tr><td><b>Participant Name:</b>&nbsp;" . $registrant->first_name. ' '.$registrant->last_name . "</td></tr>" .
        "<tr><td><b>Home Phone Number:</b>&nbsp;" . $registrant->phone . "</td></tr>" .
        "<tr><td><b>Mobile Phone Number:</b>&nbsp;" . $mobile_phone . "</td></tr>" .
        "<tr><td><b>Event Date:</b>&nbsp;" . substr($event->event_date,0,10) . "</td></tr>" .
        "</table>";

        $content = $content . "<h2>Emergency Contact or Next of Kin</h2>".
        "<table>" .
        "<tr><td><b>Name:</b>&nbsp;".$fieldextras->get('field_kin_name')."</td></tr>".
        "<tr><td><b>Relationship:</b>&nbsp;".$fieldextras->get('field_kin_relationship')."</td></tr>".
        "<tr><td><b>Home Phone:</b>&nbsp;".$fieldextras->get('field_kin_home_phone')."</td></tr>".
        "<tr><td><b>Mobile Phone:</b>&nbsp;".$fieldextras->get('field_kin_mobile_phone')."</td></tr>";
        
        if ($fieldextras->get('field_kin_name_2'))
        {
            $content = $content .  "<tr><td><b>Name:</b>&nbsp;".$fieldextras->get('field_kin_name_2')."</td></tr>".
        "<tr><td><b>Relationship:</b>&nbsp;".$fieldextras->get('field_kin_relationship_2')."</td></tr>".
        "<tr><td><b>Home Phone:</b>&nbsp;".$fieldextras->get('field_kin_home_phone_2')."</td></tr>".
        "<tr><td><b>Mobile Phone:</b>&nbsp;".$fieldextras->get('field_kin_mobile_phone_2')."</td></tr>";
        }


        $content = $content . "</table>";
        $content = $content . "<h2>Acknowledgement of Risks and Obligations</h2>".
        "In voluntarily participating in activities organised by the Maroondah Bushwalking Club (the Club), described to me by the Club’s activity leaders, I am aware that my participation in these activities may expose me to risks that could lead to injury, property loss or damage. These risks include (but are not limited to) slippery or uneven surfaces, loose rocks, sunburn, pits/trenches and hyperthermia.<br>
To minimise these risks during activities I will:
<ol>
<li>Ensure activities are within my capabilities.</li>
<li>Carry snacks, lunch, 1 litre water (more in hot weather), sunscreen, personal medication, first
aid kit, wear protective clothing, wear strong walking boots, and carry the appropriate equipment.</li>
<li>Inform the activity leader if I am taking medication or have physical or other limitations that might affect
my participation.</li>
<li>Make every effort to ensure that I will remain with the rest of the party during the activity.</li>
<li>Accept & follow instructions given by the activity leader and the nominated whip.</li>
<li>Carry the club's Personal Emergency Information (Form M6) detailing any critical medical information
and person(s) who can act on my behalf.</li>
</ol>
<p><b>NOTE: Bushwalking Victoria strongly recommends that all members take out personal ambulance cover with
Ambulance Victoria.	</b></p>
<p>I will notify the activity leader as soon as practicable if I become unable or unwilling to participate in this activity.</p>
Having read and understood these requirements and risks, I wish to join this activity. I have considered the risks before choosing to sign this acknowledgement of risk and I accept that in signing this form I take responsibility for my actions<br><br>".
"<table><tr><td><b>Signed:</b>&nbsp;".$registrant->first_name.' '.$registrant->last_name."</td>K/tr><tr><td><b>Date:</b>&nbsp;".substr($registrant->register_date,0,10)."</td></tr></table>";
        
        if (strpos(strtolower($event->title),"test")===false)
        {
            $recipients[]='membsec@mbwc.org.au';
            $recipients[]=$email;
		    $notificationEmails = MBWCHelper::getLeaderEmail($event->id);
            if ($notificationEmails)
            {
                array_merge($recipients,explode(',', $notificationEmails));
            }
        }
        else
        {
            $recipients[]=$user->email;
        }

		MBWCHelper::sendMail($recipients, "Temporary Member's Form for ".$event->title, $content, 1, $replyEmail, null, null, $replyEmail, $replyName);
    }
	public static function countNumberWaitingList($event)
	{
		$db    = Factory::getDbo();
		$query = $db->getQuery(true)
			->select('IFNULL(SUM(number_registrants), 0)')
			->from('#__eb_registrants')
			->where('event_id = ' . (int) $event->id)
			->where('group_id = 0')
			->where('published in (3,5)');
		$db->setQuery($query);

		return $db->loadResult();
	}
	public static function SaveICS($start,$end,$name,$description,$location) {
        $message[]="BEGIN:VCALENDAR";
        $message[]="VERSION:2.0";
        $message[]="PRODID:MBWC";
        $message[]="METHOD:PUBLISH";
        $message[]="BEGIN:VEVENT";
        $message[]="TZID:Australia/Melbourne";
        $message[]="DTSTART:".date("Ymd\THis",strtotime($start));
        $message[]="DTEND:".date("Ymd\THis",strtotime($end));
        $message[]="LOCATION:".$location;
        $message[]="TRANSP:OPAQUE";
        $message[]="SEQUENCE:0";
        $message[]="UID:";
        $message[]="DTSTAMP:".date("Ymd\THis");
        $message[]="SUMMARY:".$name;
        $message[]="DESCRIPTION:".$description;
        $message[]="PRIORITY:1";
        $message[]="CLASS:PUBLIC";
        $message[]="ORGANIZER;CN='Maroondah Bushwalking Club':mailto:webadmin@mbwc.org.au";
        $message[]="BEGIN:VALARM";
        $message[]="TRIGGER:-PT10080M";
        $message[]="ACTION:DISPLAY";
        //$message[]="DESCRIPTION:".$name;
        $message[]="END:VALARM";
        $message[]="END:VEVENT";
        $message[]='END:VCALENDAR';

        $data = implode("\r\n", $message);
        file_put_contents(JPATH_ROOT . '/media/mail.ics',$data);
    }
	public static function ClearICS() {
	    unlink(JPATH_ROOT . '/media/mail.ics');
	}
	public static function isGroupRegistration($id)
	{
		if (!$id)
			return false;
		$db = Factory::getDbo();
		$sql = 'SELECT COUNT(*) FROM #__eb_registrants WHERE group_id=' . $id;
		$db->setQuery($sql);
		$total = (int) $db->loadResult();
		return $total > 0 ? true : false;
	}

	public static function checkWaitList($eventId,$max=99)
	{
		$db = Factory::getDbo();
		$config = \EventbookingHelper::getConfig();

        //only check cutoffdate if we are doing this via the normal cancellation method. If its via the promote button, we will set max=1, so don't check cutoff.
        if ($max == 99)
        {
    		$sql = "SELECT * FROM #__eb_events WHERE id=" . $eventId." and DATE(cut_off_date) > CURDATE()";
    		$db->setQuery($sql);
    		$event = $db->loadObject();
        }
        else
        {
    		$sql = "SELECT * FROM #__eb_events WHERE id=" . $eventId;
    		$db->setQuery($sql);
    		$event = $db->loadObject();
        }
		
		if ($event)
		{
            Log::add('Promote '.$max, Log::INFO, 'com_mbwc');
            //No promotions in the past unless via the promote button
            if (strtotime($event->event_date) > time() || $max == 1)
            {
       	        $fieldextras = new Registry($event->custom_fields);
        		$sql = "select name as leader_name from #__users where id = ".$fieldextras->get('field_leader_id1');
             	$db->setQuery($sql) ;
        		$replyName = $db->loadResult();
        		$notificationEmails = MBWCHelper::getLeaderEmail($event->id);
        		$notificationEmails .= ",webadmin@mbwc.org.au";

        		$sql = 'SELECT SUM(number_registrants) FROM #__eb_registrants WHERE event_id='.$event->id.' AND group_id=0 AND (published=1 or published=4) group by event_id';
        		$db->setQuery($sql);
        		$total_number=$db->loadResult();
        
                //If the walk was full, then check if anyone on the waitlist needs to be moved onto the walk
        		$sql = 'SELECT SUM(number_registrants) FROM #__eb_registrants WHERE event_id='.$event->id.' AND group_id=0 AND (published=3 or published=5) group by event_id';
        		$db->setQuery($sql);
        		$num_waitlist=$db->loadResult();
        
                $num_promoted=0;
        		while (($max==1 || $total_number < $event->event_capacity) && $num_waitlist > 0 && $num_promoted<$max)
        		{
        		    //get first person off waitlist and change state to 1 from 3
        			$sql = 'SELECT id FROM #__eb_registrants WHERE event_id=' . $event->id .
        				 ' AND is_group_billing=0 AND (published=3 or published=5) ORDER BY register_date  limit 1';
        		    $db->setQuery($sql);
        		    $waitlistid = $db->loadResult();
        		    $sql = 'UPDATE #__eb_registrants SET published = 1 WHERE published=3 and id='.$waitlistid;
        		    $db->setQuery($sql);
            		$db->execute();
        		    $sql = 'UPDATE #__eb_registrants SET published = 4 WHERE published=5 and id='.$waitlistid;
        		    $db->setQuery($sql);
            		$db->execute();
            		
            		$sql = 'SELECT * FROM #__eb_registrants WHERE id=' . $waitlistid;
            		$db->setQuery($sql);
            		$row = $db->loadObject();
            		Log::add('Promoted '.$row->first_name . ' '. $row->last_name .' to event:'.$event->title, Log::INFO, 'com_mbwc');
            		
            		//Delete registrant from other waitlists on events on the same day
                    MBWCHelper::deleteFromWaitlists($row->user_id,$event->id,$config);  		
 
                    // No emails in the past
                    if (strtotime($event->event_date) > time())
                    {
                        list($emailSubject,$emailBody) = MBWCHelper::generateMail($row, 'watinglist_notification_subject', 'watinglist_notification_body', 1);

                		//Send emails to notification emails
             		    Log::add('Mailing leader about promotion of '.$row->first_name . ' '. $row->last_name .' to event:'.$event->title, Log::INFO, 'com_mbwc');
	                    MBWCHelper::sendMail($notificationEmails, $emailSubject, $emailBody, 1, null, null, null);           

                		//don't email unapproved visitors
                		if ($row->email && $row->published==1)
                		{
                		    $toEmail = $row->email;
                            list($emailSubject,$emailBody) = MBWCHelper::generateMail($row, 'watinglist_confirmation_subject', 'watinglist_confirmation_body', 1);

             		        Log::add('Mailing registrant '.$row->first_name . ' '. $row->last_name .' about promotion to event:'.$event->title, Log::INFO, 'com_mbwc');
                		    
    			            $attachments =MBWCHelper::generateICS($event); 						
                			MBWCHelper::sendMail($toEmail, $emailSubject, $emailBody, 1, null, null, $attachments, $emails[0], $replyName);
                			MBWCHelper::ClearICS();
                		}
            		}
        			$num_promoted = $num_promoted + 1;
        			$num_waitlist = $num_waitlist - 1;
        			$total_number = $total_number + 1;
                }

                // No emails in the past
                if (strtotime($event->event_date) > time())
                {
    			
        		    // Mail remaining people (not pending visitors tho) on waitlist to tell them their position has changed.
             		Log::add('Mailing people on waitlist about their position change in event:'.$event->title, Log::INFO, 'com_mbwc');
             		
            		$sql = 'SELECT id FROM #__eb_registrants WHERE event_id=' . $event->id .
            	 ' AND is_group_billing=0 AND published=3 ORDER BY register_date';
            	    $db->setQuery($sql);
            	    $waitlistids = $db->loadColumn();
            
            		for ($i = 0; $i < count($waitlistids); $i++)
            		{
                		$sql = 'SELECT * FROM #__eb_registrants WHERE id=' . $waitlistids[$i];
                		$db->setQuery($sql);
                		$row = $db->loadObject();
            		    MBWCHelper::sendWaitinglistPromotionEmail($row, $config, $i+1, $emails[0], $replyName);
                    }
                }
            }
		}
	}

    public static function generateICS($event)
    {
    	$leaderName=MBWCHelper::getLeaderName($event->id);

		$db = Factory::getDbo();
   	    $sql = "select custom_fields from jos_eb_events where id =".$event->id;
    	$db->setQuery($sql);
		$custom_fields = $db->loadResult();
        $fieldextras = new Registry($custom_fields);
        
		$sql = "select concat(b.cb_mobphone,' (',a.name,')' ) as leader_ph from jos_users a, jos_comprofiler b where a.id=".$fieldextras->get('field_leader_id1')." and b.user_id=a.id";
   	    $db->setQuery($sql);
		$leaderPh = $db->loadResult();

    	$db->setQuery("SELECT name FROM #__eb_categories WHERE id IN (SELECT category_id FROM #__eb_event_categories WHERE event_id = $event->id)");
    	$category= implode(', ', $db->loadColumn());			

    	$description = "Walk Grade: ".$category.'\nDistance: '.$fieldextras->get('field_distance').'\nLeader Name: '.$leaderName.'\nLeader Mobile Phone: '.$leaderPh;
	    $location='';
	    if ($fieldextras->get('field_address')) {
	        $location=$fieldextras->get('field_address');
	        $description = $description .'\nCar Pool Address: '.$location;
	    }
	    if ($fieldextras->get('field_address_start')) {
	        $location=$fieldextras->get('field_address_start');
	        $description = $description .'\nWalk Start Address: '.$location;
	    }
	    $description = $description .'\n'.strip_tags($event->description);
	    MBWCHelper::SaveICS($event->event_date,$event->event_end_date,$event->title,$description,$location);
		$attachments[] = JPATH_ROOT . '/media/mail.ics';
		return $attachments;
    }

    //only send to leader
    public static function sendWaitinglistEmail($row, $config)
	{
		$config = \EventbookingHelper::getConfig();
	    $mailer = Factory::getMailer();
        $app = Factory::getApplication();
		$db = Factory::getDbo();

 		$email=MBWCHelper::getRegistrantEmail($row);
	    if ($email)
	    {
		    $sql = "SELECT a.* FROM #__eb_events as a WHERE a.id=" . $row->event_id;
		    $db->setQuery($sql);
    		$event = $db->loadObject();
		    $event->leaders_name = MBWCHelper::getLeaderName($row->event_id);

    		//Send emails to notification emails
		    $notificationEmails = MBWCHelper::getLeaderEmail($row->event_id);
    		$emails = explode(',', $notificationEmails);
    		
            list($emailSubject,$emailBody) = MBWCHelper::generateMail($row, 'admin_email_subject', 'admin_email_body', 1, 0);

     		MBWCHelper::sendMail($emails, $emailSubject, $emailBody, 1, null, null, null,$email,$replyName);
 	    }
	}
    
    public static function sendRegistrationEmails($row, $config)
	{
		$config = \EventbookingHelper::getConfig();
	    $mailer = Factory::getMailer();

 		$email=MBWCHelper::getRegistrantEmail($row);
	    if ($email)
	    {
            $app = Factory::getApplication();
    		$db = Factory::getDbo();
		    $sql = "SELECT a.* FROM #__eb_events as a WHERE a.id=" . $row->event_id;
		    $db->setQuery($sql);
    		$event = $db->loadObject();
		    $event->leaders_name = MBWCHelper::getLeaderName($row->event_id);

    		//Send emails to notification emails
		    $notificationEmails = MBWCHelper::getLeaderEmail($row->event_id);
    		$emails = explode(',', $notificationEmails);
    		
            list($emailSubject,$emailBody) = MBWCHelper::generateMail($row, 'user_email_subject', 'user_email_body', 0, 0);

     		$attachments =MBWCHelper::generateICS($event); 						
      		MBWCHelper::sendMail($email, $emailSubject, $emailBody, 1, $emails, null, $attachments,$emails[0],$event->leaders_name);
      		MBWCHelper::ClearICS();
	    }
	}

    public static function sendGroupRegistrationEmails($rowMembers, $config)
	{
		$config = \EventbookingHelper::getConfig();
	    $mailer = Factory::getMailer();
        $app = Factory::getApplication();
		$db = Factory::getDbo();
		foreach ($rowMembers as $row)
		{
     		$email=MBWCHelper::getRegistrantEmail($row);
    	    if ($email)
    	    {
     		    $sql = "SELECT a.* FROM #__eb_events as a WHERE a.id=" . $row->event_id;
    		    $db->setQuery($sql);
        		$event = $db->loadObject();
    		    $event->leaders_name = MBWCHelper::getLeaderName($row->event_id);
    
        		//Send emails to notification emails
    		    $notificationEmails = MBWCHelper::getLeaderEmail($row->event_id);
        		$emails = explode(',', $notificationEmails);
        		
                list($emailSubject,$emailBody) = MBWCHelper::generateMail($row, 'group_member_email_subject', 'group_member_email_body', 0, 0);
    
         		$attachments =MBWCHelper::generateICS($event); 						
          		MBWCHelper::sendMail($email, $emailSubject, $emailBody, 1, $emails, null, $attachments,$emails[0],$event->leaders_name);
          		MBWCHelper::ClearICS();
    	    }
		}
	}

	public static function sendRegistrationLeaderEmails($row, $config)
	{
		$config = \EventbookingHelper::getConfig();
	    $mailer = Factory::getMailer();

 		$email=MBWCHelper::getRegistrantEmail($row);
	    if ($email)
	    {
            $app = Factory::getApplication();
    		$db = Factory::getDbo();
    		if ($row->first_name)
    		{
    		    $replyName = $row->first_name . " ". $row->last_name;
    		}
		    $sql = "SELECT a.* FROM #__eb_events as a WHERE a.id=" . $row->event_id;
		    $db->setQuery($sql);
    		$event = $db->loadObject();
		    $event->leaders_name = MBWCHelper::getLeaderName($row->event_id);

    		//Send emails to notification emails
		    $notificationEmails = MBWCHelper::getLeaderEmail($row->event_id);
    		$emails = explode(',', $notificationEmails);
    		
            list($emailSubject,$emailBody) = MBWCHelper::generateMail($row, 'admin_email_subject', 'admin_email_body', 0, 0);

     		MBWCHelper::sendMail($emails, $emailSubject, $emailBody, 1, null, null, null,$email,$replyName);
	    }
	}

    
	public static function sendAddMemberEmails($row, $config, $waitlist, $manual_visitor)
	{
		$config = \EventbookingHelper::getConfig();
	    $mailer = Factory::getMailer();

 		$email=MBWCHelper::getRegistrantEmail($row);
	    if ($email)
	    {
            $app = Factory::getApplication();
    		$db = Factory::getDbo();
 		    $sql = "SELECT a.* FROM #__eb_events as a WHERE a.id=" . $row->event_id;
		    $db->setQuery($sql);
    		$event = $db->loadObject();
		    $event->leaders_name = MBWCHelper::getLeaderName($row->event_id);

    		//Send emails to notification emails
		    $notificationEmails = MBWCHelper::getLeaderEmail($row->event_id);
    		$emails = explode(',', $notificationEmails);
    		
            list($emailSubject,$emailBody) = MBWCHelper::generateMail($row, 'invitation_email_subject', 'invitation_email_body', $waitlist, $manual_visitor);

            $attachments=null;
    		if ($config->send_ics && !$waitlist)
    		{
    			$attachments =MBWCHelper::generateICS($event); 						
    		}
     		MBWCHelper::sendMail($email, $emailSubject, $emailBody, 1, $emails, null, $attachments,$emails[0],$event->leaders_name);
     		if ($attachments)
     		{
     		    MBWCHelper::ClearICS();
     		}
	    }
	}
	public static function addUser($eventId, $id, $waitlist, $sendMail)
	{
		if ($waitlist)
		{
		    $published_state=3;
		}
		else
		{
		    $published_state=1;
		}
		$user = Factory::getUser();
		$db = Factory::getDbo();
		
		$sql = 'SELECT title FROM #__eb_events WHERE id ='.$eventId;
		$db->setQuery($sql) ;
		$title=$db->loadResult();
		
		$currentDate = gmdate('Y-m-d H:i:s');
		$sql = "SELECT * FROM #__users where id = " .  $id;
		$db->setQuery($sql);

		$rows = $db->loadObjectList();
		$rowname = explode(" ", $rows[0]->name,2); 
        Log::add($user->get('name').' Add Member Registrant '.$rows[0]->name.' for event:'.$title.' waitlist '.$waitlist, Log::INFO, 'com_mbwc');

    	$sql = 'SELECT * FROM #__comprofiler WHERE id='.$id;
    	$db->setQuery($sql);
    	$res = $db->loadObject();

		$sql = "INSERT INTO #__eb_registrants (number_registrants, published, event_id, user_id, first_name, last_name, email, phone, register_date) 
		values(1,".$published_state.", ".$eventId.", " .$id. ", '" . $rowname[0] ."', '" . str_replace("'", "\'", $rowname[1]) ."', '" .  $rows[0]->email . "','" . $res->cb_homephone . "', '" . $currentDate . "')";

		$db->setQuery($sql) ;
		$db->execute();			
		
		$newid = $db->insertid();
		
		if (strlen($res->cb_mobphone) > 0)
		{
        	$sql =  "INSERT INTO #__eb_field_values (registrant_id, field_id, field_value) values (" . $newid  . ", 21,'"  . $res->cb_mobphone. "')"; 
        	$db->setQuery($sql) ;
        	$db->execute();	
		}			
		if (strlen($res->cb_firstaid) > 0)
		{
        	$sql =  "INSERT INTO #__eb_field_values (registrant_id, field_id, field_value) values (" . $newid  . ", 22,'"  . $res->cb_firstaid. "')";
        	$db->setQuery($sql) ;
        	$db->execute();	
		}			
		if (strlen($res->cb_firstaidlevel) > 0)
		{
        	$sql =  "INSERT INTO #__eb_field_values (registrant_id, field_id, field_value) values (" . $newid  . ", 23,'"  . $res->cb_firstaidlevel. "')";
        	$db->setQuery($sql) ;
        	$db->execute();	
		}
		if (strlen($res->cb_next_of_kin_1_name) > 0)
		{
        	$sql =  "INSERT INTO #__eb_field_values (registrant_id, field_id, field_value) values (" . $newid  . ", 28,'"  . $res->cb_next_of_kin_1_name. "')";
        	$db->setQuery($sql) ;
        	$db->execute();	
		}
		if (strlen($res->cb_next_of_kin_1_relationship) > 0)
		{
        	$sql =  "INSERT INTO #__eb_field_values (registrant_id, field_id, field_value) values (" . $newid  . ", 29,'"  . $res->cb_next_of_kin_1_relationship. "')";
        	$db->setQuery($sql) ;
        	$db->execute();	
		}
		if (strlen($res->cb_next_of_kin_1_home) > 0)
		{
        	$sql =  "INSERT INTO #__eb_field_values (registrant_id, field_id, field_value) values (" . $newid  . ", 30,'"  . $res->cb_next_of_kin_1_home. "')";
        	$db->setQuery($sql) ;
        	$db->execute();	
		}
		if (strlen($res->cb_next_of_kin_1_mobile) > 0)
		{
        	$sql =  "INSERT INTO #__eb_field_values (registrant_id, field_id, field_value) values (" . $newid  . ", 31,'"  . $res->cb_next_of_kin_1_mobile. "')";
        	$db->setQuery($sql) ;
        	$db->execute();	
		}
		if (strlen($res->cb_next_of_kin_2_name) > 0)
		{
        	$sql =  "INSERT INTO #__eb_field_values (registrant_id, field_id, field_value) values (" . $newid  . ", 32,'"  . $res->cb_next_of_kin_2_name. "')";
        	$db->setQuery($sql) ;
        	$db->execute();	
		}
		if (strlen($res->cb_next_of_kin_2_relationship) > 0)
		{
        	$sql =  "INSERT INTO #__eb_field_values (registrant_id, field_id, field_value) values (" . $newid  . ", 33,'"  . $res->cb_next_of_kin_2_relationship. "')";
        	$db->setQuery($sql) ;
        	$db->execute();	
		}
		if (strlen($res->cb_next_of_kin_2_home) > 0)
		{
        	$sql =  "INSERT INTO #__eb_field_values (registrant_id, field_id, field_value) values (" . $newid  . ", 35,'"  . $res->cb_next_of_kin_2_home. "')";
        	$db->setQuery($sql) ;
        	$db->execute();	
		}
		if (strlen($res->cb_next_of_kin_2_mobile) > 0)
		{
        	$sql =  "INSERT INTO #__eb_field_values (registrant_id, field_id, field_value) values (" . $newid  . ", 34,'"  . $res->cb_next_of_kin_2_mobile. "')";
        	$db->setQuery($sql) ;
        	$db->execute();	
		}
		$config = \EventbookingHelper::getConfig();
		if (!$waitlist)
		{
		    //Delete registrant from other waitlists on events on the same day
            MBWCHelper::deleteFromWaitlists($newid, $eventId, $config);  		
		}
 		if ($sendMail)
		{
		    $config->send_ics=1;
    		$sql = 'SELECT * FROM #__eb_registrants WHERE id=' . $newid;
    		$db->setQuery($sql);
    		$row = $db->loadObject();
		    MBWCHelper::sendAddMemberEmails($row, $config, $waitlist,0);
		}
   }
	public static function checkAndSendMembershipMail($row, $config)
    {
		$app = Factory::getApplication() ;
		$db = Factory::getDbo();
		$user = Factory::getUser() ;
		$email=MBWCHelper::getRegistrantEmail($row);
		
        $query="select count(*) from #__eb_registrants as a left join #__eb_events as b on b.id=a.event_id where ((a.last_name='".$row->last_name."' and a.first_name='".$row->first_name."') or a.email='".$email."') 
        and b.published=1 and date(b.event_date) > (now() - INTERVAL 12 month) and date(b.event_date) <= now() and a.is_group_billing=0 and a.published=1 
        and exists (select 1 from jos_mbwc_tripreports as d where d.event_id=b.id)
        and not exists (select 1 from #__membership as c where ((c.last_name='".$row->last_name."' and c.first_name='".$row->first_name."') or c.email='".$email."'))
        and not exists (select 1 from #__users where ((name='".$row->first_name.' '.$row->last_name."') or email='".$email."'))";
     		
		$db->setQuery($query);
		$howManyBooked = $db->loadResult();
		if ($howManyBooked>1 && $$email)
		{
            $content = "<p>Hi ".$row->first_name." ".$row->last_name.",</p><p>You have now done or been approved to do your qualifying walks and are now eligble to join membership of the Maroondah Bushwalking Club!</p><p>You can click <a href='https://www.mbwc.org.au/apply-for-membership'>here</a> to start your Membership process.</p><p>Regards,</p>MBWC Activity Convenor";
			MBWCHelper::sendMail($email, "You can now join Maroondah Bushwalking Club", $content, 1);		
		}
    }
    public static function mail_info($first_name, $last_name, $email, $title, $content)
    {
		$app = Factory::getApplication() ;
		$db = Factory::getDbo();
		$user = Factory::getUser() ;

        //exclude basecamps and walks over a year ago, and walks after a rejected membership
		if ($email)
		{
			$sql = "select count(distinct b.id) from #__eb_registrants as a left join #__eb_events as b on b.id=a.event_id  where a.email='".$email."'
		and (a.user_id is null or a.user_id=0) and b.published=1 and date(b.event_date) >= DATE_SUB(CURDATE(), INTERVAL 1 YEAR) and date(b.event_date) <= CURRENT_DATE() and a.is_group_billing=0 and a.published=1 
		and date(b.event_date) >= (select ifnull(max(reject_date),date(b.event_date)) from jos_membership as c where c.email='".$email."' and c.status=2)
		and not exists (select 1 from jos_eb_event_categories as d where d.event_id=b.id and d.category_id = 17)";
            $db->setQuery($sql) ;
            $num_walks = $db->loadResult();
    
			$sql = "select count(distinct b.id) from #__eb_registrants as a left join #__eb_events as b on b.id=a.event_id where a.email='".$email."'
		and (a.user_id is null or a.user_id=0) and b.published=1 and date(b.event_date) >= DATE_SUB(CURDATE(), INTERVAL 1 YEAR) and date(b.event_date) <= CURRENT_DATE() and a.is_group_billing=0 and a.published in (3,4,5) 
		and date(b.event_date) >= (select ifnull(max(reject_date),date(b.event_date)) from jos_membership as c where c.email='".$email."' and c.status=2)
		and not exists (select 1 from jos_eb_event_categories as d where d.event_id=b.id and d.category_id = 17)";
            $db->setQuery($sql) ;
            $num_pending_walks = $db->loadResult();
		}
		else
		{
			$sql = "select count(distinct b.id) from #__eb_registrants as a left join #__eb_events as b on b.id=a.event_id where a.first_name='".$first_name."' and a.last_name='".$last_name."'
		and b.published=1 and (a.user_id is null or a.user_id=0) and date(b.event_date) >= DATE_SUB(CURDATE(), INTERVAL 1 YEAR) and date(b.event_date) <= CURRENT_DATE() and a.is_group_billing=0 and a.published =1 
		and date(b.event_date) >= (select ifnull(max(reject_date),date(b.event_date)) from jos_membership as c where c.email=a.first_name='".$first_name."' and a.last_name='".$last_name."' and c.status=2)
		and not exists (select 1 from jos_eb_event_categories as d where d.event_id=b.id and d.category_id = 17)";
            $db->setQuery($sql) ;
            $num_walks = $db->loadResult();
    
			$sql = "select count(distinct b.id) from #__eb_registrants as a left join #__eb_events as b on b.id=a.event_id where a.first_name='".$first_name."' and a.last_name='".$last_name."'
		and b.published=1 and (a.user_id is null or a.user_id=0) and date(b.event_date) >= DATE_SUB(CURDATE(), INTERVAL 1 YEAR) and date(b.event_date) <= CURRENT_DATE() and a.is_group_billing=0 and a.published in (3,4,5) 
		and date(b.event_date) >= (select ifnull(max(reject_date),date(b.event_date)) from jos_membership as c where c.email=a.first_name='".$first_name."' and a.last_name='".$last_name."' and c.status=2)
		and not exists (select 1 from jos_eb_event_categories as d where d.event_id=b.id and d.category_id = 17)";
            $db->setQuery($sql) ;
            $num_pending_walks = $db->loadResult();
		}
        
        $content=$content."<p>They now have ".$num_walks." approved registrations, and ".$num_pending_walks." pending registrations.</p><p>Regards,</p>MBWC Activity Convenor";

        if (strpos(strtolower($title),"test")===false)
        {
            $recipients = array( 'info@mbwc.org.au' );
        }
        else
        {
            $outputstr=json_encode($user);
            Log::add('test info mail going to '.$outputstr, Log::ERROR, 'com_mbwc');
            $recipients=$user->email;
        }

        MBWCHelper::sendMail($recipients, "Visitor notification for event ".$title, $content, 1);
    }
	public static function isSuperUser()
	{
		$user = Factory::getUser();
		$userId = $user->get('id');
		$db = Factory::getDbo();
		$sql = "select 1 from jos_user_usergroup_map where (group_id = 8) and user_id = " .$userId;
		$db->setQuery($sql);
		return $db->loadResult();
	}
	public static function isSecretary()
	{
		$user = Factory::getUser();
		$userId = $user->get('id');
		$db = Factory::getDbo();
		$sql = "select 1 from jos_user_usergroup_map where (group_id = 47 or group_id = 8) and user_id = " .$userId;
		$db->setQuery($sql);
		return $db->loadResult();
	}
	public static function isEventCoordinator()
	{
		$user = Factory::getUser();
		$userId = $user->get('id');
		$db = Factory::getDbo();
		$sql = "select 1 from jos_user_usergroup_map where (group_id = 25 or group_id = 8 or group_id=79) and user_id = " .$userId;
		$db->setQuery($sql);
		return $db->loadResult();
	}
	public static function isLeader($eventId)
	{
		$user = Factory::getUser();
		$userId = $user->get('id');
		$db = Factory::getDbo();
		if (!$eventId)
        {
            return false;
        }
		$sql = "SELECT created_by, JSON_UNQUOTE(json_extract(custom_fields,'$.field_leader_id1')) as leader_id1, JSON_UNQUOTE(json_extract(custom_fields,'$.field_leader_id2')) as leader_id2, JSON_UNQUOTE(json_extract(custom_fields,'$.field_leader_id3')) as leader_id3 FROM #__eb_events WHERE id=" . $eventId;
		$db->setQuery($sql);
		$rowEvent = $db->loadObject();
		if (!$rowEvent)
        {
            return false;
        }
        if ($user->get('guest'))
        {
            return false;
        }
        if ($rowEvent->created_by == $userId || $rowEvent->leader_id1 == $userId || $rowEvent->leader_id2 == $userId || $rowEvent->leader_id3 == $userId)
        {
            return true;
        }
        else
        {
            return false;
        }
	}
	public static function loadCommonLayout($layout, $data = array())
	{
		$app = Factory::getApplication();
		$themeFile = str_replace('/tmpl', '', $layout);
 		$path = JPATH_ROOT . '/components/com_mbwc/tmpl/common/' . $layout;
		// Start an output buffer.
		ob_start();
		extract($data);
		// Load the layout.
		include $path;
		// Get the layout contents.
		$output = ob_get_clean();
		
		return $output;
	}
	
	public static function isMobile(){
	    $browser = Browser::getInstance();
    	return $browser->isMobile();
    }
    public static function validateDate($date, $format = 'Y-m-d')
    {
        $d = DateTime::createFromFormat($format, $date);
        return $d && $d->format($format) === $date;
    }
	public static function sendMail($toEmail, $subject, $content, $mode, $cc=null, $bcc=null, $attachment=null, $replyEmail=null, $replyName=null)
	{
	    $mailer = Factory::getMailer();
	    $mailer->SMTPDebug = 4;
    	$mailer->isHTML(true);
    	$mailer->Encoding = 'base64';
        // convert everything to arrays
        if ($toEmail && !is_array($toEmail))
        {
            $toEmail=explode(",",$toEmail);
        }
         // array_filter will filter out empty strings
        $toEmail = array_map('trim', $toEmail);
        $toEmail = array_unique(array_filter($toEmail));
         // convert everything to arrays
        if ($cc && !is_array($cc))
        {
            $cc=explode(",",$cc);
        }
        if ($cc)
        {
            $cc = array_map('trim', $cc);
            $cc = array_unique(array_filter($cc));
        }
        // convert everything to arrays
        if ($bcc && !is_array($bcc))
        {
            $bcc=explode(",",$bcc);
        }
        if ($bcc)
        {
            $bcc = array_map('trim', $bcc);
            $bcc = array_unique(array_filter($bcc));
        }
        // Strip out from $cc and $bcc
        if ($cc)
        {
            $cc = MBWCHelper::arrayDiffEmulation( $cc, $toEmail );
            if ($bcc)
            {
                $cc = MBWCHelper::arrayDiffEmulation( $cc, $bcc );
            }
        }
        if ($bcc)
        {
            $bcc = MBWCHelper::arrayDiffEmulation( $bcc, $toEmail );
            if ($cc)
            {
                $bcc = MBWCHelper::arrayDiffEmulation( $bcc, $cc );
            }
        }
        $config   = Factory::getConfig();
        $debug = $config->get('debug', false);
		$config = \EventbookingHelper::getConfig() ;
		$app = Factory::getApplication();
	    if ($config->from_name)
		{
			$fromName = $config->from_name;
		}			
		else
		{
            $fromName = $app->getCfg('from_name');
		}			
		if ($config->from_email)
		{
			$fromEmail = $config->from_email;
		}			
		else
		{
            $fromEmail = $app->getCfg('mailfrom');
		}
        if (strpos(strtolower($subject),"test")!==false || $debug || strpos($fromName,"DEV")!==false)
        {
	    	$user = Factory::getUser();
	    	if (!$user || !$user->email)
	    	{
	    	    $email='webadmin@mbwc.org.au';
	    	}
	    	else
	    	{
	    	    $email=$user->email;
	    	}
            $c = "Email redirected to ".$email."<br>";
            $c = $c . "to: ". print_r($toEmail, true)."<br>";
            $c = $c . "cc: ". print_r($cc, true)."<br>";
            $c = $c . "bcc: ". print_r($bcc, true)."<br>";
            $c = $c . $content;
            $content=$c;
	    	$toEmail=array();
            $toEmail[]=$email;
            $cc=null;
            $bcc=null;
        }

        if (!$replyEmail) 
        {
            $replyName=null;
        }
		if ($replyEmail)
		{
		    $content .= "<p><b>Note:</b> The reply-to on this email has been set to ".$replyEmail.". Please don't reply to walks@mbwc.org.au</p>";
		}
        try
        {
                $ret=$mailer->sendMail($fromEmail, $fromName, $toEmail, $subject, $content, $mode, $cc, $bcc, $attachment, $replyEmail, $replyName);
        }
        catch (\Exception $e)
        {
            $mailer->ClearAllRecipients();
    	    $mailer->clearAttachments();
	        $newContent="From_Mail: ".$fromEmail." From_Name: ".$fromName." To_: ".print_r($toEmail, true)." Subject: ".$subject." cc_: ".print_r($cc, true)." bcc_: ".print_r($bcc, true). " Reply_Mail: ".$replyEmail." Reply_Name: ".$replyName . " Ret: ".$ret." Content: ".$content;
            Log::add('Error Sending Mail: '.$newContent. "ret: ".$e->getMessage(), Log::ERROR, 'com_eventbooking');
	        $mailer->sendMail("webadmin@mbwc.org.au", "WebAdmin", "webadmin@mbwc.org.au", "Mail Error", $newContent, 1);
        }
        $mailer->ClearReplyTos();
        $mailer->ClearAllRecipients();
	    $mailer->clearAttachments();
	    return $ret;
    }
    public static function arrayDiffEmulation($arrayFrom, $arrayAgainst)
    {
        $arrayAgainst = array_flip($arrayAgainst);
       
        foreach ($arrayFrom as $key => $value) {
            if(isset($arrayAgainst[trim($value)])) {
                unset($arrayFrom[$key]);
            }
        }
       
        return $arrayFrom;
    }
    public static function getBrowser()
    {
        $user_agent = $_SERVER['HTTP_USER_AGENT'];
        $browser = "N/A";
    
        $browsers = [
            '/msie/i' => 'IE',
            '/firefox/i' => 'Firefox',
            '/safari/i' => 'Safari',
            '/chrome/i' => 'Chrome',
            '/edge/i' => 'Edge',
            '/opera/i' => 'Opera',
            '/mobile/i' => 'Mobile browser',
        ];
    
        foreach ($browsers as $regex => $value) {
            if (preg_match($regex, $user_agent)) {
                $browser = $value;
            }
        }
    
        return $browser;
    }
	public static function getFiles($pk, $table, $field)
	{
		$db = Factory::getContainer()->get('DatabaseDriver');
		$query = $db->getQuery(true);

		$query
			->select($field)
			->from($table)
			->where('id = ' . (int) $pk);

		$db->setQuery($query);

		return explode(',', $db->loadResult());
	}

	/**
	 * Gets the edit permission for an user
	 *
	 * @param   mixed  $item  The item
	 *
	 * @return  bool
	 */
	public static function canUserEdit($item)
	{
		$permission = false;
		$user       = Factory::getApplication()->getIdentity();

		if ($user->authorise('core.edit', 'com_mbwc') || (isset($item->created_by) && $user->authorise('core.edit.own', 'com_mbwc') && $item->created_by == $user->id) || $user->authorise('core.create', 'com_mbwc'))
		{
			$permission = true;
		}

		return $permission;
	}
	public static function manageTraineeTripLeaders()
	{
		$user = Factory::getUser();
		$userId = $user->get('id');
		$db = Factory::getDbo();
		$sql = "select 1 from jos_user_usergroup_map where (group_id = 79 or group_id = 8 or group_id=47 or group_id=83) and user_id = " .$userId;
		$db->setQuery($sql);
		return $db->loadResult();
	}
	
	public static function getLeaderPhone($eventId)
	{
		$db = Factory::getDbo();
	   	$sql = "select custom_fields from jos_eb_events where id =".$eventId;
    	$db->setQuery($sql);
		$custom_fields = $db->loadResult();
        $fieldextras = new Registry($custom_fields);
        
		$sql = "select concat(b.cb_mobphone,' (',a.name,')' ) as leader_ph from jos_users a, jos_comprofiler b where a.id=".$fieldextras->get('field_leader_id1')." and b.user_id=a.id";
   	    $db->setQuery($sql);
		$leaderPh = $db->loadResult();
		return $leaderPh;
	}

	public static function getLeaderEmail($eventId)
	{
	    // add event owner
		$db = Factory::getDbo(); 
		$sql = "select concat_ws(',',
		(select email from jos_users as a where a.id=JSON_UNQUOTE(JSON_EXTRACT(b.custom_fields,'$.field_leader_id1'))),
		(select email from jos_users as a where a.id=JSON_UNQUOTE(JSON_EXTRACT(b.custom_fields,'$.field_leader_id2'))),
		(select email from jos_users as a where a.id=JSON_UNQUOTE(JSON_EXTRACT(b.custom_fields,'$.field_leader_id3')))) from jos_eb_events as b where b.id=".$eventId;
    	$db->setQuery($sql);
    	$emails=$db->loadResult();
    	
    	// now remove duplicates
        $emailsArray=explode(",",$emails);
        // array_filter will filter out empty strings
        $emailsArray = array_map('trim', $emailsArray);
        $emailsArray = array_unique(array_filter($emailsArray));
        $emails=implode(",",$emailsArray);
        $emails = str_replace(' ', '', $emails);

	    return $emails;
	}
	
	public static function getLeaderName($eventId)
	{
		$db = Factory::getDbo();
		$sql = "select concat_ws(',',
		(select name from jos_users as a where a.id=JSON_UNQUOTE(JSON_EXTRACT(b.custom_fields,'$.field_leader_id1'))),
		(select name from jos_users as a where a.id=JSON_UNQUOTE(JSON_EXTRACT(b.custom_fields,'$.field_leader_id2'))),
		(select name from jos_users as a where a.id=JSON_UNQUOTE(JSON_EXTRACT(b.custom_fields,'$.field_leader_id3')))) from jos_eb_events as b where b.id=".$eventId;
    	$db->setQuery($sql);
	    return $db->loadResult();
	}
	public static function getRegistrantEmail($row)
	{
		$db = Factory::getDbo(); 
	    $email=$row->email;
	    if ($row->user_id)
	    {
    		$sql = "select email from jos_users where id=".$row->user_id;
    		$db->setQuery($sql); 
    		$email = $db->loadResult();
	    } 
	    return $email;
	}
}
?>
