<?php
namespace MBWC\Component\MBWC\Site\Helper;

use Joomla\CMS\Factory;
use \Joomla\CMS\MVC\Model\BaseDatabaseModel;
require_once JPATH_ADMINISTRATOR . '/components/com_eventbooking/libraries/rad/bootstrap.php';
use DateTime;
use Joomla\CMS\Log\Log;
use Joomla\Registry\Registry;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Environment\Browser;
use Joomla\CMS\Mail\MailHelper;
use Joomla\CMS\Application\ApplicationHelper;
use Joomla\CMS\Component\ComponentHelper;
use Joomla\CMS\Language\Multilanguage;
use Joomla\CMS\Menu\MenuItem;

class MBWCRouteHelper
{
	protected static $lookup;
	protected static $categories;
	protected static $items;

	/**
	 * Get IDs of all categories in category tree from the given category to root
	 *
	 * @param   int  $id
	 * @param   int  $parentId
	 *
	 * @retrun []
	 */
	protected static function getCategoryIdsTree($id, $parentId = 0)
	{
		self::buildCategories();

		$catIds = [];

		do
		{
			if (isset(self::$categories[$id]))
			{
				$catIds[] = self::$categories[$id]->id;
				$id       = self::$categories[$id]->parent;
			}
			else
			{
				break;
			}
		} while ($id != $parentId);

		return $catIds;
	}

	/**
	 * Build categories data
	 *
	 * @return void
	 */
	protected static function buildCategories()
	{
		if (self::$categories === null)
		{
			$db    = Factory::getDbo();
			$query = $db->getQuery(true)
				->select('id, parent, alias')->from('#__eb_categories');

			if (Multilanguage::isEnabled())
			{
				$languages = EventbookingHelper::getLanguages();

				foreach ($languages as $language)
				{
					$query->select($db->quoteName('alias_' . $language->sef));
				}
			}

			$db->setQuery($query);

			self::$categories = $db->loadObjectList('id');
		}
	}
	public static function getEventRoute($id, $catId = 0, $itemId = 0, $language = null)
	{
		$id      = (int) $id;
		$needles = ['event' => [$id]];
		$link    = 'index.php?option=com_eventbooking&view=event&id=' . $id;
 
		if (!$catId)
		{
			//Find the main category of this event
			$db    = Factory::getDbo();
			$query = $db->getQuery(true)
				->select('main_category_id')
				->from('#__eb_events')
				->where('id = ' . $id);
			$db->setQuery($query);
			$catId = (int) $db->loadResult();
		}

		if ($catId)
		{
			$needles['category']       = self::getCategoryIdsTree($catId);
			$needles['upcomingevents'] = $needles['calendar'] = $needles['fullcalendar'] = $needles['categories'] = $needles['category'];
			$link                      .= '&catid=' . $catId;
 		}

		if ($language)
		{
			$needles['language'] = $language;
			$link                .= '&lang=' . $language;
		}
		elseif (Multilanguage::isEnabled())
		{
			$needles['language'] = Factory::getLanguage()->getTag();
		}

		if ($item = self::findItem($needles, $itemId))
		{
			$link .= '&Itemid=' . $item;
		}

		return $link;
	}
    	/**
	 * Find menu item which matches needles array
	 *
	 * @param   array  $needles
	 * @param   int    $itemId
	 *
	 * @return int|mixed
	 */
	public static function findItem($needles = [], $itemId = 0)
	{
		$language = $needles['language'] ?? '*';

		self::buildLookup($language);

		foreach ($needles as $view => $ids)
		{
			if (isset(self::$lookup[$language][$view]))
			{
				foreach ($ids as $id)
				{
					$id = (int) $id;

					if (isset(self::$lookup[$language][$view][(int) $id]))
					{
						return self::$lookup[$language][$view][(int) $id];
					}
				}
			}
		}

		//Return default item id
		return $itemId;
	}

	/**
	 * Build and cache the lookup array
	 *
	 * @param $language
	 */
	protected static function buildLookup($language = '*')
	{
		// Prepare the reverse lookup array.
		if (!isset(self::$lookup[$language]))
		{
			self::$lookup[$language] = [];

			$items = self::getMenuItems($language);

			foreach ($items as $item)
			{
				if (!empty($item->query['view']))
				{
					$view = $item->query['view'];

					// Ignore that export for routing
					if ($view == 'registrants' && !empty($item->query['layout']) && $item->query['layout'] == 'export')
					{
						continue;
					}

					if ($view === 'category' && $item->getParams()->get('display_events_type') == '3')
					{
						continue;
					}

					if (!isset(self::$lookup[$language][$view]))
					{
						self::$lookup[$language][$view] = [];
					}

					if (isset($item->query['id']))
					{
						self::$lookup[$language][$view][$item->query['id']] = $item->id;
					}
					else
					{
						self::$lookup[$language][$view][0] = $item->id;
					}
				}
			}
		}
	}

	/**
	 * Get component menu items for given language
	 *
	 * @param   string  $language
	 *
	 * @return MenuItem[]
	 */
	protected static function getMenuItems($language = '*')
	{
		if (!isset(self::$items[$language]))
		{
			$component  = ComponentHelper::getComponent('com_mbwc');
			$attributes = ['component_id'];
			$values     = [$component->id];

			if ($language != '*')
			{
				$attributes[] = 'language';
				$values[]     = [$language, '*'];
			}

			self::$items[$language] = Factory::getApplication()->getMenu('site')->getItems($attributes, $values);
		}

		return self::$items[$language];
	}
}
?>