<?php
/**
 * @version    CVS: 1.0.0
 * @package    Com_Mbwc
 * @author     Jeff Dun <jvevfvf+cc@gmail.com>
 * @copyright  2023 Jeff Dun
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace Mbwc\Component\Mbwc\Site\Model;
// No direct access.
defined('_JEXEC') or die;

use \Joomla\CMS\Factory;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\MVC\Model\ListModel;
use \Joomla\Component\Fields\Administrator\Helper\FieldsHelper;
use \Joomla\CMS\Helper\TagsHelper;
use \Joomla\CMS\Layout\FileLayout;
use \Joomla\Database\ParameterType;
use \Joomla\Utilities\ArrayHelper;
use MBWC\Component\MBWC\Site\Helper\MBWCHelper;


/**
 * Methods supporting a list of Mbwc records.
 *
 * @since  1.0.0
 */
class IncidentreportsModel extends ListModel
{
	/**
	 * Constructor.
	 *
	 * @param   array  $config  An optional associative array of configuration settings.
	 *
	 * @see    JController
	 * @since  1.0.0
	 */
	public function __construct($config = array())
	{
		if (empty($config['filter_fields']))
		{
			$config['filter_fields'] = array(
				'id', 'a.id',
				'event_id', 'a.event_id',
				'name', 'a.name',
				'person_phone', 'a.person_phone',
				'person_email', 'a.person_email',
				'address', 'a.address',
				'date', 'a.date',
				'leader_name', 'a.leader_name',
				'leader_phone', 'a.leader_phone',
				'location', 'a.location',
				'conditions', 'a.conditions',
				'what', 'a.what',
				'where_happened', 'a.where_happened',
				'injury', 'a.injury',
			);
		}

		parent::__construct($config);
	}

	

	/**
	 * Method to auto-populate the model state.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @param   string  $ordering   Elements order
	 * @param   string  $direction  Order direction
	 *
	 * @return  void
	 *
	 * @throws  Exception
	 *
	 * @since   1.0.0
	 */
	protected function populateState($ordering = null, $direction = null)
	{
		// List state information.
		parent::populateState("a.id", "ASC");

		$app = Factory::getApplication();
		$list = $app->getUserState($this->context . '.list');

		$value = $app->getUserState($this->context . '.list.limit', $app->get('list_limit', 25));
		$list['limit'] = $value;
		
		$this->setState('list.limit', $value);

		$value = $app->input->get('limitstart', 0, 'uint');
		$this->setState('list.start', $value);

		$ordering  = $this->getUserStateFromRequest($this->context .'.filter_order', 'filter_order', "a.id");
		$direction = strtoupper($this->getUserStateFromRequest($this->context .'.filter_order_Dir', 'filter_order_Dir', "ASC"));
		
		if(!empty($ordering) || !empty($direction))
		{
			$list['fullordering'] = $ordering . ' ' . $direction;
		}

		$app->setUserState($this->context . '.list', $list);

        $authorId = $app->getUserStateFromRequest($this->context . 'filter_event', 'filter_event');
        $this->setState('filter_event', $authorId);
        $authorId = $app->getUserStateFromRequest($this->context . 'filter_leader', 'filter_leader');
        $this->setState('filter_leader', $authorId);
		
		// Split context into component and optional section
		if (!empty($context))
		{
			$parts = FieldsHelper::extract($context);

			if ($parts)
			{
				$this->setState('filter.component', $parts[0]);
				$this->setState('filter.section', $parts[1]);
			}
		}
	}

	/**
	 * Build an SQL query to load the list data.
	 *
	 * @return  DatabaseQuery
	 *
	 * @since   1.0.0
	 */
	protected function getListQuery()
	{
			// Create a new query object.
			$db    = $this->getDbo();
			$query = $db->getQuery(true);

			// Select the required fields from the table.
			$query->select(
						$this->getState(
								'list.select', 'DISTINCT a.*'
						)
				);

			$query->from('`#__mbwc_incident` AS a');

			$search = $this->getState('filter_event');

			if (!empty($search))
			{
					$query->where('a.event_id = ' . $db->quote($search));
			}
			
			$search = $this->getState('filter_leader');

			if (!empty($search))
			{
					$query->where('a.leader_name = ' . $db->quote($search));
			}

			// Add the list ordering clause.
			$orderCol  = $this->state->get('list.ordering', "a.id");
			$orderDirn = $this->state->get('list.direction', "ASC");

			if ($orderCol && $orderDirn)
			{
				$query->order($db->escape($orderCol . ' ' . $orderDirn));
			}

			return $query;
	}

	/**
	 * Method to get an array of data items
	 *
	 * @return  mixed An array of data on success, false on failure.
	 */
	public function getItems()
	{
		$items = parent::getItems();
		

		return $items;
	}
	
}
