<?php
/**
 * @version    CVS: 1.0.0
 * @package    Com_Mbwc
 * @author     Jeff Dun <jvevfvf+cc@gmail.com>
 * @copyright  2023 Jeff Dun
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace Mbwc\Component\Mbwc\Site\Model;
// No direct access.
defined('_JEXEC') or die;

use \Joomla\CMS\Factory;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\MVC\Model\ListModel;
use \Joomla\Component\Fields\Administrator\Helper\FieldsHelper;
use \Joomla\CMS\Helper\TagsHelper;
use \Joomla\CMS\Layout\FileLayout;
use \Joomla\Database\ParameterType;
use \Joomla\Utilities\ArrayHelper;
use \Mbwc\Component\Mbwc\Site\Helper\MbwcHelper;


/**
 * Methods supporting a list of Mbwc records.
 *
 * @since  1.0.0
 */
class LeaderswalksModel extends ListModel
{
	/**
	 * Constructor.
	 *
	 * @param   array  $config  An optional associative array of configuration settings.
	 *
	 * @see    JController
	 * @since  1.0.0
	 */
	public function __construct($config = array())
	{
		if (empty($config['filter_fields']))
		{
			$config['filter_fields'] = array(
				'id', 'a.id',
				'event_id', 'a.event_id',
				'name', 'a.name',
				'person_phone', 'a.person_phone',
				'person_email', 'a.person_email',
				'address', 'a.address',
				'date', 'a.date',
				'leader_name', 'a.leader_name',
				'leader_phone', 'a.leader_phone',
				'location', 'a.location',
				'conditions', 'a.conditions',
				'what', 'a.what',
				'where_happened', 'a.where_happened',
				'injury', 'a.injury',
			);
		}

		parent::__construct($config);
	}

	

	/**
	 * Method to auto-populate the model state.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @param   string  $ordering   Elements order
	 * @param   string  $direction  Order direction
	 *
	 * @return  void
	 *
	 * @throws  Exception
	 *
	 * @since   1.0.0
	 */
	protected function populateState($ordering = null, $direction = null)
	{
		// List state information.
		parent::populateState("a.id", "ASC");

		$app = Factory::getApplication();
		$list = $app->getUserState($this->context . '.list');

		$value = $app->getUserState($this->context . '.list.limit', $app->get('list_limit', 25));

		$this->setState('list.limit', $value);

		$value = $app->input->get('limitstart', 0, 'uint');
		$this->setState('list.start', $value);

		$ordering  = $this->getUserStateFromRequest($this->context .'.filter_order', 'filter_order', "a.id");
		$direction = strtoupper($this->getUserStateFromRequest($this->context .'.filter_order_Dir', 'filter_order_Dir', "ASC"));

		if(!empty($ordering) || !empty($direction))
		{
			$listFull = $ordering . ' ' . $direction;
		    $this->setState('list.fullordering', $listFull);
		}

        $authorId = $app->getUserStateFromRequest($this->context . 'filter_name', 'filter_name');
        $this->setState('filter_name', $authorId);
		
		// Split context into component and optional section
		if (!empty($context))
		{
			$parts = FieldsHelper::extract($context);

			if ($parts)
			{
				$this->setState('filter.component', $parts[0]);
				$this->setState('filter.section', $parts[1]);
			}
		}
	}

	/**
	 * Build an SQL query to load the list data.
	 *
	 * @return  DatabaseQuery
	 *
	 * @since   1.0.0
	 */
	protected function getListQuery()
	{
			// Create a new query object.
			$db    = $this->getDbo();
			$query = $db->getQuery(true);

			// Select the required fields from the table.
			$query->select(
						"concat(a.firstname,' ',a.lastname) as name, a.*, b.num_walks, (select count(*) from jos_eb_events as c where c.event_date > '2023-01-01' and c.event_date <= now() and c.published=1 
    		and (json_unquote(json_extract(c.custom_fields,'$.field_leader_id1'))=a.user_id or json_unquote(json_extract(c.custom_fields,'$.field_leader_id2'))=a.user_id or json_unquote(json_extract(c.custom_fields,'$.field_leader_id3'))=a.user_id) and 
    		exists (select 1 from jos_mbwc_tripreports where event_id=c.id) and exists (select 1 from jos_eb_event_categories as d join jos_eb_categories as e on d.category_id=e.id join jos_mbwc_categoryextras as h on e.id=h.category_id 
    		where d.event_id=c.id and h.counts_as_trip=1)) as num_new_walks,
    		(select count(*) from jos_eb_events as c where c.event_date > '2022-01-01' and c.event_date <= '2022-12-31' and c.published=1 
    		and (json_unquote(json_extract(c.custom_fields,'$.field_leader_id1'))=a.user_id or json_unquote(json_extract(c.custom_fields,'$.field_leader_id2'))=a.user_id or json_unquote(json_extract(c.custom_fields,'$.field_leader_id3'))=a.user_id) 
    		and exists (select 1 from jos_mbwc_tripreports where event_id=c.id) and exists (select 1 from jos_eb_event_categories as d join jos_eb_categories as e on d.category_id=e.id join jos_mbwc_categoryextras as h on e.id=h.category_id 
    		where d.event_id=c.id and h.counts_as_trip=1)) as num_twentytwo,
    		b.num_walks+(select count(*) from jos_eb_events as c where c.event_date > '2022-01-01' and c.event_date <= now() and c.published=1 and (json_unquote(json_extract(c.custom_fields,'$.field_leader_id1'))=a.user_id or 
    		json_unquote(json_extract(c.custom_fields,'$.field_leader_id2'))=a.user_id or json_unquote(json_extract(c.custom_fields,'$.field_leader_id3'))=a.user_id) 
    		and exists (select 1 from jos_mbwc_tripreports where event_id=c.id) and exists (select 1 from jos_eb_event_categories as d join jos_eb_categories as e on d.category_id=e.id 
    		join jos_mbwc_categoryextras as h on e.id=h.category_id where d.event_id=c.id and h.counts_as_trip=1)) as total_walks "
				);

		    $query->from('#__comprofiler AS a')->join('','jos_mbwc_leader_walks as b on a.user_id=b.user_id');

			$search = $this->getState('filter_name');

			if (!empty($search))
			{
					$query->where('concat(a.firstname," ",a.lastname) = ' . $db->quote($search));
			}
			else
			{
			    $query->where('a.cb_trip_leader_all="Yes" and a.cb_status="Current"');
			}

			// Add the list ordering clause.
			$orderCol  = $this->getState('list.fullordering');

			if ($orderCol)
			{
				$query->order($db->escape($orderCol));
			}

			return $query;
	}
	public function getAllItems()
	{
		$app = Factory::getApplication();
		$app->setUserState($this->context . '.list.limit', 0);
		$app->setUserState($this->context . '.filter_name', 0);

		$items = parent::getItems();
		

		return $items;
	}

	/**
	 * Method to get an array of data items
	 *
	 * @return  mixed An array of data on success, false on failure.
	 */
	public function getItems()
	{
		$items = parent::getItems();
		

		return $items;
	}
	
}
