<?php
/**
 * @version    CVS: 1.0.0
 * @package    Com_Mbwc
 * @author     Jeff Dun <jvevfvf+cc@gmail.com>
 * @copyright  2023 Jeff Dun
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace Mbwc\Component\Mbwc\Site\Model;
// No direct access.
defined('_JEXEC') or die;

use \Joomla\CMS\Factory;
use \Joomla\Utilities\ArrayHelper;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\Table\Table;
use \Joomla\CMS\MVC\Model\ItemModel;
use \Joomla\CMS\Object\CMSObject;
use \Joomla\CMS\Helper\TagsHelper;

/**
 * Mbwc model.
 *
 * @since  1.0.0
 */
class MembershipModel extends ItemModel
{
	private $item = null;

	

	

	/**
	 * Method to auto-populate the model state.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @return  void
	 *
	 * @since   1.0.0
	 *
	 * @throws  Exception
	 */
	protected function populateState()
	{
		$app = Factory::getApplication('com_mbwc');

		// Load state from the request userState on edit or from the passed variable on default
		if (Factory::getApplication()->input->get('layout') == 'edit')
		{
			$id = Factory::getApplication()->getUserState('com_mbwc.edit.membership.id');
		}
		else
		{
			$id = Factory::getApplication()->input->get('id');
			Factory::getApplication()->setUserState('com_mbwc.edit.membership.id', $id);
		}

		$this->setState('membership.id', $id);

		// Load the parameters.
		$params       = $app->getParams();
		$params_array = $params->toArray();

		if (isset($params_array['item_id']))
		{
				$this->setState('membership.id', $params_array['item_id']);
		}

		$this->setState('params', $params);
	}

	/**
	 * Method to get an ojbect.
	 *
	 * @param   integer $id The id of the object to get.
	 *
	 * @return  Object|boolean Object on success, false on failure.
	 *
	 * @throws  Exception
	 */
	public function getItem($id = null)
	{
		if ($this->item === null)
		{
			$this->item = false;

			if (empty($id))
			{
				$id = $this->getState('membership.id');
			}

			// Get a level row instance.
			$table = $this->getTable();
			$properties = $table->getProperties();
			$this->item = ArrayHelper::toObject($properties, CMSObject::class);

			if ($table !== false && $table->load($id) && !empty($table->id))
			{
				$user = Factory::getApplication()->getIdentity();
				$id   = $table->id;
				
				// Check published state.
				if ($published = $this->getState('filter.published'))
				{
					if (isset($table->state) && $table->state != $published)
					{
						return $this->item;
					}
				}

				// Convert the Table to a clean CMSObject.
				$properties = $table->getProperties(1);
				$this->item = ArrayHelper::toObject($properties, CMSObject::class);
				

				
			}
		}

		return $this->item;
	}

	/**
	 * Method to get the table
	 *
	 * @param   string $type   Name of the Table class
	 * @param   string $prefix Optional prefix for the table class name
	 * @param   array  $config Optional configuration array for Table object
	 *
	 * @return  Table|boolean Table if found, boolean false on failure
	 */
	public function getTable($type = 'Membership', $prefix = 'Administrator', $config = array())
	{
		return parent::getTable($type, $prefix, $config);
	}


	/**
	 * Method to save the form data.
	 *
	 * @param   array $data The form data
	 *
	 * @return  bool
	 *
	 * @throws  Exception
	 * @since   1.0.0
	 */
	public function save($data)
	{
		$id    = (!empty($data['id'])) ? $data['id'] : (int) $this->getState('membership.id');
		$state = (!empty($data['state'])) ? 1 : 0;
		$user  = Factory::getApplication()->getIdentity();

		
		$table = $this->getTable();

		if(!empty($id))
		{
			$table->load($id);
		}

	    try{
			if ($table->save($data) === true)
			{
				return $table->id;
			}
			else
			{
				Factory::getApplication()->enqueueMessage($table->getError(), 'error');
				return false;
			}
		}catch(\Exception $e)
		{
			Factory::getApplication()->enqueueMessage($e->getMessage(), 'error');
			return false;
		}
			
	}

	/**
	 * Method to delete data
	 *
	 * @param   int $pk Item primary key
	 *
	 * @return  int  The id of the deleted item
	 *
	 * @throws  Exception
	 *
	 * @since   1.0.0
	 */
	public function delete($id)
	{
		$user = Factory::getApplication()->getIdentity();

		
		if (empty($id))
		{
			$id = (int) $this->getState('membership.id');
		}

		if ($id == 0 || $this->getItem($id) == null)
		{
				throw new \Exception(Text::_('COM_MBWC_ITEM_DOESNT_EXIST'), 404);
		}

		if ($user->authorise('core.delete', 'com_mbwc') !== true)
		{
				throw new \Exception(Text::_('JERROR_ALERTNOAUTHOR'), 403);
		}

		$table = $this->getTable();

		if ($table->delete($id) !== true)
		{
				throw new \Exception(Text::_('JERROR_FAILED'), 501);
		}

		return $id;
		
	}

	/**
	 * Check if data can be saved
	 *
	 * @return bool
	 */
	public function getCanSave()
	{
		$table = $this->getTable();

		return $table !== false;
	}


	function reject_membership($id, $reason)
	{
		if (!$id)
			return false;
		$db = Factory::getDbo();
		$sql = 'update #__mbwc_membership set status=2, reject_date=NOW(), reject_reason="' . str_replace("'", "\'", $reason) . '" where id='.$id;
		$db->setQuery($sql);
		if (!$db->execute())
			return false;
	    return true ;
	}
	function defer($id, $reason)
	{
		if (!$id)
			return false;
		$db = Factory::getDbo();
		$sql = 'update #__mbwc_membership set status=1, defer_date=NOW(), defer_reason="' . str_replace("'", "\'", $reason) . '" where id='.$id;
		$db->setQuery($sql);
		if (!$db->execute())
			return false;
	    return true ;
	}
	function undefer($id, $reason)
	{
		if (!$id)
			return false;
		$db = Factory::getDbo();
		$sql = 'update #__mbwc_membership set status=0, defer_date=null, defer_reason="' . str_replace("'", "\'", $reason) . '" where id='.$id;
		$db->setQuery($sql);
		if (!$db->execute())
			return false;
	    return true ;
	}	
}
