<?php
/**
 * @version    CVS: 1.0.0
 * @package    Com_Mbwc
 * @author     Jeff Dun <jvevfvf+cc@gmail.com>
 * @copyright  2023 Jeff Dun
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace Mbwc\Component\Mbwc\Site\Model;
// No direct access.
defined('_JEXEC') or die;

use \Joomla\CMS\Factory;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\MVC\Model\ListModel;
use \Joomla\Component\Fields\Administrator\Helper\FieldsHelper;
use \Joomla\CMS\Helper\TagsHelper;
use \Joomla\CMS\Layout\FileLayout;
use \Joomla\Database\ParameterType;
use \Joomla\Utilities\ArrayHelper;
use \Mbwc\Component\Mbwc\Site\Helper\MbwcHelper;
use Joomla\CMS\Log\Log;


/**
 * Methods supporting a list of Mbwc records.
 *
 * @since  1.0.0
 */
class UpcomingeventsModel extends ListModel
{
	/**
	 * Constructor.
	 *
	 * @param   array  $config  An optional associative array of configuration settings.
	 *
	 * @see    JController
	 * @since  1.0.0
	 */
	public function __construct($config = array())
	{
		if (empty($config['filter_fields']))
		{
			$config['filter_fields'] = array(
				'id', 'a.id',
				'event_id', 'a.event_id',
				'name', 'a.name',
				'person_phone', 'a.person_phone',
				'person_email', 'a.person_email',
				'address', 'a.address',
				'date', 'a.date',
				'leader_name', 'a.leader_name',
				'leader_phone', 'a.leader_phone',
				'location', 'a.location',
				'conditions', 'a.conditions',
				'what', 'a.what',
				'where_happened', 'a.where_happened',
				'injury', 'a.injury',
			);
		}

		parent::__construct($config);
	}

	

	/**
	 * Method to auto-populate the model state.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @param   string  $ordering   Elements order
	 * @param   string  $direction  Order direction
	 *
	 * @return  void
	 *
	 * @throws  Exception
	 *
	 * @since   1.0.0
	 */
	protected function populateState($ordering = null, $direction = null)
	{
		// List state information.
		parent::populateState("a.id", "ASC");
		$app = Factory::getApplication();

        if ($app->getUserState('com_mbwc.upcomingevents.footnotes',0))
        {
		    $this->setState('list.limit', 0);
    		$this->setState('list.start', 0);
        }
        else
        {
    		$value = $app->getUserState('com_mbwc.upcomingevents.list.limit', $app->get('list_limit', 25));
    		$this->setState('list.limit', $value);

    		$value = $app->input->get('limitstart', 0, 'uint');
    		$this->setState('list.start', $value);
        }


		$list = $app->getUserState($this->context . '.list');

		$ordering  = $this->getUserStateFromRequest($this->context .'.filter_order', 'filter_order', "date(a.event_date) asc, published asc, main_category_ordering");
		$direction = strtoupper($this->getUserStateFromRequest($this->context .'.filter_order_Dir', 'filter_order_Dir', "ASC"));

		if(!empty($ordering) || !empty($direction))
		{
			$listFull = $ordering . ' ' . $direction;
		    $this->setState('list.fullordering', $listFull);
		}
 
		// Split context into component and optional section
		if (!empty($context))
		{
			$parts = FieldsHelper::extract($context);

			if ($parts)
			{
				$this->setState('filter.component', $parts[0]);
				$this->setState('filter.section', $parts[1]);
			}
		}
	}

	/**
	 * Build an SQL query to load the list data.
	 *
	 * @return  DatabaseQuery
	 *
	 * @since   1.0.0
	 */
	protected function getListQuery()
	{
			// Create a new query object.
			$db    = $this->getDbo();
			$query = $db->getQuery(true);
 		    $user = Factory::getUser() ;

			// Select the required fields from the table.
			$query->select(
						" a.*, concat_ws(',',
		(select name from jos_users as b where b.id=JSON_UNQUOTE(JSON_EXTRACT(a.custom_fields,'$.field_leader_id1'))),
		(select name from jos_users as b where b.id=JSON_UNQUOTE(JSON_EXTRACT(a.custom_fields,'$.field_leader_id2'))),
		(select name from jos_users as b where b.id=JSON_UNQUOTE(JSON_EXTRACT(a.custom_fields,'$.field_leader_id3')))) as leader_name, IFNULL(SUM(b.number_registrants), 0) AS total_registrants,
		(select ordering from jos_eb_categories as x where x.id=a.main_category_id) as main_category_ordering "
				);

		    $query->from('#__eb_events as a')->join('',' #__eb_registrants AS b ON (a.id = b.event_id AND b.group_id=0 AND (b.published = 1 OR b.published = 4))');
            $query->where("a.published>0");
            $query->where("a.registration_type!=3");
            if ($this->getState('past') === 1)
            {
                $query->where("DATE(a.event_date) <= CURDATE()");
                $query->where("DATE(a.event_date) > DATE_SUB(CURDATE(), INTERVAL 2 MONTH)");
            }
            else
            {
                $query->where("DATE(a.event_date) >= CURDATE()");
            }
            
            $query->where('a.id not IN (SELECT event_id FROM #__eb_event_categories WHERE category_id = 53 or category_id = 19) ');
            $query->where('a.main_category_id not in (53,19)');

			$where="";
            if (!$this->getState('filter_notme') && (($this->getState('filter_category') && $this->getState('filter_category') > 0) || $this->getState('filter_notfull') || ($this->getState('filter_leader') && $this->getState('filter_leader') != 'all') || ($this->getState('filter_day') && $this->getState('filter_day') != -1)))
            {
                $where = $where . " ((";
            }
            else if ($this->getState('filter_notme') || 
                 (($this->getState('filter_category') && $this->getState('filter_category') > 0) || 
                 $this->getState('filter_notfull') || 
                 ($this->getState('filter_leader') && $this->getState('filter_leader') != 'all') || 
                 ($this->getState('filter_day') && $this->getState('filter_day') != -1)))
            {
               $where = $where . "  ";
            }
            if ($this->getState('filter_day') && $this->getState('filter_day') != -1)
            {
                if ($this->getState('filter_day') == 8)
                {
                    $where = $where . '  DAYOFWEEK(DATE(a.event_date)) in (1,7)';
                }
                else
                {
                    $where = $where . '  DAYOFWEEK(DATE(a.event_date))=' . $this->getState('filter_day');
                }
                if (($this->getState('filter_leader') && $this->getState('filter_leader') != 'all') || $this->getState('filter_notfull') || $this->getState('filter_notme') || ($this->getState('filter_category') && $this->getState('filter_category') > 0))
                {
                  $where = $where . " and ";
                }
            }
            if ($this->getState('filter_leader') && $this->getState('filter_leader') != 'all')
            {
                $where = $where . " a.id in (select a.id from #__eb_events as a where concat_ws(',',
		(select name from jos_users as b where b.id=JSON_UNQUOTE(JSON_EXTRACT(a.custom_fields,'$.field_leader_id1'))),
		(select name from jos_users as b where b.id=JSON_UNQUOTE(JSON_EXTRACT(a.custom_fields,'$.field_leader_id2'))),
		(select name from jos_users as b where b.id=JSON_UNQUOTE(JSON_EXTRACT(a.custom_fields,'$.field_leader_id3')))) like '%" . str_replace("'", "\'", $this->getState('filter_leader')) ."%')";
                
                if ($this->getState('filter_notfull') || $this->getState('filter_notme') || ($this->getState('filter_category') && $this->getState('filter_category') > 0))
                {
                  $where = $where . " and ";
                }
             }
            if ($this->getState('filter_notfull'))
            {
               $where = $where . " a.published=1 and (a.event_capacity > (select IFNULL(SUM(d.number_registrants), 0) from #__eb_registrants d where d.group_id=0 AND (d.published = 1 or d.published=4) and d.event_id = a.id) and IFNULL(DATEDIFF(NOW(), a.cut_off_date),0) <= 0)";
                if ($this->getState('filter_notme') || ($this->getState('filter_category') && $this->getState('filter_category') > 0))
                {
                   $where = $where . " and ";
                }
            }
            if ($this->getState('filter_notme'))
            {
               $where = $where . " not exists (select 1 from #__eb_registrants d where d.is_group_billing=0 AND (d.published = 1 or d.published=4) and d.event_id = a.id and d.user_id=".$user->id.")";
                if (($this->getState('filter_category') && $this->getState('filter_category') > 0))
                {
                  $where = $where . " and ";
                }
            }
            if ($this->getState('filter_category'))
            {
                switch ($this->getState('filter_category')) {
                    case 1:
                        $where = $where . '  (a.id IN (SELECT event_id FROM #__eb_event_categories WHERE category_id=25))' ;
                        break;
                    case 2:
                        $where = $where . '  (a.id IN (SELECT event_id FROM #__eb_event_categories WHERE category_id in (27,28,29)))' ;
                        break;
                    case 3:
                        $where = $where . '  (a.id IN (SELECT event_id FROM #__eb_event_categories WHERE category_id in (39,40,41)))' ;
                        break;
                    case 4:
                        $where = $where . '  (a.id IN (SELECT event_id FROM #__eb_event_categories WHERE category_id in (36,37,38)))' ;
                        break;
                    case 5:
                        $where = $where . '  (a.id IN (SELECT event_id FROM #__eb_event_categories WHERE category_id in (31,32,33)))' ;
                        break;
                    case 6:
                        $where = $where . '  (a.id IN (SELECT event_id FROM #__eb_event_categories WHERE category_id=17))' ;
                        break;
                    case 7:
                        $where = $where . '  (a.id IN (SELECT event_id FROM #__eb_event_categories WHERE category_id=21))' ;
                        break;
                    case 8:
                        $where = $where . '  (a.id IN (SELECT event_id FROM #__eb_event_categories WHERE category_id=3))' ;
                        break;
                    case 9:
                        $where = $where . '  (a.id IN (SELECT event_id FROM #__eb_event_categories WHERE category_id=20))' ;
                        break;
                     case 10:
                        $where = $where . '  (a.id IN (SELECT event_id FROM #__eb_event_categories WHERE category_id=43))' ;
                        break;
                     case 11:
                        $where = $where . '  (a.id IN (SELECT event_id FROM #__eb_event_categories WHERE category_id in (36,37,38,31,32,33)))' ;
                        break;
               }
    
            }
            if (!$this->getState('filter_notme') && (($this->getState('filter_category') && $this->getState('filter_category') > 0) || $this->getState('filter_notfull') || ($this->getState('filter_leader') && $this->getState('filter_leader') != 'all') || ($this->getState('filter_day') && $this->getState('filter_day') != -1)))
            {
                $where = $where . ") ";
            }
            if (!$this->getState('filter_notme') && (($this->getState('filter_category') && $this->getState('filter_category') > 0) || $this->getState('filter_notfull') || ($this->getState('filter_leader') && $this->getState('filter_leader') != 'all') || ($this->getState('filter_day') && $this->getState('filter_day') != -1)))
            {
               $where = $where . " or exists (select 1 from #__eb_registrants d where d.is_group_billing=0 AND (d.published = 1 or d.published=4) and d.event_id = a.id and d.user_id=".$user->id."))";
            }
            if ($where)
            {
 			 $query->where($where);
            }
			
			// Add the list ordering clause.
			$orderCol  = $this->getState('list.fullordering');

			if ($orderCol)
			{
				$query->order($db->escape($orderCol));
			}
			$query->group("a.id");
           $outputstr=json_encode($query->__toString());
            echo "<script>console.log(".$outputstr.")</script>"; 

			return $query;
	}

	/**
	 * Method to get an array of data items
	 *
	 * @return  mixed An array of data on success, false on failure.
	 */
	public function getItems()
	{
		$items = parent::getItems();
		

		return $items;
	}
	
}
