<?php

/**
 * @version    CVS: 1.0.0
 * @package    Com_Mbwc
 * @author     Jeff Dun <jvevfvf+cc@gmail.com>
 * @copyright  2023 Jeff Dun
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */


// No direct access
defined('_JEXEC') or die;
namespace Mbwc\Component\Mbwc\Site\Service;

use Joomla\CMS\Component\Router\RouterViewConfiguration;
use Joomla\CMS\Component\Router\RouterView;
use Joomla\CMS\Component\Router\Rules\StandardRules;
use Joomla\CMS\Component\Router\Rules\NomenuRules;
use Joomla\CMS\Component\Router\Rules\MenuRules;
use Joomla\CMS\Factory;
use Joomla\CMS\Categories\Categories;
use Joomla\CMS\Application\SiteApplication;
use Joomla\CMS\Categories\CategoryFactoryInterface;
use Joomla\CMS\Categories\CategoryInterface;
use Joomla\Database\DatabaseInterface;
use Joomla\CMS\Menu\AbstractMenu;

/**
 * Class MbwcRouter
 *
 */
class Router extends RouterView
{
	private $noIDs;
	/**
	 * The category factory
	 *
	 * @var    CategoryFactoryInterface
	 *
	 * @since  1.0.0
	 */
	private $categoryFactory;

	/**
	 * The category cache
	 *
	 * @var    array
	 *
	 * @since  1.0.0
	 */
	private $categoryCache = [];

	public function __construct(SiteApplication $app, AbstractMenu $menu, CategoryFactoryInterface $categoryFactory, DatabaseInterface $db)
	{
		$params = Factory::getApplication()->getParams('com_mbwc');
		$this->noIDs = (bool) $params->get('sef_ids');
		$this->categoryFactory = $categoryFactory;
		
		
		$incidentreports = new RouterViewConfiguration('incidentreports');
		$this->registerView($incidentreports);
		$incidentreport = new RouterViewConfiguration('incidentreport');
		$incidentreport->setKey('id');
		$this->registerView($incidentreport);
		$mailleaders = new RouterViewConfiguration('mailleaders');
		$this->registerView($mailleaders);
		$countsbycategories = new RouterViewConfiguration('countsbycategory');
		$this->registerView($countsbycategories);
		$mailednewsletters = new RouterViewConfiguration('mailednewsletters');
		$this->registerView($mailednewsletters);
		$covidreport = new RouterViewConfiguration('covidreport');
		$this->registerView($covidreport);
		$incidentexport = new RouterViewConfiguration('incidentexport');
		$this->registerView($incidentexport);
		$infoexport = new RouterViewConfiguration('infoexport');
		$this->registerView($infoexport);
		$leadersintraining = new RouterViewConfiguration('leadersintraining');
		$this->registerView($leadersintraining);
		$committeeexport = new RouterViewConfiguration('committeeexport');
		$this->registerView($committeeexport);
		$outstandingtripreports = new RouterViewConfiguration('outstandingtripreports');
		$this->registerView($outstandingtripreports);
		$monthlytripreport = new RouterViewConfiguration('monthlytripreport');
		$this->registerView($monthlytripreport);
		$yearplanner = new RouterViewConfiguration('yearplanner');
		$this->registerView($yearplanner);
		$cancelledvisitors = new RouterViewConfiguration('cancelledvisitors');
		$this->registerView($cancelledvisitors);
		$visitors = new RouterViewConfiguration('visitors');
		$this->registerView($visitors);
		$leaderswalks = new RouterViewConfiguration('leaderswalks');
		$this->registerView($leaderswalks);
		$memberships = new RouterViewConfiguration('memberships');
		$this->registerView($memberships);
		$membership = new RouterViewConfiguration('membership');
		$this->registerView($membership);
		$membername = new RouterViewConfiguration('membername');
		$this->registerView($membername);
		$mailmember = new RouterViewConfiguration('mailmember');
		$this->registerView($mailmember);
		$history = new RouterViewConfiguration('history');
		$this->registerView($history);
		$tripreport = new RouterViewConfiguration('tripreport');
		$this->registerView($tripreport);
		$tripreport->setKey('event_id');
		$newregistrant = new RouterViewConfiguration('newregistrant');
		$this->registerView($newregistrant);
		$newregistrant->setKey('event_id');
		$visitormailleader = new RouterViewConfiguration('visitormailleader');
		$this->registerView($visitormailleader);
		$visitormailleader->setKey('event_id');
		$upcomingevents = new RouterViewConfiguration('upcomingevents');
		$this->registerView($upcomingevents);
		$summary = new RouterViewConfiguration('summary');
		$this->registerView($summary);
		$summary->setKey('id');
		$pastevents = new RouterViewConfiguration('pastevents');
		$this->registerView($pastevents);

		parent::__construct($app, $menu);

		$this->attachRule(new MenuRules($this));
		$this->attachRule(new StandardRules($this));
		$this->attachRule(new NomenuRules($this));
	}


	
		/**
		 * Method to get the segment(s) for an incidentreport
		 *
		 * @param   string  $id     ID of the incidentreport to retrieve the segments for
		 * @param   array   $query  The request that is built right now
		 *
		 * @return  array|string  The segments of this item
		 */
		public function getIncidentreportSegment($id, $query)
		{
			return array((int) $id => $id);
		}
	
		/**
		 * Method to get the segment(s) for an incidentreport
		 *
		 * @param   string  $segment  Segment of the incidentreport to retrieve the ID for
		 * @param   array   $query    The request that is parsed right now
		 *
		 * @return  mixed   The id of this item or false
		 */
		public function getIncidentreportId($segment, $query)
		{
			return (int) $segment;
		}

	/**
	 * Method to get categories from cache
	 *
	 * @param   array  $options   The options for retrieving categories
	 *
	 * @return  CategoryInterface  The object containing categories
	 *
	 * @since   1.0.0
	 */
	private function getCategories(array $options = []): CategoryInterface
	{
		$key = serialize($options);

		if (!isset($this->categoryCache[$key]))
		{
			$this->categoryCache[$key] = $this->categoryFactory->createCategory($options);
		}

		return $this->categoryCache[$key];
	}
}
