<?php

/**
 * @version    CVS: 1.0.0
 * @package    Com_Mbwc
 * @author     Jeff Dun <jvevfvf+cc@gmail.com>
 * @copyright  2023 Jeff Dun
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace Mbwc\Component\Mbwc\Site\View\Incidentreport;
// No direct access
defined('_JEXEC') or die;

use Joomla\CMS\MVC\View\HtmlView as BaseHtmlView;
use \Joomla\CMS\Factory;
use \Joomla\CMS\Language\Text;
use \Joomla\Registry\Registry;
use MBWC\Component\MBWC\Site\Helper\MBWCHelper;
use Joomla\CMS\Log\Log;

/**
 * View class for a list of Mbwc.
 *
 * @since  1.0.0
 */
class HtmlView extends BaseHtmlView
{
	protected $state;

	protected $item;

	protected $form;

	protected $params;

	protected $canSave;

	/**
	 * Display the view
	 *
	 * @param   string  $tpl  Template name
	 *
	 * @return void
	 *
	 * @throws Exception
	 */
	public function display($tpl = null)
	{
		$app  = Factory::getApplication();
		$user = $app->getIdentity();

		$this->state   = $this->get('State');
		$this->params  = $app->getParams('com_mbwc');
		$this->canSave = $this->get('CanSave');
		$this->form		= $this->get('Form');

		// Check for errors.
		if (count($errors = $this->get('Errors')))
		{
			throw new \Exception(implode("\n", $errors));
		}

		

		$this->_prepareDocument();

		parent::display($tpl);
	}

	/**
	 * Prepares the document
	 *
	 * @return void
	 *
	 * @throws Exception
	 */
	protected function _prepareDocument()
	{
		$app   = Factory::getApplication();
		$menus = $app->getMenu();
		$title = null;

		// Because the application sets a default page title,
		// we need to get it from the menu item itself
		$menu = $menus->getActive();

		if ($menu)
		{
			$this->params->def('page_heading', $this->params->get('page_title', $menu->title));
		}
		else
		{
			$this->params->def('page_heading', Text::_('COM_MBWC_DEFAULT_PAGE_TITLE'));
		}

		$title = $this->params->get('page_title', '');

		if (empty($title))
		{
			$title = $app->get('sitename');
		}
		elseif ($app->get('sitename_pagetitles', 0) == 1)
		{
			$title = Text::sprintf('JPAGETITLE', $app->get('sitename'), $title);
		}
		elseif ($app->get('sitename_pagetitles', 0) == 2)
		{
			$title = Text::sprintf('JPAGETITLE', $title, $app->get('sitename'));
		}

		$this->document->setTitle($title);

		if ($this->params->get('menu-meta_description'))
		{
			$this->document->setDescription($this->params->get('menu-meta_description'));
		}

		if ($this->params->get('menu-meta_keywords'))
		{
			$this->document->setMetadata('keywords', $this->params->get('menu-meta_keywords'));
		}

		if ($this->params->get('robots'))
		{
			$this->document->setMetadata('robots', $this->params->get('robots'));
		}
		
        $eventId = $app->input->getInt('event_id', 0);
        $id = $app->input->getInt('id', 0);
		
		$db = Factory::getDbo();
		$this->nullDate = $db->getNullDate();
 
		if ($eventId)
		{
            $this->edit = MBWCHelper::isSecretary() && !MBWCHelper::isLeader($eventId);
    		$sql = 'select * from #__eb_events where id = '.$eventId;
    	    $db->setQuery($sql) ;
    		$this->event = $db->loadObject();
		    
		    // first check for an existing object
    		$sql = 'select * from #__mbwc_incident where temporary=1 and event_id = '.$eventId;
    	    $db->setQuery($sql) ;
    		$incident = $db->loadObject();
    		if ($incident)
    		{
     		    $this->incident=$incident;
    		}
    		else
    		{
        		$this->incident = new \stdClass() ;
        		$params= new Registry();
        		$params->loadString($this->event->custom_fields,'JSON');
        		$leader_id1 = $params['field_leader_id1'];
        		$db = Factory::getDbo(); 
 		        $sql = 'select concat(b.firstname," ",b.lastname) as name, b.cb_homephone, b.cb_mobphone from jos_comprofiler as b where b.user_id='.$leader_id1;
            	$db->setQuery($sql);
            	$leader=$db->loadObject();
            	$this->incident->leader_name=$leader->name;
        		
        		$this->incident->leader_phone = $leader->cb_mobphone;
        		if (!$this->incident->leader_phone)
        		{
        		    $this->incident->leader_phone = $leader->cb_homephone;
        		}
        		$this->incident->location = $this->event->title;
        		$this->incident->date=substr($this->event->event_date,0,10);
        		$this->incident->event_id=$eventId;
        		$this->incident->name="";
        		$this->incident->person_phone="";
        		$this->incident->person_email="";
        		$this->incident->address="";
        		$this->incident->conditions="";
        		$this->incident->what="";
        		$this->incident->where_happened="";
        		$this->incident->injury="";
        		$this->incident->treatment="";
        		$this->incident->emergency_called=0;
        		$this->incident->whoattended="";
        		$this->incident->witness1_name="";
        		$this->incident->witness1_phone="";
        		$this->incident->witness1_address="";
        		$this->incident->witness2_name="";
        		$this->incident->witness2_phone="";
        		$this->incident->witness2_address="";
        		$this->incident->treatment_required="";
        		$this->incident->hazard="";
        		$this->incident->hazard_controlled="";
        		$this->incident->submit_date=null;
        		$this->incident->claim_number="";
        		$this->incident->claim_lodged_date=null;
        		$this->incident->cancelled=null;
        		$this->incident->reason="";
    		    $this->incident->id=0;
    		}
		} 
		else if ($id)
		{
    		$sql = 'select a.* from #__eb_events as a, #__mbwc_incident as b where b.event_id = a.id and b.id = '.$id;
    	    $db->setQuery($sql) ;
    		$this->event = $db->loadObject();
            $this->edit = MBWCHelper::isSecretary() && !MBWCHelper::isLeader($this->event->id);
   		    $sql = 'select * from #__mbwc_incident where id = '.$id;
    	    $db->setQuery($sql) ;
    		$this->incident = $db->loadObject();
        	$eventId=$this->event->id;
    		if ($this->edit)
    		{
    		    $this->incident->date=substr($this->incident->date,0,10);
    		}
		}
		else
		{
		    $this->edit=false;
       		$this->incident = new \stdClass() ;
        	$this->incident->leader_name="";
    		$this->incident->leader_phone = "";
    		$this->incident->location = "";
    		$this->incident->date=null;
    		$this->incident->event_id=0;
    		$this->incident->name="";
    		$this->incident->person_phone="";
    		$this->incident->person_email="";
    		$this->incident->address="";
    		$this->incident->conditions="";
    		$this->incident->what="";
    		$this->incident->where_happened="";
    		$this->incident->injury="";
    		$this->incident->treatment="";
    		$this->incident->emergency_called=0;
    		$this->incident->whoattended="";
    		$this->incident->witness1_name="";
    		$this->incident->witness1_phone="";
    		$this->incident->witness1_address="";
    		$this->incident->witness2_name="";
    		$this->incident->witness2_phone="";
    		$this->incident->witness2_address="";
    		$this->incident->treatment_required="";
    		$this->incident->hazard="";
    		$this->incident->hazard_controlled="";
    		$this->incident->submit_date=null;
    		$this->incident->claim_number="";
    		$this->incident->claim_lodged_date=null;
    		$this->incident->cancelled=null;
    		$this->incident->reason="";
    		$this->incident->id=0;
    		$eventId=0;
		}

        if ($this->event && $this->event->id)
        {
        	$sql = 'select notification_emails from #__eb_events where id = '.$this->event->id;
    	    $db->setQuery($sql) ;
    		$this->emails = $db->loadResult();
        }

		$Itemid =  $app->input->getInt('Itemid');						
		$this->Itemid = $Itemid;
		$this->eventId = $eventId;
		$this->tmpl    = $app->input->getVar('tmpl', '');		
		$this->return =  $app->input->get('return');						
		
	}
}
