<?php
/**
 * @package            Joomla
 * @subpackage         Event Booking
 * @author             Tuan Pham Ngoc
 * @copyright          Copyright (C) 2010 - 2023 Ossolution Team
 * @license            GNU/GPL, see LICENSE.php
 */

namespace MBWC\Component\MBWC\Site\View\Tripreport;

use Joomla\CMS\MVC\View\HtmlView as BaseHtmlView;
use Joomla\CMS\Factory;
use MBWC\Component\MBWC\Site\Helper\MBWCHelper;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Pagination\Pagination;
use Joomla\String\StringHelper;
use Joomla\Registry\Registry;

// Require library + register autoloader
require_once JPATH_ADMINISTRATOR . '/components/com_eventbooking/libraries/rad/bootstrap.php';


class HtmlView extends BaseHtmlView
{
	function display($tpl = null)
	{	
		$this->setLayout('default') ;
		$user = Factory::getUser();			    
		$app = Factory::getApplication() ;
		$option    = 'com_mbwc' ;									

		$eventId			= $app->getUserStateFromRequest( $option.'event_id',			'event_id',			0,				'int' );
		
		$db = Factory::getDbo();
		$sql = "select a.*, (select count(*) from jos_eb_event_categories as f  left join jos_eb_categories as g on g.id=f.category_id join jos_mbwc_categoryextras as h on g.id=h.category_id where f.event_id=a.id and h.multiple_trip_reports=1) as multiple_trip_reports, 
		concat_ws(',',
		(select name from jos_users as b where b.id=JSON_UNQUOTE(JSON_EXTRACT(a.custom_fields,'$.field_leader_id1'))),
		(select name from jos_users as b where b.id=JSON_UNQUOTE(JSON_EXTRACT(a.custom_fields,'$.field_leader_id2'))),
		(select name from jos_users as b where b.id=JSON_UNQUOTE(JSON_EXTRACT(a.custom_fields,'$.field_leader_id3')))) as leader_name  from #__eb_events as a   
		where a.id = ".$eventId;
	    $db->setQuery($sql) ;
		$this->event = $db->loadObject();
		
		$startdate=substr($this->event->event_date,0,10);
		$enddate=substr($this->event->event_end_date,0,10);
		
		$this->multi=$this->event->multiple_trip_reports;

        // multi is always a new trip report
		if ($this->multi)
		{
    		$sql = "SELECT id, parent, parent AS parent_id, name, name AS title FROM #__eb_categories where published=1 order by ordering";
    		$db->setQuery($sql);
    		$rows = $db->loadObjectList();
    		$children = array();
    		if ($rows)
    		{
    			// first pass - collect children
    			foreach ($rows as $v)
    			{
    				$pt = $v->parent;
    				$list = @$children[$pt] ? $children[$pt] : array();
    				array_push($list, $v);
    				$children[$pt] = $list;
    			}
    		}
    		$list = HTMLHelper::_('menu.treerecurse', 0, '', array(), $children, 9999, 0, 0);
    		$options = array();
    		foreach ($list as $listItem)
    		{
    			$options[] = HTMLHelper::_('select.option', $listItem->name, '&nbsp;&nbsp;&nbsp;' . $listItem->treename);
    		}
    
    		$this->lists['category_id'] = HTMLHelper::_('select.genericlist', $options, 'grade', 
    			array(
    				'option.text.toHtml' => false, 
    				'option.text' => 'text', 
    				'option.value' => 'value', 
    				'list.attr' => 'class="form-select"  size="1"'));
    
    		$this->lists['event_date_hour'] = HTMLHelper::_('select.integerlist', 0, 23, 1, 'event_date_hour', ' style="display:unset; width:100px" class="form-select" ', 9);
    		$this->lists['event_date_minute'] = HTMLHelper::_('select.integerlist', 0, 60, 5, 'event_date_minute', ' style="display:unset; width:100px" class="form-select" ', 0, '%02d');
    		$this->lists['event_end_date_hour'] = HTMLHelper::_('select.integerlist', 0, 23, 1, 'event_end_date_hour', ' style="display:unset; width:100px" class="form-select" ',15);
    		$this->lists['event_end_date_minute'] = HTMLHelper::_('select.integerlist', 0, 60, 5, 'event_end_date_minute', ' style="display:unset; width:100px" class="form-select" ', 0, '%02d');
    		
    		$sql = "select distinct a.* from jos_users as a join jos_user_usergroup_map as b on ((b.group_id=9 or b.group_id=25) and b.user_id=a.id) join jos_eb_registrants as c on c.user_id=a.id where c.published=1 and c.event_id=$eventId order by a.name";
    		$db->setQuery($sql);
    		$this->users = $db->loadObjectList();
    		
    		$this->$tripreport = new \stdClass() ;

    		$this->tripreport->comment="";
    		$this->tripreport->behaviour="";
    		$this->tripreport->incident=0;
    		$this->tripreport->id=0;
    		$this->tripreport->actual_distance="";
            $this->tripreport->num_members=0;
            $this->tripreport->num_cancellations=0;
		}
        else
        {
		    // first check for an existing object
    		$sql = 'select * from #__mbwc_tripreports where event_id = '.$eventId  .' order by id desc limit 1';
    	    $db->setQuery($sql) ;
    		$tripreport = $db->loadObject();
    		if ($tripreport)
    		{
     		    $this->tripreport=$tripreport;
    		}
    		else
    		{
        		$this->tripreport = new \stdClass() ;

        		$this->tripreport->comment="";
        		$this->tripreport->behaviour="";
        		$this->tripreport->incident=0;
        		$this->tripreport->id=0;
        		$this->tripreport->actual_distance="";
         		$sql = 'SELECT count(*) FROM #__eb_registrants WHERE event_id=' . $eventId . ' AND is_group_billing=0 AND published=1 and user_id is not null and user_id != 0 ';
        	    $db->setQuery($sql) ;
                $this->tripreport->num_members=$db->loadResult();
        		$sql = 'SELECT count(*) FROM #__eb_registrants WHERE event_id=' . $eventId . ' AND is_group_billing=0 AND published in (2,6,7,8) ';
        	    $db->setQuery($sql) ;
                $this->tripreport->num_cancellations=$db->loadResult();
    		}
		} 

        if ($this->event && $this->event->id)
        {
        	$sql = 'select notification_emails from #__eb_events where id = '.$this->event->id;
    	    $db->setQuery($sql) ;
    		$this->emails = $db->loadResult();
    		
     		$db->setQuery("SELECT name FROM #__eb_categories WHERE id IN (SELECT category_id FROM #__eb_event_categories WHERE event_id = $eventId)");
    		$this->category=implode(', ', $db->loadColumn());

    		$params= new Registry();
    		$params->loadString($this->event->custom_fields,'JSON');
    		$this->leader_name = $this->event->leader_name;
    		$this->leader_id1 = $params['field_leader_id1'];
    		$this->distance = $params['field_distance'];

    		$sql = 'SELECT count(*) FROM #__eb_registrants WHERE event_id=' . $eventId . ' AND is_group_billing=0 AND (published=1 or published=4)  and (user_id = 0 or user_id is null) ';
    	    $db->setQuery($sql) ;
            $this->num_visitors=$db->loadResult();
            
            $sql = "SELECT a.first_name, a.last_name, ifnull(b.field_value,a.phone) as phone, false as paid, a.published FROM #__eb_registrants as a 
            left join #__eb_field_values as b on b.registrant_id = a.id and b.field_id=21 
            WHERE a.event_id=" . $eventId .' AND a.is_group_billing=0 AND (published=1 or published=4) and (a.user_id = 0 or a.user_id is null) ';
           $outputstr=json_encode($sql);
            echo "<script>console.log(".$outputstr.")</script>"; 
    	    $db->setQuery($sql) ;
    		$this->visitors = $db->loadObjectList();
        }
        
		$config = \EventbookingHelper::getConfig();

		$Itemid = $app->input->getInt('Itemid');						
		$this->return = $app->input->getVar('return');						
		$this->config = $config;
		$this->Itemid = $Itemid;
		$this->eventId = $eventId;
		$this->tmpl    = $app->input->getVar('tmpl', '');		

		parent::display($tpl);				
	}
}