<?php
/**
 * @package            Joomla
 * @subpackage         Event Booking
 * @author             Tuan Pham Ngoc
 * @copyright          Copyright (C) 2010 - 2023 Ossolution Team
 * @license            GNU/GPL, see LICENSE.php
 */

defined('_JEXEC') or die;

use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Factory;
use Joomla\CMS\Uri\Uri;

$cols = 2;
$return = base64_encode(Uri::getInstance()->toString());
HTMLHelper::_('formbehavior.chosen', 'select');

if (in_array('last_name', EventbookingHelper::getPublishedCoreFields()))
{
	$showLastName = true;
}
else
{
	$showLastName = false;
}
$baseUrl  = Uri::base(true);
$document = Factory::getDocument();
$document->addStyleSheet($baseUrl . '/media/com_eventbooking/assets/css/style.css');

$isJoomla4        = EventbookingHelper::isJoomla4();
$bootstrapHelper  = EventbookingHelperBootstrap::getInstance();
$btnPrimary       = $bootstrapHelper->getClassMapping('btn btn-primary');
$btnDanger        = $bootstrapHelper->getClassMapping('btn btn-danger');
$hiddenPhoneClass = $bootstrapHelper->getClassMapping('hidden-phone');
?>
<script language="javascript">
    function cancelRegistration(registrantId) {
        var form = document.regForm ;
        var pr = prompt("If you like, you can add the reason for your cancellation, and the leader will be notified. This is optional. Press cancel to back out of this action.\n\nReason (Optional):");
        if (pr === null) {
            return false;
        }
        form.reason.value = pr;
        form.controller.value = 'registrant' ;
        form.task.value = 'cancel_registration' ;
        form.id.value = registrantId ;
        form.submit() ;
    }
</script>
<div id="eb-registration-history-page" class="eb-container<?php if ($isJoomla4) echo ' eb-joomla4-container'; ?>">
<?php if ($this->first_name)
{
    ?>
    <button class="btn btn-primary" onclick="window.history.back();">Go Back</button>
    <?php
} ?>
	<?php
		$pageHeading = "Registration History";

		if ($this->input->getInt('hmvc_call'))
		{
			$hTag = 'h2';
		}
		else
		{
			$hTag = 'h1';
		}
		$extra="";
		if ($this->first_name)
	    {
	        $extra=" for ".$this->first_name." ".$this->last_name;
	    }
	?>
		<<?php echo $hTag; ?> class="eb-page-heading"><?php echo $this->escape($pageHeading). $extra; ?></<?php echo $hTag; ?>>
	<form action="<?php echo Route::_('index.php?option=com_mbwc&view=history&Itemid=' . $this->Itemid);  ?>" method="post" name="adminForm"  id="adminForm">
	<?php
		if (count($this->items))
		{
		?>
			<table class="<?php echo $bootstrapHelper->getClassMapping('table table-striped table-bordered table-hover'); ?> eb-responsive-table">
			<thead>
				<tr>
					<?php
						if ($this->config->show_event_date)
						{
							$cols++;
							$cols++;
						?>
							<th class="center">
								Day
							</th>
							<th class="list_event_date">
								<?php echo HTMLHelper::_('grid.sort', 'Event Date', 'ev.event_date', $this->lists['order_Dir'], $this->lists['order']); ?>
							</th>
						<?php
						} ?>
							<th class="center <?php echo $hiddenPhoneClass; ?>">
								Category
							</th>
					<th class="list_event">
						<?php echo HTMLHelper::_('grid.sort', 'Event', 'ev.title', $this->lists['order_Dir'], $this->lists['order']); ?>
					</th>
                        <?php
						if ($this->config->get('history_show_registration_date', 1))
						{
							$cols++;
						 ?>
	                        <th class="list_event_date">
			                    <?php echo HTMLHelper::_('grid.sort', 'Registration Date', 'tbl.register_date', $this->lists['order_Dir'], $this->lists['order']); ?>
	                        </th>
	                    <?php
						} 

						if ($this->config->get('history_show_number_registrants', 1))
						{
							$cols++;
						?>
							<th class="list_registrant_number <?php echo $hiddenPhoneClass; ?>">
								<?php echo HTMLHelper::_('grid.sort', Text::_('EB_REGISTRANTS'), 'tbl.number_registrants', $this->lists['order_Dir'], $this->lists['order']); ?>
							</th>
						<?php
						}

						if ($this->config->get('history_show_registration_status', 1))
						{
							$cols++;
						?>
	                        <th class="list_id">
			                    <?php echo HTMLHelper::_('grid.sort', 'Registration Status', 'tbl.published', $this->lists['order_Dir'], $this->lists['order']); ?>
	                        </th>
	                    <?php
						}

					?>
				</tr>
			</thead>
			<tfoot>
				<tr>
					<?php
						if ($this->pagination->total > $this->pagination->limit)
						{
						?>
							<td colspan="<?php echo $cols; ?>">
								<?php echo $this->pagination->getListFooter(); ?>
							</td>
						<?php
						}
					?>
				</tr>
			</tfoot>
			<tbody>
			<?php
			$k = 0;
			$Itemid = EventbookingHelper::getItemid();

			for ($i = 0, $n = count($this->items); $i < $n; $i++)
			{
				$row       = $this->items[$i];
				$link      = Route::_('index.php?option=com_eventbooking&view=registrant&id=' . $row->id . '&Itemid=' . $this->Itemid . '&return=' . $return);
				$eventLink = Route::_(EventbookingHelperRoute::getEventRoute($row->event_id, $row->main_category_id, $Itemid));
                $dateParts = explode(' ', $row->event_date) ;
    		    $startDate = strtotime($dateParts[0]) ;
                $dateParts2 = explode(' ', $row->event_end_date) ;
    		    $endDate = strtotime($dateParts2[0]) ;
    		    if (!$endDate || $endDate == '0000-00-00 00:00:00')
    		    {
    		        $endDate=$startDate;
    		    }

				?>
				<tr <?php if ($endDate <= strtotime(date('d-m-Y'))) echo 'style="background-color: #ADD8E6;"';?>>
				    <?php
					if ($this->config->show_event_date)
					{
					?>
  	                    <td class="tdno<?php echo $i; ?> center" data-content="<?php echo 'Day' ?>">
	                        <?php
								if ($row->event_date == EB_TBC_DATE)
								{
									echo Text::_('EB_TBC');
								}
								else
								{
									echo date("l", strtotime($row->event_date));
								}
							?>
	                    </td>
  
	                    <td class="tdno<?php echo $i; ?> center" data-content="Event Date">
	                        <?php
								if ($row->event_date == EB_TBC_DATE)
								{
									echo Text::_('EB_TBC');
								}
								else
								{
									echo HTMLHelper::_('date', $row->event_date, "d-m-Y", null);
								}
							?>
	                    </td>
	                <?php
					} ?>
					<td class="tdno<?php echo $i; ?>" data-content="Category">
					<?php 
  					$db = JFactory::getDbo();
					$db->setQuery("SELECT name FROM #__eb_categories WHERE id IN (SELECT category_id FROM #__eb_event_categories WHERE event_id = $row->event_id union select main_category_id from jos_eb_events where id=$row->event_id)");
					echo implode(', ', $db->loadColumn());					
					?>	
					</td>

					<td class="tdno<?php echo $i; ?>" data-content="<?php echo 'Event' ?>">
						<a href="<?php echo $eventLink; ?>" target="_blank"><?php echo $this->escape($row->title); ?></a>
					</td>
					<?php

					if ($this->config->get('history_show_registration_date', 1))
					{
					?>
	                    <td class="tdno<?php echo $i; ?> center" data-content="<?php echo 'Registration Date' ?>">
			                <?php echo HTMLHelper::_('date', $row->register_date, $this->config->date_format) ; ?>
	                    </td>
	                <?php
					}

					if ($this->config->get('history_show_number_registrants', 1))
					{
					?>
						<td class="center <?php echo $hiddenPhoneClass; ?>" style="font-weight: bold;">
							<?php echo $row->number_registrants; ?>
						</td>
					<?php
					}

					if ($this->config->get('history_show_amount', 1))
					{
					?>
						<td align="right" class="<?php echo $hiddenPhoneClass; ?>">
							<?php echo EventbookingHelper::formatCurrency($row->amount, $this->config, $row->currency_symbol) ; ?>
						</td>
					<?php
					}


					if ($this->config->get('history_show_registration_status', 1))
					{
					?>
	                <td class="tdno<?php echo $i; ?> center" data-content="Status">
	                    <?php
						switch($row->published)
						{
							case 0 :
								echo 'Pending';

								if ($row->group_id == 0 && $hasOnlinePaymentMethods && strpos($row->payment_method, 'os_offline') !== false)
								{
								?>
									<a class="<?php echo $btnPrimary; ?>" href="<?php echo Route::_('index.php?option=com_eventbooking&view=payment&layout=registration&order_number=' . $row->registration_code . '&Itemid=' . $this->Itemid); ?>"><?php echo Text::_('EB_MAKE_PAYMENT'); ?></a>
								<?php
								}
								break ;
							case 1 :
								echo "Registered";
								break ;
							case 2 :
								echo 'Cancelled';
								break;
							case 3:
								echo 'Waiting List';
								break;
							case 4:
								echo 'Visitor pending approval';
								break;
							case 5:
								echo 'Visitor pending approval on Waiting List';
								break;
							case 6:
								echo 'Visitor on mainlist Cancelled before approval';
								break;
							case 7:
								echo 'Visitor on Waiting list Cancelled before approval';
								break;
							case 8:
								echo 'Waiting list Cancelled';
								break;
						}

						if (!$row->group_id && !empty($row->enable_cancel_registration) && in_array($row->published, [0, 1, 3]) && EventbookingHelperRegistration::canCancelRegistrationNow($row))
						{
							if ($row->published == 3)
							{
								$buttonText = 'Cancel Waiting List';
							}
							else
							{
								$buttonText = 'Cancel Registration';
							}
							?>
	                            <a class="<?php echo $btnDanger; ?>" href="javascript:cancelRegistration(<?php echo $row->id; ?>)"><?php echo Text::_($buttonText); ?></a>
  	                        <?php
						}
						?>
	                </td>
	                <?php
					}
				?>
				</tr>
				<?php
				$k = 1 - $k;
			}
			?>
			</tbody>
		</table>
		<?php
		}
		else
		{
			echo '<div class="text-info">' . "No Records" . '</div>' ;
		}
	?>
		<input type="hidden" name="view" value="history" />
		<input type="hidden" name="option" value="com_mbwc" />
		<input type="hidden" name="filter_order" value="<?php echo $this->lists['order']; ?>" />
		<input type="hidden" name="filter_order_Dir" value="<?php echo $this->lists['order_Dir']; ?>" />
		<?php echo HTMLHelper::_('form.token'); ?>
	</form>
	<form action="<?php echo Route::_('index.php?Itemid=' . $this->Itemid);  ?>" method="post" name="regForm"  id="regForm">
		<input type="hidden" name="task" value="" />
		<input type="hidden" name="controller" value="" />
		<input type="hidden" name="option" value="com_mbwc" />
		<input type="hidden" name="id" value="" />
		<input type="hidden" name="reason" value="" />
	    </form>
</div>
