<?php
/**
 * @package            Joomla
 * @subpackage         Event Booking
 * @author             Tuan Pham Ngoc
 * @copyright          Copyright (C) 2010 - 2023 Ossolution Team
 * @license            GNU/GPL, see LICENSE.php
 */

defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Plugin\CMSPlugin;
use Joomla\CMS\Uri\Uri;
use Joomla\Registry\Registry;
use Joomla\CMS\Log\Log;

class plgEventbookingMbwcmap extends CMSPlugin
{
	/**
	 * Application object.
	 *
	 * @var    JApplicationCms
	 */
	protected $app;

	/**
	 * Database object.
	 *
	 * @var    JDatabaseDriver
	 */
	protected $db;

	/**
	 * Constructor.
	 *
	 * @param $subject
	 * @param $config
	 */
	public function __construct(&$subject, $config)
	{
		parent::__construct($subject, $config);

		Factory::getLanguage()->load('plg_eventbooking_map', JPATH_ADMINISTRATOR);
	}

	/**
	 * Display event location in a map
	 *
	 * @param $row
	 *
	 * @return array|string
	 */
	public function onEventDisplay($row)
	{
		$db    = $this->db;
		$params    = new Registry($row->custom_fields);
		$rootUri   = Uri::root(true);

		$print = $this->app->input->getInt('print', 0);
    	ob_start();
   		HTMLHelper::_('behavior.core');
		Factory::getDocument()
			->addScript($rootUri . '/media/com_eventbooking/assets/js/leaflet/leaflet.js')
			->addStyleSheet($rootUri . '/media/com_eventbooking/assets/js/leaflet/leaflet.css')
			->addScriptOptions('mapZoomLevel', 14);
        ?>
        <style>
            .leaflet-bottom {z-index:1;}
            .leaflet-pane {z-index:1;}
            .leaflet-control {z-index:1;}
            .leaflet-top {z-index:1;}
            </style>
        		<script>
		    (function (document) {
    document.addEventListener('DOMContentLoaded', function(){
        var zoomLevel = Joomla.getOptions('mapZoomLevel');
        var location = Joomla.getOptions('mapLocation1');
        var id = Joomla.getOptions('mapId');

        var mymap = L.map('map_canvas1', {
            center: [location.lat, location.long],
            zoom: zoomLevel,
            zoomControl: true,
            scrollWheelZoom: false
        });

        L.tileLayer('https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png', {
            attribution: 'Map data &copy; <a href="https://www.openstreetmap.org/">OpenStreetMap</a> contributors, <a href="https://creativecommons.org/licenses/by-sa/2.0/">CC-BY-SA</a>, Imagery © <a href="https://www.mapbox.com/">Mapbox</a>',
            maxZoom: 18,
            id: 'mapbox.streets',
            zoom: zoomLevel,
        }).addTo(mymap);

        var marker = L.marker([location.lat, location.long], {
            draggable: false,
            autoPan: true,
            title: location.name
        }).addTo(mymap);

        marker.bindPopup(location.popupContent);
        marker.openPopup();
    });
    document.addEventListener('DOMContentLoaded', function(){
        var zoomLevel = Joomla.getOptions('mapZoomLevel');
        var location = Joomla.getOptions('mapLocation2');
        var id = Joomla.getOptions('mapId');

        var mymap = L.map('map_canvas2', {
            center: [location.lat, location.long],
            zoom: zoomLevel,
            zoomControl: true,
            scrollWheelZoom: false
        });

        L.tileLayer('https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png', {
            attribution: 'Map data &copy; <a href="https://www.openstreetmap.org/">OpenStreetMap</a> contributors, <a href="https://creativecommons.org/licenses/by-sa/2.0/">CC-BY-SA</a>, Imagery © <a href="https://www.mapbox.com/">Mapbox</a>',
            maxZoom: 18,
            id: 'mapbox.streets',
            zoom: zoomLevel,
        }).addTo(mymap);

        var marker = L.marker([location.lat, location.long], {
            draggable: false,
            autoPan: true,
            title: location.name
        }).addTo(mymap);

        marker.bindPopup(location.popupContent);
        marker.openPopup();
    });
})(document);
		</script>
               <div class="container">
                  <div class="row">
		<?php
        $location = new \stdClass();
        $location->lat = $params['field_address_start_lat'];
        $location->long = $params['field_address_start_long'];
        $location->address = $params['field_address_start'];
 
		if (
			empty($location->address)
			|| ($location->lat == 0 && $location->long == 0)
			|| $print
		)
		{
		    //
		}
		else
		{
    		$this->drawOpenStreetMap($location,"Walk Start",1);
 		}
        $location = new \stdClass();
        $location->lat = $params['field_address_lat'];
        $location->long = $params['field_address_long'];
        $location->address = $params['field_address'];
 
		$print = $this->app->input->getInt('print', 0);

		if (
			empty($location->address)
			|| ($location->lat == 0 && $location->long == 0)
			|| $print
		)
		{
		    //
		}
		else
		{
    		$this->drawOpenStreetMap($location,"Car Pool Point",2);
		}
		?>
		</div></div>
		<?php
        $form = ob_get_clean();
		return [
			'title'    => '',
			'form'     => $form,
			'name'     => $this->_name,
			'position' => $this->params->get('output_position', 'after_register_buttons'),
		];
	}

	/**
	 * Display location on openstreetmap
	 *
	 * @param   EventbookingTableLocation  $location
	 */
	private function drawOpenStreetMap($location,$title,$id)
	{
		$config    = EventbookingHelper::getConfig();
		$zoomLevel = 14;
		$mapHeight = 270;

		$popupContent           = [];
		$popupContent[]         = '<h4 class="eb-location-name">' . $location->address . '</h4>';
		$location->popupContent = implode('', $popupContent);

		Factory::getDocument()
			->addScriptOptions('mapLocation'.$id, $location)
		?>

        <div id="mapform" class="col-sm-6">
             <h3>Map of <?php echo $title;?></h3>
              <a class="btn btn-primary" href="https://www.google.com/maps/dir/?api=1&origin=My+Location&destination=<?php echo $location->lat.",".$location->long ?>">Google Maps Directions to <?php echo $title;?></a><br>
 			<div id="map_canvas<?php echo $id;?>" style="width: 400px; height: <?php
			echo $mapHeight; ?>px"></div>
            <small><a target="_blank" href="https://www.openstreetmap.org/?mlat=<?php echo $location->lat?>&amp;mlon=<?php echo $location->long?>#map=14/<?php echo $location->lat?>/<?php echo $location->long?>">View Larger Map</a></small>
        </div>
		<?php
	}
}
