<?php
/**
 * @package            Joomla
 * @subpackage         Event Booking
 * @author             Tuan Pham Ngoc
 * @copyright          Copyright (C) 2010 - 2023 Ossolution Team
 * @license            GNU/GPL, see LICENSE.php
 */

defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;
use MBWC\Component\MBWC\Site\Helper\MBWCHelper;

/**
 * Layout variables
 * -----------------
 * @var   EventbookingTableEvent $item
 * @var   boolean                $isMultipleDate
 * @var   boolean                $showInviteFriend
 * @var   int                    $Itemid
 * @var   string                 $return
 */

$bootstrapHelper   = EventbookingHelperBootstrap::getInstance();
$config            = EventbookingHelper::getConfig();
$ssl               = (int) $config->use_https;
$btnClass          = $bootstrapHelper->getClassMapping('btn');
$btnBtnPrimary     = $bootstrapHelper->getClassMapping('btn btn-primary');
$iconPencilClass   = $bootstrapHelper->getClassMapping('icon-pencil');
$iconOkClass       = $bootstrapHelper->getClassMapping('icon-ok');
$iconRemoveClass   = $bootstrapHelper->getClassMapping('icon-remove');
$iconDownloadClass = $bootstrapHelper->getClassMapping('icon-download');
$clearfixClass     = $bootstrapHelper->getClassMapping('clearfix');

$db = Factory::getDbo();

$sql = "select count(*) from jos_eb_event_categories as d join jos_eb_categories as e on d.category_id=e.id join jos_mbwc_categoryextras as f on f.category_id=e.id where f.external_event=1 and d.event_id=".$item->id;
$db->setQuery($sql);
$external_event = $db->loadResult();

$sql = "select count(*) from jos_eb_event_categories as d join jos_eb_categories as e on d.category_id=e.id join jos_mbwc_categoryextras as f on f.category_id=e.id where f.club_meeting=1 and d.event_id=".$item->id;
$db->setQuery($sql);
$club_meeting = $db->loadResult();

$isSuperUser = MBWCHelper::isSuperUser();
$isEventCoordinator = MBWCHelper::isEventCoordinator();
$isLeader = MBWCHelper::isLeader($item->id);
$isSecretary = MBWCHelper::isSecretary();

$sql = "select 1 from jos_mbwc_tripreports where event_id=".$item->id;
$db->setQuery($sql);
$hasTripReport = $db->loadResult();

$dateParts = explode(' ', $item->event_date) ;
$startDate = strtotime($dateParts[0]) ;
$dateParts2 = explode(' ', $item->event_end_date) ;
$endDate = strtotime($dateParts2[0]) ;

if (empty($hideRegisterButtons) && !$item->is_multiple_date && !$club_meeting && !$external_event)
{
	if ($item->can_register)
	{
		echo EventbookingHelperHtml::loadCommonLayout('common/buttons_register.php', ['item' => $item, 'Itemid' => $Itemid]);
	}
	elseif ($item->waiting_list && $item->registration_type != 3 && !EventbookingHelperRegistration::isUserJoinedWaitingList($item->id))
	{
		echo EventbookingHelperHtml::loadCommonLayout('common/buttons_waiting_list.php', ['item' => $item, 'Itemid' => $Itemid]);
	}
}

if ($config->show_save_to_personal_calendar && $item->event_date != EB_TBC_DATE)
{
?>
	<li class="eb-save-to-calendar-buttons">
		<?php echo EventbookingHelperHtml::loadCommonLayout('common/save_calendar.php', ['item' => $item, 'Itemid' => $Itemid]); ?>
	</li>
<?php
}

if ($showInviteFriend && $config->show_invite_friend && EventbookingHelperRegistration::canInviteFriend($item))
{
?>
	<li>
		<a class="<?php echo $btnClass; ?> eb-colorbox-invite" href="<?php echo Route::_('index.php?option=com_eventbooking&view=invite&tmpl=component&id=' . $item->id . '&Itemid=' . $Itemid, false); ?>"><?php echo Text::_('EB_INVITE_FRIEND'); ?></a>
	</li>
<?php
}

$user = Factory::getUser();

if ($user->guest)
{
	return;
}

if ($item->enable_cancel_registration && !$club_meeting && !$external_event)
{
	$registrantId = EventbookingHelperRegistration::getRegistrantId($item->id);

	if ($registrantId !== false)
	{
        $canCancel = MBWCHelper::canCancelRegistration($item->id) ; 
		if (EventbookingHelperRegistration::isUserJoinedWaitingList($item->id) && $canCancel !== false)
		{
			$buttonLabel = 'EB_CANCEL_WAITING_LIST';
            $waitlist=1;?>
		<li>
			<a class="<?php echo $btnClass; ?>"
			   href="javascript:cancelRegistration(<?php echo $registrantId.",".$waitlist ?>)"><?php echo Text::_($buttonLabel); ?></a>
		</li>
		<?php
		}
		else
		{
			$buttonLabel = 'EB_CANCEL_REGISTRATION';
            $waitlist=0;
			if ($canCancel !== false) 
			{

?>
		<li>
			<a class="<?php echo $btnClass; ?>"
			   href="javascript:cancelRegistration(<?php echo $registrantId.",".$waitlist ?>)"><?php echo Text::_($buttonLabel); ?></a>
		</li>
		<?php }
		    $canCancel = MBWCHelper::canCancelGroupRegistration($item->id) ; 
    		if ($canCancel !== false) 
			{
            ?>
		<li>
			<a class="<?php echo $btnClass; ?>"
			   href="javascript:cancelRegistration(<?php echo $registrantId.",".$waitlist ?>)">Cancel Group</a>
		</li>
		<?php
			}
		}
	?>
	<?php
	}
}
?>
		<li>
			<a class="<?php echo $btnClass; ?>"
			   href="index.php?option=com_mbwc&view=mailleader&event_id=<?php echo $item->id;?>&Itemid=<?php echo $Itemid;?>">Mail Leader</a>
		</li>
		<li>
			<a class="<?php echo $btnClass; ?>"
			   href="images/How%20To/Events%20Help.pdf">Help</a>
		</li>

<?php

if (!$config->get('show_actions_button', '1'))
{
	return;
}
?>
<li>
<nav class="navbar navbar-expand navbar-light bg-light" style="--navbar-padding-y:0">
  <div class="container-fluid">
    <div class="collapse navbar-collapse" id="navbarSupportedContent">
      <ul class="navbar-nav me-auto mb-2 mb-lg-0">
        <li class="nav-item dropdown" style="margin-top: 0.2em; margin-bottom:0px">
          <a class="nav-link dropdown-toggle" href="#" id="navbarDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">
           <?php if ($isLeader) { echo "Leader"; } else { echo "Event Coordinator"; }?>
          </a>
          <ul class="dropdown-menu" aria-labelledby="navbarDropdown">
<?php
            if (!$isSuperUser && ($hasTripReport || $startDate < strtotime(date('d-m-Y'). ' - 3 days')))
            {
                $link="javascript:alert('You cannot edit an event after you have submitted the Trip Report or if the event was over 3 days ago.')";
            }
            elseif ($item->published ==2)
            {                                           $link="javascript:alert('You cannot edit a Cancelled event.')";
            }
            else
            {
                $link = Route::_('index.php?option=com_eventbooking&view=event&layout=form&id=' . $item->id . '&Itemid=' . $Itemid . '&return=' . $return, false);
            }
            
            ?>
            <li><a class="dropdown-item"  href="<?php echo $link?>">Edit Event</a></li>
<?php
            if (!$external_event && !$club_meeting)
            {
                $link = Route::_('index.php?option=com_mbwc&view=tripreport&return=event&event_id=' . $item->id . '&Itemid=' . $Itemid) ;
                echo "<li><a class='dropdown-item' href='".$link."'>Trip Report</a></li>";
            }
            if ($item->published == 1 && ($item->event_capacity > $item->total_registrants) && !$external_event)
            {
                if ($isSuperUser || (!$hasTripReport && $startDate >= strtotime(date('d-m-Y'). ' - 3 days')))
                {
                    $link = Route::_('index.php?option=com_mbwc&view=newregistrant&waitlist=0&return=event&event_id='.$item->id);
                }
                else
                {
                    $link = "javascript:alert('You cannot add a registrant after you have submitted the Trip Report or if the event was over 3 days ago.')";
                }
            ?>
                <li><a class="dropdown-item" href="<?php echo $link ; ?>"><?php echo 'Add Registrant' ; ?></a></li>
            <?php
            }
            if ($item->published == 1  && ($item->event_capacity <= $item->total_registrants) && !$external_event)
            {
                if (!$hasTripReport && $startDate >= strtotime(date('d-m-Y'). ' - 3 days'))
                {
                    $link = Route::_('index.php?option=com_mbwc&view=newregistrant&waitlist=1&return=event&event_id='.$item->id);
                }
                else
                {
                    $link = "javascript:alert('You cannot add to waitlist after you have submitted the Trip Report or if the event was over 3 days ago.')";
                }
            ?>
                 <li><a class="dropdown-item" href="<?php echo $link ; ?>"><?php echo JText::_('Add Waitlist') ; ?></a></li>
            <?php                    
            }
			if ($item->published == 1)
            {
                if (!$isSuperUser && $hasTripReport)
                {
                    $link="javascript:alert('You cannot cancel an event after you have submitted the Trip Report or if the event was over 3 days ago.')";
                }
                else
                {
                   $link = "javascript:cancelEvent(".$item->id.");";
                }
                ?>
                <li><a class="dropdown-item" onclick="return confirm('Are you sure you want to cancel?')" href="<?php echo $link?>">Cancel Event</a>      
           <?php }

			if ($item->published == 2)
            {
                ?>
                <li><a class="dropdown-item" href="javascript:unCancelEvent(<?php echo $item->id; ?>)">Uncancel Event</a></li>   
                <?php
            }
            $link = Route::_('index.php?option=com_mbwc&view=mailregistrants&return=event&waitlist=0&event_id='.$item->id);

            ?>
            <li><a class="dropdown-item" href="<?php echo $link; ?>" >Mail Registrants</a></li>
            </ul>
            </li>
             <?php
            if ($isSecretary && !$external_event && !$club_meeting)
            {
            ?>
                <li class="nav-item dropdown" style="margin-top: 0.2em; margin-bottom:0px">
                  <a class="nav-link dropdown-toggle" href="#" id="navbarDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">
                   Secretary
                  </a>
                     <ul class="dropdown-menu" aria-labelledby="navbarDropdown">
                          <?php
                            if ($startDate > strtotime(date('d-m-Y')))
                            {
                                $link="javascript:alert('You cannot submit an Incident Report for a future Event.')";
                            }
                            else
                            {
                                $link = Route::_('index.php?option=com_mbwc&view=incidentreport&event_id='.$item->id.'&return=' . $return) ;
                            }
                            ?>
                            <li><a class="dropdown-item" href="<?php echo $link ; ?>">Incident Report</a></li>     
                     </ul>
                </li>
              <?php
            }
            if ( ($isSuperUser ||MBWCHelper::isTripLeaderOnEvent($item->id)) && $dateParts2[0] !== '0000-00-00' && $startDate !== $endDate && !$club_meeting)
            { 
            ?>
                <li class="nav-item dropdown" style="margin-top: 0.2em; margin-bottom:0px">
                  <a class="nav-link dropdown-toggle" href="#" id="navbarDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">
                   Basecamp Leader Actions
                  </a>
                     <ul class="dropdown-menu" aria-labelledby="navbarDropdown">
                          <?php
                            if ($startDate > strtotime(date('d-m-Y')))
                            {
                                $link="javascript:alert('You cannot submit an Trip Report for a future Event.')";
                            }
                            else
                            {
                                $link = Route::_('index.php?option=com_mbwc&view=tripreport&event_id='.$item->id.'&return=' . $return) ;
                            }
                            ?>
                            <li><a tabindex="-1" href="<?php echo $link ; ?>">Trip Report</a></li>     
                          <?php
                            if ($startDate > strtotime(date('d-m-Y')))
                            {
                                $link="javascript:alert('You cannot submit an Incident Report for a future Event.')";
                            }
                            else
                            {
                                $link = Route::_('index.php?option=com_mbwcg&view=incidentreport&event_id='.$item->id.'&return=' . $return) ;
                            }
                            ?>
                            <li><a class="dropdown-item" href="<?php echo $link ; ?>">Incident Report</a></li>
                     </ul>
                </li>
                 <?php
            }
            ?>
           
      </ul>
    </div>
  </div>
</nav>
</li>


<?php


