<?php
/**
 * @package            Joomla
 * @subpackage         Event Booking
 * @author             Tuan Pham Ngoc
 * @copyright          Copyright (C) 2010 - 2023 Ossolution Team
 * @license            GNU/GPL, see LICENSE.php
 */

defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Uri\Uri;
use Joomla\Registry\Registry;

$item = $this->item ;

EventbookingHelper::callOverridableHelperMethod('Data', 'prepareDisplayData', [[$item], @$item->main_category_id, $this->config, $this->Itemid]);

$socialUrl = Uri::getInstance()->toString(['scheme', 'user', 'pass', 'host']) . $item->url;

/* @var EventbookingHelperBootstrap $bootstrapHelper*/
$bootstrapHelper   = $this->bootstrapHelper;
$iconPencilClass   = $bootstrapHelper->getClassMapping('icon-pencil');
$iconOkClass       = $bootstrapHelper->getClassMapping('icon-ok');
$iconRemoveClass   = $bootstrapHelper->getClassMapping('icon-remove');
$iconDownloadClass = $bootstrapHelper->getClassMapping('icon-download');
$btnClass          = $bootstrapHelper->getClassMapping('btn');
$iconPrint         = $bootstrapHelper->getClassMapping('icon-print');
$clearfixClass     = $bootstrapHelper->getClassMapping('clearfix');
$return = base64_encode(Uri::getInstance()->toString());

$isMultipleDate = false;

if ($this->config->show_children_events_under_parent_event && $item->event_type == 1)
{
	$isMultipleDate = true;
}

$offset = Factory::getApplication()->get('offset');

if ($this->showTaskBar)
{
	$layoutData = [
		'item'              => $this->item,
		'isMultipleDate'    => $isMultipleDate,
		'showInviteFriend'  => true,
		'Itemid'            => $this->Itemid,
		'return'            => $return,
	];

	$registerButtons = EventbookingHelperHtml::loadCommonLayout('common/buttons.php', $layoutData);
}

if (!$this->config->get('show_group_rates', 1))
{
	$this->rowGroupRates = [];
}

$cssClasses   = $item->cssClasses ?? [];
$cssClasses[] = 'eb-container';
$cssClasses[] = 'eb-event';

if ($this->print)
{
	$cssClasses[] = 'eb-print-page';
}

if ($this->input->getInt('hmvc_call'))
{
	$hTag = 'h2';
}
else
{
	$hTag = 'h1';
}
$db = Factory::getDbo();
$sql = "select count(*) from jos_eb_event_categories as d join jos_eb_categories as e on d.category_id=e.id join jos_mbwc_categoryextras as f on e.id=f.category_id where f.club_meeting=1 and d.event_id=".$this->item->id;
$db->setQuery($sql);
$this->item->club_meeting = $db->loadResult();

?>
<div id="eb-event-page" class="<?php echo implode(' ', $cssClasses); ?>">
	<div class="eb-box-heading <?php echo $clearfixClass; ?>">
		<<?php echo $hTag; ?> class="eb-page-heading">
			<?php
			echo $item->title;

			if ($this->config->get('show_print_button', '1') === '1' && !$this->print)
			{
				$uri = clone Uri::getInstance($this->url);
				$uri->setVar('tmpl', 'component');
				$uri->setVar('print', '1');
			?>
				<div id="pop-print" class="btn hidden-print">
					<a href="<?php echo $uri->toString();?> " rel="nofollow" target="_blank">
						<span class="<?php echo $iconPrint; ?>"></span>
					</a>
				</div>
			<?php
			}
			?>
		</<?php echo $hTag; ?>>
	</div>
	<div id="eb-event-details" class="eb-description">
		<?php
			// Facebook, twitter, Gplus share buttons
			if ($this->config->show_fb_like_button || $this->config->show_twitter_button)
			{
				echo $this->loadTemplate('share', ['socialUrl' => $socialUrl]);
			}

			if ($this->showTaskBar && in_array($this->config->get('register_buttons_position', 0), [1, 2]))
			{
			?>
				<div class="eb-taskbar eb-register-buttons-top <?php echo $clearfixClass; ?>">
					<ul>
						<?php echo $registerButtons; ?>
					</ul>
				</div>
			<?php
			}
		?>

		<div class="eb-description-details <?php echo $clearfixClass; ?>">
			<?php
				if ($this->config->get('show_image_in_event_detail', 1) && $this->config->display_large_image && !empty($item->image_url))
				{
				?>
					<img src="<?php echo $item->image_url; ?>" alt="<?php echo $item->image_alt ?: $item->title; ?>" class="eb-event-large-image img-polaroid"/>
				<?php
				}
				elseif ($this->config->get('show_image_in_event_detail', 1) && !empty($item->thumb_url))
				{
					EventbookingHelperJquery::colorbox('a.eb-modal');
				?>
					<a href="<?php echo $item->image_url; ?>" class="eb-modal"><img src="<?php echo $item->thumb_url; ?>" class="eb-thumb-left" alt="<?php echo $item->image_alt ?: $item->title; ?>"/></a>
				<?php
				}

				echo $item->description;
			?>
		</div>

		<div id="eb-event-info" class="<?php echo $bootstrapHelper->getClassMapping('row-fluid clearfix'); ?>">
			<?php
			if (!empty($this->items))
			{
				if (EventbookingHelperHtml::isLayoutOverridden('common/events_children.php'))
				{
					echo EventbookingHelperHtml::loadCommonLayout('common/events_children.php', ['items' => $this->items, 'config' => $this->config, 'Itemid' => $this->Itemid, 'nullDate' => $this->nullDate, 'ssl' => (int) $this->config->use_https, 'viewLevels' => $this->viewLevels, 'categoryId' => $this->item->category_id, 'bootstrapHelper' => $this->bootstrapHelper]);
				}
				else
				{
					// Prepare additional data needed by events_table_layout
					$this->categoryId = $this->item->category_id;
					$this->category = EventbookingHelperDatabase::getCategory($this->item->category_id);

					echo $this->loadCommonLayout('common/events_table_layout.php', ['displayChildrenEvents' => true]);
				}
			}
			else
			{
				$leftCssClass = 'span8';

				if (empty($this->rowGroupRates))
				{
					$leftCssClass = 'span12';
				}
				/*
				$params    = new Registry($item->custom_fields);
                if (!$params['field_address_lat'])
                {
                    $item->address1=trim(rawurldecode($item->paramData['field_address']['value']),' ');
                    if ($item->address1)
                    {
                        $melway=0;
                        $matches=null;
                        $resp=preg_match('/^[ ]*Mel[.: ]+(.*)$/',$item->address1,$matches);
                        if ($resp)
                        {
                            $item->address1=$matches[1];
                            $melway=1;
                        }
                        $response = @file_get_contents('https://online.melway.com.au/melway/php/MelwaySearchInfo.php?directory=Mel&search='.rawurlencode($item->address1),0, stream_context_create(["http"=>["timeout"=>10]]));
                        if ($response !== false && strpos($response,"syntax error") === FALSE)
                        {
                            $response = new SimpleXMLElement($response);
                            if ($response->marker[1]['COL3'] == $item->address1)
                            {
                               $poly=substr($response->marker[1]['COL4'],15,-3);
                                $polyArray=explode(',',$poly);
                                // average opposite sides
                                $poly1=explode(' ',$polyArray[0]);
                                $poly2=explode(' ',$polyArray[2]);
                                $item->address1 = ($poly1[1] + $poly2[1])/2 . ", ". ($poly1[0] + $poly2[0])/2;
                            }
                            else
                            {
                                if ($melway)
                                {
                                    $item->address1=null;
                                }
                            }
                        }
                        else
                        {
                            if ($melway)
                            {
                                $item->address1=null;
                            }
                        }
                    }
                }
                else
                {
                    $item->address1 = $params['field_address_lat'].",".$params['field_address_long'];
                }
                if (!$params['field_address_start_lat'])
                {
                    $item->address2=trim(rawurldecode($item->paramData['field_address_start']['value']),' ');
                    if ($item->address2)
                    {
                        $melway=0;
                        $matches=null;
                        $resp=preg_match('/^[ ]*Mel[.: ]+(.*)$/',$item->address2,$matches);
                        if ($resp)
                        {
                            $item->address2=$matches[1];
                            $melway=1;
                        }
                        $response = @file_get_contents('https://online.melway.com.au/melway/php/MelwaySearchInfo.php?directory=Mel&search='.rawurlencode($item->address2),0, stream_context_create(["http"=>["timeout"=>10]]));
                        if ($response !== false && strpos($response,"syntax error") === FALSE)
                        {
                            $response = new SimpleXMLElement($response);
                             if ($response->marker[1]['COL3'] ==$item->address2)
                            {
                                $poly=substr($response->marker[1]['COL4'],15,-3);
                                $polyArray=explode(',',$poly);
                                // average opposite sides
                                $poly1=explode(' ',$polyArray[0]);
                                $poly2=explode(' ',$polyArray[2]);
                                $item->address2 = ($poly1[1] + $poly2[1])/2 . ", ". ($poly1[0] + $poly2[0])/2;
                            }
                            else
                            {
                                if ($melway)
                                {
                                    $item->address2=null;
                                }
                            }
                        }
                        else
                        {
                            if ($melway)
                            {
                                $item->address2=null;
                            }
                        }
                    }
                }
                else
                {
                    $item->address2 = $params['field_address_start_lat'].",".$params['field_address_start_long'];
                } */
				if (!$item->club_meeting)
				{

			?>
				<div id="eb-event-info-left" class="<?php echo $bootstrapHelper->getClassMapping($leftCssClass); ?>">
					<h3 id="eb-event-properties-heading">
						<?php echo Text::_('EB_EVENT_PROPERTIES'); ?>
					</h3>
					<?php
					$layoutData = [
						'item'           => $this->item,
						'config'         => $this->config,
						'location'       => $item->location,
						'showLocation'   => true,
						'isMultipleDate' => false,
						'nullDate'       => $this->nullDate,
						'Itemid'         => $this->Itemid,
					];

					echo EventbookingHelperHtml::loadCommonLayout('common/event_properties.php', $layoutData);
					?>
				</div>
				<?php } ?>
                <div class="container">
                  <div class="row">
                <?php
                    $item->address1='';
                	if($item->address1)
                	{ ?>
                    <div class="col-sm-6">
                    	<h3>Map of car pool point</h3>
                    	<a class="btn btn-primary" href="https://www.google.com/maps/dir/?api=1&origin=My+Location&destination=<?php echo $item->address1 ?>">Directions to Car Pool Point</a><br>
                        <iframe src="https://maps.google.com/maps?q=<?php echo $item->address1;?>&z=15&output=embed" width="360" height="270" frameborder="0" style="border:0"></iframe>			
                    </div>
                	<?php 
                	}
                    $item->address2='';
                	if($item->address2)
                	{
                    	if ($item->club_meeting)
                    	{ ?>
                        <div class="col-sm-6">
                    	<h3>Location of Club Meeting</h3>
                    	<a class="btn btn-primary" href="https://www.google.com/maps/dir/?api=1&origin=My+Location&destination=<?php echo $item->address2 ?>">Directions to Club Meeting</a><br>
                     	    <?php } else { ?>
                    	<div class="col-sm-6">
                    	<h3>Map of walk starting point</h3>
                    	<a class="btn btn-primary" href="https://www.google.com/maps/dir/?api=1&origin=My+Location&destination=<?php echo $item->address2 ?>">Directions to Walk Start</a><br>
                    	    <?php } ?>
                    	<iframe src="https://maps.google.com/maps?q=<?php echo $item->address2;?>&z=15&output=embed" width="360" height="270" frameborder="0" style="border:0"></iframe>							
                   		</div>
                	<?php 
                    	    
                    	} ?>
                   </div>
                </div>


				<?php
				if (count($this->rowGroupRates))
				{
					echo $this->loadTemplate('group_rates');
				}
			}
			?>
		</div>
		<div class="<?php echo $clearfixClass; ?>"></div>
	<?php

	if ($this->config->show_location_info_in_event_details && $item->location && ($item->location->image || EventbookingHelper::isValidMessage($item->location->description)))
	{
		echo $this->loadTemplate('location', ['location' => $item->location]);
	}

	foreach ($this->horizontalPlugins as $plugin)
	{
	?>
		<h3 class="eb-horizontal-plugin-header<?php if (!empty($plugin['name'])) echo ' eb-plugin-' . $plugin['name']; ?>"><?php echo $plugin['title']; ?></h3>
	<?php
		echo $plugin['form'];
	}
	if ($this->config->display_ticket_types && !empty($item->ticketTypes))
	{
		echo EventbookingHelperHtml::loadCommonLayout('common/tickettypes.php', ['ticketTypes' => $item->ticketTypes, 'config' => $this->config, 'event' => $item]);
	?>
		<div class="<?php echo $clearfixClass; ?>"></div>
	<?php
	}

	echo EventbookingHelperHtml::loadCommonLayout('common/event_message.php', ['config' => $this->config, 'event' => $item]);

	if ($this->showTaskBar && in_array($this->config->get('register_buttons_position', 0), [0, 2])
	) {
		?>
		<div class="eb-taskbar eb-register-buttons-bottom <?php echo $clearfixClass; ?>">
			<ul>
				<?php
				if ($this->config->get('show_back_button', 1)) {
				?>
	                <li>
		                <a class="eb-button-button-link <?php echo $bootstrapHelper->getClassMapping('btn'); ?>" href="javascript: window.history.go(-1);"><?php echo Text::_('EB_BACK'); ?></a>
	                </li>
				<?php
				}
				echo $registerButtons;

				?>
			</ul>
		</div>
	<?php
	}

	if (count($this->plugins))
	{
		echo $this->loadTemplate('plugins');
	}

	if ($this->config->show_social_bookmark && !$this->print)
	{
		echo $this->loadTemplate('social_buttons', ['socialUrl' => $socialUrl]);
	}
    Factory::getApplication()->triggerEvent('onDisplayEvents', [[$item]]);?>
	</div>
</div>

<?php
Factory::getDocument()->addScriptDeclaration('
	function cancelRegistration(registrantId,waitlist)
	{
        var form = document.adminForm ;
        var pr = prompt("If you like, you can add the reason for your cancellation, and the leader will be notified. This is optional. Press cancel to back out of this action.\n\nReason (Optional):");
        if (pr === null) {
            return false;
        }
        form.reason.value = pr;
        form.option.value = "com_mbwc" ;
        form.controller.value = "registrant" ;
        form.task.value = "cancel_registration" ;
        form.waitlist.value = waitlist ;
        form.id.value = registrantId ;
        form.submit() ;
	}
	function cancelEvent(eventId)
	{
        var form = document.adminForm ;
        var pr = "";
        while (pr == "")
        {
          var pr = prompt("Please enter a Reason for cancelling this Event. Press the cancel button to back out of this action.\n\nReason (Required):");
        }
        if (pr === null) {
            return false;
        }
        form.reason.value = pr;
        form.task.value = "cancel_event" ;
        form.option.value = "com_mbwc" ;
        form.controller.value = "event" ;
        form.event_id.value = eventId ;
        form.return.value = "event" ;
        form.submit() ;
	}
    function unCancelEvent(eventId) {
        var form = document.adminForm ;
        var pr = prompt("If you like, you can add the reason for your un-cancellation, and all registrants will be informed. This is optional. Press cancel to back out of this action.\n\nReason (Optional):");
        if (pr === null) {
            return false;
        }
        form.reason.value = pr;
        form.task.value = "uncancel_event" ;
        form.option.value = "com_mbwc" ;
        form.controller.value = "event" ;
        form.event_id.value = eventId ;
        form.return.value = "event" ;
        form.submit() ;
    }
	
	');
?>
<form name="adminForm" id="adminForm" action="<?php echo Route::_('index.php?option=com_eventbooking&Itemid=' . $this->Itemid); ?>" method="post">
	<input type="hidden" name="task" value="" />
	<input type="hidden" name="controller" value="" />
	<input type="hidden" name="option" value="" />
	<input type="hidden" name="reason" value="" />
	<input type="hidden" name="waitlist" value="" />
	<input type="hidden" name="event_id" value="" />
	<input type="hidden" name="return" value="" />
	<input type="hidden" name="id" value="" />
	<?php echo HTMLHelper::_('form.token'); ?>
</form>

<script type="text/javascript">
	<?php
	if ($this->print)
	{
	?>
		window.print();
	<?php
	}
?>
</script>


