<?php
/**
 * @package        Joomla
 * @subpackage     Event Booking
 * @author         Tuan Pham Ngoc
 * @copyright      Copyright (C) 2010 - 2023 Ossolution Team
 * @license        GNU/GPL, see LICENSE.php
 */

defined('_JEXEC') or die;

use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Toolbar\Toolbar;
use MBWC\Component\MBWC\Site\Helper\MBWCHelper;
use Joomla\CMS\Uri\Uri;
use Joomla\CMS\Factory;
use Joomla\CMS\Toolbar\ToolbarHelper;

HTMLHelper::_('formbehavior.chosen', 'select');
$isJoomla4       = EventbookingHelper::isJoomla4();
$bootstrapHelper = EventbookingHelperBootstrap::getInstance();
$hiddenPhone     = $bootstrapHelper->getClassMapping('hidden-phone');
HTMLHelper::_('bootstrap.dropdown');
$return=base64_encode(Uri::getInstance()->toString());
EventbookingHelperModal::iframeModal('a.eb-colorbox-register-lists', 'eb-registrant-lists-modal');
EventbookingHelperModal::iframeModal('a.eb-colorbox-wait-lists', 'eb-registrant-lists-modal');
EventbookingHelperModal::iframeModal('a.eb-colorbox-approve-lists', 'eb-registrant-lists-modal');

	if ($this->input->getInt('hmvc_call'))
	{
		$hTag = 'h2';
	}
	else
	{
		$hTag = 'h1';
	}
?>
	<<?php echo $hTag; ?> class="eb-page-heading">My Submitted Events</<?php echo $hTag; ?>>
<?php
if (EventbookingHelper::isValidMessage($this->params->get('intro_text')))
{
?>
	<div class="eb-description eb-events-management-intro-text"><?php echo $this->params->get('intro_text');?></div>
<?php
}

Factory::getDocument()->addScriptDeclaration('
	function cancelRegistration(registrantId)
	{
        var form = document.adminForm ;
        var pr = prompt("If you like, you can add the reason for your cancellation, and the leader will be notified. This is optional. Press cancel to back out of this action.\n\nReason (Optional):");
        if (pr === null) {
            return false;
        }
        form.reason.value = pr;
        form.option.value = "com_mbwc" ;
        form.controller.value = "registrant" ;
        form.task.value = "cancel_registration" ;
        form.id.value = registrantId ;
        form.submit() ;
	}
	function cancelEvent(eventId)
	{
        var form = document.mbwcForm ;
        var pr = "";
        while (pr == "")
        {
          var pr = prompt("Please enter a Reason for cancelling this Event. Press the cancel button to back out of this action.\n\nReason (Required):");
        }
        if (pr === null) {
            return false;
        }
        form.reason.value = pr;
        form.task.value = "cancel_event" ;
        form.option.value = "com_mbwc" ;
        form.controller.value = "event" ;
        form.event_id.value = eventId ;
        form.return.value = "events" ;
        form.submit() ;
	}
    function unCancelEvent(eventId) {
        var form = document.mbwcForm ;
        var pr = prompt("If you like, you can add the reason for your un-cancellation, and all registrants will be informed. This is optional. Press cancel to back out of this action.\n\nReason (Optional):");
        if (pr === null) {
            return false;
        }
        form.reason.value = pr;
        form.task.value = "uncancel_event" ;
        form.option.value = "com_mbwc" ;
        form.controller.value = "event" ;
        form.event_id.value = eventId ;
        form.return.value = "events" ;
        form.submit() ;
    }

	');
?>
<form name="mbwcForm" id="mbwcForm" action="<?php echo Route::_('index.php?option=com_mbwc&Itemid=' . $this->Itemid); ?>" method="post">
	<input type="hidden" name="task" value="" />
	<input type="hidden" name="controller" value="" />
	<input type="hidden" name="option" value="" />
	<input type="hidden" name="reason" value="" />
	<input type="hidden" name="event_id" value="" />
	<input type="hidden" name="return" value="" />
	<input type="hidden" name="id" value="" />
	<?php echo HTMLHelper::_('form.token'); ?>
</form>

<div id="eb-events-manage-page" class="eb-container<?php if ($isJoomla4) echo ' eb-joomla4-container'; ?>">
	<div class="btn-toolbar" id="btn-toolbar">
		<?php echo Toolbar::getInstance('toolbar')->render(); ?>
	</div>
	<form method="post" name="adminForm" id="adminForm" action="<?php echo Route::_('index.php?option=com_eventbooking&view=events&Itemid=' . $this->Itemid);  ?>">
		<div class="filters btn-toolbar clearfix mt-2 mb-2">
			<?php echo $this->loadTemplate('search_bar'); ?>
		</div>
		<?php
		if(count($this->items))
		{
		?>
			<table style="width:100%" class="eb-responsive-table <?php echo $bootstrapHelper->getClassMapping('table table-striped table-bordered table-considered'); ?>">
				<thead>
					<tr>
						<th >
							<input type="checkbox" name="toggle" value="" onclick="Joomla.checkAll(this);" />
						</th>
						<th>
							<?php echo HTMLHelper::_('grid.sort', Text::_('EB_TITLE'), 'tbl.title', $this->state->filter_order_Dir, $this->state->filter_order); ?>
						</th>
						<th>
							Trip Report
						</th>
						<th>
							Incident Report
						</th>
						<th class="<?php echo $hiddenPhone; ?>">
							<?php echo Text::_('EB_CATEGORY'); ?>
						</th>
						<th class="center" >
							<?php echo HTMLHelper::_('grid.sort', Text::_('EB_EVENT_DATE'), 'tbl.event_date', $this->state->filter_order_Dir, $this->state->filter_order); ?>
						</th>
						<th style="width:10%" class="<?php echo $hiddenPhone; ?>">
							<?php echo Text::_('EB_NUMBER_REGISTRANTS'); ?>
						</th>
						<th style="width:10%" class="<?php echo $hiddenPhone; ?>">
							#Waitlist
						</th>
						<th  nowrap="nowrap">
							<?php echo HTMLHelper::_('grid.sort', Text::_('EB_STATUS'), 'tbl.published', $this->state->filter_order_Dir, $this->state->filter_order); ?>
						</th>
                        <?php if (MBWCHelper::isEventCoordinator()) { ?>
                        <th nowrap="nowrap">
                            <?php echo "Leader" ?>
                        </th>
                        <?php } ?>
					</tr>
				</thead>
				<tfoot>
					<tr>
						<td colspan="7">
							<div class="pagination"><?php echo $this->pagination->getPagesLinks(); ?></div>
						</td>
					</tr>
				</tfoot>
				<tbody>
					<?php
					$k      = 0;
					$Itemid = EventbookingHelper::getItemid();
					[$itemId, $layout] = EventbookingHelper::getAddEditEventFormLayout();

					for ($i = 0, $n = count($this->items); $i < $n; $i++)
					{
						$row      = $this->items[$i];
						$link     = Route::_(EventbookingHelperRoute::getEventRoute($row->id, $row->main_category_id, $Itemid) . '&layout=default');
						$checked  = HTMLHelper::_('grid.id', $i, $row->id);
                        $dateParts = explode(' ', $row->event_date) ;
            		    $startDate = strtotime($dateParts[0]) ;
                        $dateParts2 = explode(' ', $row->event_end_date) ;
            		    $endDate = strtotime($dateParts2[0]) ;
            		    if (!$endDate || $endDate == '0000-00-00 00:00:00')
            		    {
            		        $endDate=$startDate;
            		    }

						if (MBWCHelper::canChangeEventStatus($row->id))
						{
							$published = HTMLHelper::_('jgrid.published', $row->published, $i);
						}
						else
						{
							$published = $row->published ? Text::_('EB_PUBLISHED') : Text::_('EB_PENDING');
						}

						$canEditEvent = EventbookingHelperAcl::checkEditEvent($row->id);
						?>
						<tr class="<?php echo "row$k"; ?>">
							<td  data-content="Select">
								<?php echo $checked; ?>
							</td>
							<td data-content="Title" <?php if ($endDate <= strtotime(date('d-m-Y'))) echo 'style="background-color: #ADD8E6;"';?>>
								<a href="<?php echo $link; ?>" >
									<?php echo $row->title ; ?>
								</a>
                                <br>
                                   <?php
                            		$db = JFactory::getDbo();

                            		$sql = "select 1 from jos_mbwc_tripreports where event_id=".$row->id;
                            		$db->setQuery($sql);
                            		$hasTripReport = $db->loadResult();
                            		
                            		$sql = "select 1 from jos_eb_events as a join jos_eb_events as b on a.id=b.parent_id join jos_mbwc_tripreports as c on c.event_id=b.id where a.id=".$row->id;
                            		$db->setQuery($sql);
                            		$baseCampChildHasTripReport = $db->loadResult();

                            		$sql = "select count(*) from jos_eb_event_categories as d join jos_eb_categories as e on d.category_id=e.id join jos_mbwc_categoryextras as f on f.category_id=e.id where f.multiple_trip_reports=1 and d.event_id=".$row->id;
                            		$db->setQuery($sql);
                            		$multipleTripReports = $db->loadResult();
                            		
                            		$sql = "select count(*) from jos_eb_events as a where exists (select 1 from jos_eb_categories as e join jos_eb_event_categories as d on d.category_id=e.id join jos_mbwc_categoryextras as f on f.category_id=e.id where f.trip_report_required=1 and d.event_id=a.id) and not exists (select 1 from jos_eb_categories as e join jos_eb_event_categories as d on d.category_id=e.id join jos_mbwc_categoryextras as f on f.category_id=e.id where f.trip_report_required=0 and d.event_id=a.id) and a.id=".$row->id;
                            		$db->setQuery($sql);
                            		$requiresTripReport = $db->loadResult();
                            		?>
                                    <nav class="navbar navbar-expand navbar-light bg-light" style="--navbar-padding-y:0;width:max-content;">
                                  <div class="container-fluid" style="padding:0px;">
                                    <div class="collapse navbar-collapse" id="navbarEvents<?php echo $i;?>">
                                      <ul class="navbar-nav me-auto mb-2 mb-lg-0">
                                        <li class="nav-item">
                                  <?php 
                                    $isSuperUser = MBWCHelper::isSuperUser();
                                        $link = JRoute::_('index.php?option=com_eventbooking&view=event&id=' . $row->id . '&layout=' . $layout . '&Itemid=' . $this->Itemid.'&return='.$return, false);
                                    ?>
                                    <a class="button-edit btn btn-primary btn-sm" href="<?php echo $link?>">Edit/Copy Event</a>
                                    </li>
                                    <?php
                                    $link="";
                                    if ($row->published == 1)
					                {
                                        if (!$isSuperUser && $hasTripReport)
                                        {
                                            $link="javascript:alert('You cannot cancel an event after you have submitted the Trip Report.')";
                                        }
                                        else
                                        {
                                           $link = "javascript:cancelEvent(".$row->id.");";
                                        }
                                        ?>
                                    <li class="nav-item"  style="margin-left:5px;">
                                        <a class="btn btn-primary btn-sm" onclick="return confirm('Are you sure you want to cancel?')" href="<?php echo $link?>"><span class='icon-cancel' aria-hidden='true'></span>&nbsp;Cancel Event</a>
                                    </li> <?php
					                }
					                else if ($row->published == 2)
					                {
                                        $link = "javascript:unCancelEvent(".$row->id.");";
                                        $text = "Uncancel Event";
                                        echo "<li class='nav-item'><a class='btn btn-primary btn-sm' href='".$link."'><span class='icon-cancel' aria-hidden='true'></span>&nbsp;".$text."</a></li>";      
					                }

                                      $sql="select count(*) from jos_eb_registrants where event_id=".$row->id." and published=4";
                                      $db->setQuery($sql);
                                      $numUnapproved=$db->loadResult();
                                    if ($numUnapproved > 0 && $row->published == 1)
                                    {?>
                                  <li class="nav-item" style="margin-left:5px;">
                                       <a class="btn btn-danger btn-sm eb-colorbox-approve-lists" href="<?php echo Route::_('index.php?option=com_eventbooking&view=registrantlist&id=' . $row->id . '&tmpl=component'); ?>"
            						   >Visitors to Approve</a>
                                  </li><?php } ?>
                                        </ul>
                                         </div>
                                      </div>
                                    </nav>
							</td>
							<td data-content="Trip Report" <?php if ($endDate <= strtotime(date('d-m-Y'))) echo 'style="background-color: #ADD8E6;"';?>>
                                    <?php 
                                    if (!$requiresTripReport)
                                    {
                                        echo "Not Required";
                                    }
                                    else if ($startDate <= strtotime(date('d-m-Y')) && ($row->published ==1))
                                    {
                                        $link = JRoute::_('index.php?option=com_mbwc&view=tripreport&event_id='.$row->id.'&return='.$return) ;
                                        $classExtra=' btn-secondary';
                                        $btnText="Add Trip Report";
                                        if (($requiresTripReport > 0) && ((!$hasTripReport && !$multipleTripReports) || ($multipleTripReports > 0  && !$baseCampChildHasTripReport)) && $startDate > strtotime("2021-08-30") && $endDate <= strtotime(date('d-m-Y')))
                                        {
                                            $classExtra=' btn-warning';
                                        }
                                        if ($multipleTripReports)
                                        {
                                            $btnText="Add Basecamp Trip Report";
                                        }
                                        if ($hasTripReport)
                                        {
                                            $btnText="Edit Trip Report";
                                            $classExtra=' btn-info';
                                        }
                                        ?>
                                        <br class="d-block d-sm-none">
                                        <a class="btn btn-sm <?php echo $classExtra;?>" href="<?php echo $link; ?>"><?php echo $btnText;?></a>
                                        <?php
                                    }
                                    ?>
							
							</td>
							<td data-content="Incident Report" <?php if ($endDate <= strtotime(date('d-m-Y'))) echo 'style="background-color: #ADD8E6;"';?>>
                                    <?php 
                                    $sql = 'select id from #__mbwc_incident where event_id = '.$row->id.' and temporary = 1 limit 1';
    	                            $db->setQuery($sql) ;
    		                        $temporaryIncident = $db->loadResult();
                                    $sql = 'select count(*) from #__mbwc_incident where event_id = '.$row->id.' and temporary = 0';
    	                            $db->setQuery($sql) ;
    		                        $existingIncidents = $db->loadResult();
 
                                    if ($startDate <= strtotime(date('d-m-Y')) && ($row->published ==1))
                                    {
                                        if ($temporaryIncident)
                                        {
                                            $btnName="Edit & Send Incident Report";
                                            $classExtra=" btn-info";
                                            $link = JRoute::_('index.php?option=com_mbwc&view=incidentreport&event_id='.$row->id.'&return='.$return) ;
                                            echo '<a class="btn btn-sm '.$classExtra.'" href='. $link .'>'.$btnName.'</a>';
                                        }
                                        else
                                        {
                                            if ($existingIncidents)
                                            {
                                                $btnName="View Existing Incident Reports";
                                                $classExtra=" btn-secondary";
                                                $link = JRoute::_('index.php?option=com_mbwc&view=incidentreports&filter_event='.$row->id.'&return='.$return) ;
                                                echo '<a class="btn btn-sm '.$classExtra.'" href='. $link .'>'.$btnName.'</a>';
                                            }
                                            $btnName="Create New Incident Report";
                                            $classExtra=' btn-secondary';
                                            $link = JRoute::_('index.php?option=com_mbwc&view=incidentreport&event_id='.$row->id.'&return='.$return) ;
                                            echo '<a class="btn btn-sm '.$classExtra.'" href='. $link .'>'.$btnName.'</a>';

                                        }
                                    }
                                  ?>  
							</td>
							<td  data-content="Category" class="<?php echo $hiddenPhone; ?>" <?php if ($endDate <= strtotime(date('d-m-Y'))) echo 'style="background-color: #ADD8E6;"';?>>
								<?php echo $row->category_name ; ?>
							</td>
							<td  data-content="Event Date" class="center" <?php if ($endDate <= strtotime(date('d-m-Y'))) echo 'style="background-color: #ADD8E6;"';?>>
								<?php echo HTMLHelper::_('date', $row->event_date, $this->config->date_format, null); ?>
							</td>
							<td data-content="#Registrants" class="center <?php echo $hiddenPhone; ?>" <?php if ($endDate <= strtotime(date('d-m-Y'))) echo 'style="background-color: #ADD8E6;"';?>>
							    <?php echo (int) $row->total_registrants.' ' ; ?>
							 <?php if ($row->published !=0 && EventbookingHelper::canViewRegistrantList())
							 { ?>
						<a href="<?php echo Route::_('index.php?option=com_eventbooking&view=registrantlist&id=' . $row->id . '&tmpl=component'); ?>"
						   class="eb-colorbox-register-lists"><span class="view_list"><?php echo Text::_('EB_VIEW_LIST'); ?></span></a>
						   <?php 
							 }
						     ?>
								
                                     <nav class="navbar navbar-expand navbar-light bg-light" style="--navbar-padding-y:0;">
                                  <div class="container-fluid">
                                    <div class="collapse navbar-collapse" id="navbarRegistrants<?php echo $i;?>">
                                      <ul class="navbar-nav me-auto mb-2 mb-lg-0">
                                        <li class="nav-item dropdown">
                                          <a class="nav-link dropdown-toggle" style="color:unset;" href="#" id="navbarRegistrantsDropdown<?php echo $i;?>" role="button" data-bs-toggle="dropdown" aria-expanded="false">
                                           Action
                                          </a>
                                          <ul class="dropdown-menu" aria-labelledby="navbarRegistrantsDropdown<?php echo $i;?>">
                                  <?php
                                   if ((!$hasTripReport || $multipleTripReports) && ($endDate >= strtotime(date('d-m-Y'). ' - 3 days')))
                                   {
                                     if ($row->published == 1)
                                     {
                                        if ($row->total_registrants < $row->event_capacity)
                                        {
                                        ?>
                                            <li><a class="dropdown-item" href="index.php?option=com_mbwc&view=newregistrant&waitlist=0&from=events&event_id=<?php echo $row->id ?>" >Add Registrant</a></li>
                                         <?php
                                        }
                                        else
                                        {
                                            ?>
                                            <li><a class="dropdown-item" href="javascript:alert('Please add to Waitlist instead. Event is full')">Add Registrant</a></li>
                                            <?php
                                        }
                                    }
                                    else
                                    {
                                        ?>
                                        <li><a class="dropdown-item" href="javascript:alert('Please publish the event first.')">Add Registrant</a></li>
                                        <?php
                                    }
                                   }
                                    else
                                    {
                                        ?>
                                        <li><a class="dropdown-item" href="javascript:alert('You cannot add a registrant after you have submitted the Trip Report or if the event was over 3 days ago.')">Add Registrant</a></li>
                                        <?php
                                    }
                                    if ($row->published != 0)
                                    {
                                    ?>       
                                    <li><a class="dropdown-item" href="index.php?option=com_mbwc&view=mailregistrants&return=events&waitlist=0&event_id=<?php echo $row->id ?>&Itemid=<?php echo $this->Itemid?>" >Mail Registrants</a></li>
                                     <?php
                                    }
                                     if ($row->total_registrants && $row->published != 0 && EventbookingHelper::canExportRegistrants($row->id)) 
                					{
                    				?>
                    				    <li><a class="dropdown-item" href="<?php echo JRoute::_('index.php?option=com_eventbooking&task=registrant.export&event_id='.$row->id); ?>">Export Registrants</a></li>
                    				<?php	
                    				}
                                    ?>
                                          </ul>
                                        </div>
                                      </div>
                                    </nav>
							</td>
							<td data-content="#Waitlist" class="center <?php echo $hiddenPhone; ?>" <?php if ($endDate <= strtotime(date('d-m-Y'))) echo 'style="background-color: #ADD8E6;"';?>>
								<?php echo (int) MBWCHelper::countNumberWaitingList($row) ; ?>
								<?php
                                    if ($row->published !=0 && EventbookingHelper::canViewRegistrantList()) {
										?>
            						<a href="<?php echo Route::_('index.php?option=com_eventbooking&view=registrantlist&registrant_type=3&id=' . $row->id . '&tmpl=component'); ?>"
            						   class="eb-colorbox-wait-lists"><span class="view_list"><?php echo Text::_('EB_VIEW_LIST'); ?></span></a>
                                <?php
                                    } ?>
                                     <nav class="navbar navbar-expand navbar-light bg-light" style="--navbar-padding-y:0;">
                                  <div class="container-fluid">
                                    <div class="collapse navbar-collapse" id="navbarWaitlist<?php echo $i;?>">
                                      <ul class="navbar-nav me-auto mb-2 mb-lg-0">
                                        <li class="nav-item dropdown">
                                          <a class="nav-link dropdown-toggle" style="color:unset;" href="#" id="navbarWaitlistDropdown<?php echo $i;?>" role="button" data-bs-toggle="dropdown" aria-expanded="false">
                                           Action
                                          </a>
                                          <ul class="dropdown-menu" aria-labelledby="navbarWaitlistDropdown<?php echo $i;?>">
                                   <?php if (!$hasTripReport && $startDate >= strtotime(date('d-m-Y'). ' - 3 days'))
                                   {
                                    if ($row->published == 1)
                                    {
                                        if ($row->total_registrants >= $row->event_capacity)
                                        {
                                        ?>
                                            <li><a class="dropdown-item" href="index.php?option=com_mbwc&view=newregistrant&waitlist=1&from=events&event_id=<?php echo $row->id ?>">Add to Waitlist</a></li>
                                         <?php
                                        }
                                        else
                                        {
                                            ?>
                                            <li><a class="dropdown-item" href="javascript:alert('Please add Registrant instead. Event is not full')">Add to Waitlist</a></li>
                                            <?php
                                        }
                                    }
                                    else
                                    {
                                        ?>
                                        <li><a class="dropdown-item" href="javascript:alert('Please Publish the event first.')">Add to Waitlist</a></li>
                                        <?php
                                    }
                                   }
                                   else
                                   {
                                        ?>
                                        <li><a class="dropdown-item" href="javascript:alert('You cannot add to Waitlist after the Trip Report has been submitted or if the event was over 3 days ago.')">Add to Waitlist</a></li>
                                        <?php
                                    }
                                    ?>  
                                          </ul>
                                        </div>
                                      </div>
                                    </nav>
							</td>
							<td data-content="Status" class="center" <?php if ($endDate <= strtotime(date('d-m-Y'))) echo 'style="background-color: #ADD8E6;"';?>>
								<?php
									if ($row->published == 2)
									{
										echo Text::_('EB_CANCELLED');
									}
									else
									{
										echo $published;
									}
								?>
							</td>
                       <?php if (MBWCHelper::isEventCoordinator()) { ?>
                            <td data-content="Leader" <?php if ($endDate <= strtotime(date('d-m-Y'))) echo 'style="background-color: #ADD8E6;"';?>>
                                <?php echo str_replace(',', '<br/>', MBWCHelper::getLeaderName($row->id)); ?>
                            </td>
                        <?php } ?>
						</tr>
						<?php
						$k = 1 - $k;
					}
					?>
				</tbody>
			</table>
		<?php
		}
		?>
		<input type="hidden" name="task" id="task" value="" />
		<input type="hidden" name="boxchecked" value="0" />
		<input type="hidden" name="filter_order" value="<?php echo $this->state->filter_order; ?>" />
		<input type="hidden" name="filter_order_Dir" value="<?php echo $this->state->filter_order_Dir; ?>" />
   	    <input type="hidden" name="option" value="com_eventbooking" />

		<?php echo HTMLHelper::_('form.token'); ?>
	</form>
</div>