<?php
/**
 * @package            Joomla
 * @subpackage         Event Booking
 * @author             Tuan Pham Ngoc
 * @copyright          Copyright (C) 2010 - 2023 Ossolution Team
 * @license            GNU/GPL, see LICENSE.php
 */

defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Toolbar\Toolbar;
use Joomla\CMS\Uri\Uri;

EventbookingHelperJquery::validateForm();

if (EventbookingHelper::isJoomla4())
{
	$containerClass = ' eb-container-j4';
}
else
{
	$containerClass = '';
}

$format = 'Y-m-d';
$selectedState  = '';
$numberDecimals = (int) $this->config->get('decimals', 2);

$bootstrapHelper = EventbookingHelperBootstrap::getInstance();
$controlGroupClass   = $bootstrapHelper->getClassMapping('control-group');
$controlLabelClass   = $bootstrapHelper->getClassMapping('control-label');
$controlsClass       = $bootstrapHelper->getClassMapping('controls');
$rowFluid            = $bootstrapHelper->getClassMapping('row-fluid');
$formHorizontalClass = $bootstrapHelper->getClassMapping('form form-horizontal');
?>
<div class="eb-container<?php echo $containerClass; ?>">
	<div class="page-header">
		<h1 class="eb_title"><?php echo Text::_('EB_EDIT_REGISTRANT'); ?></h1>
	</div>
	<div class="btn-toolbar" id="btn-toolbar">
		<?php echo Toolbar::getInstance('toolbar')->render(); ?>
	</div>
	<form action="<?php echo Route::_('index.php?option=com_eventbooking&view=registrants&Itemid=' . $this->Itemid); ?>" method="post" name="adminForm" id="adminForm" class="<?php echo $formHorizontalClass; ?>">
		<div class="<?php echo $controlGroupClass; ?>">
			<div class="<?php echo $controlLabelClass; ?>">
				<?php echo Text::_('EB_EVENT'); ?>
			</div>
			<div class="<?php echo $controlsClass; ?>">
				<?php
					echo $this->event->title;
				?>
			</div>
		</div>
		<div class="<?php echo $controlGroupClass; ?>">
			<div class="<?php echo $controlLabelClass; ?>">
				<?php echo Text::_('EB_NUMBER_REGISTRANTS'); ?>
			</div>
			<div class="<?php echo $controlsClass; ?>">
				<?php
				if ($this->item->number_registrants)
				{
					echo $this->item->number_registrants;
				}
				else
				{
				?>
					<input class="form-control input-small validate[required,custom[number]]" type="text" name="number_registrants"
						   id="number_registrants" size="40" maxlength="250" value="1"/>
					<small><?php echo Text::_('EB_NUMBER_REGISTRANTS_EXPLAIN'); ?></small>
				<?php
				}
				?>
			</div>
		</div>

		<?php


		$fields = $this->form->getFields();

		if (isset($fields['state']))
		{
			$selectedState = $fields['state']->value;
		}

		if (isset($fields['email']))
		{
			$emailField = $fields['email'];
			$cssClass   = $emailField->getAttribute('class');
			$cssClass   = str_replace(',ajax[ajaxEmailCall]', '', $cssClass);
			$emailField->setAttribute('class', $cssClass);
		}

		foreach ($fields as $field)
		{
			/* @var RADFormField $field */

			// Dealing with group member record
			if ($this->item->group_id > 0)
			{
				if (empty($this->item->is_first_group_member) && $field->row->only_show_for_first_member)
				{
					continue;
				}

				if (empty($this->item->is_first_group_member) && $field->row->only_require_for_first_member)
				{
					$field->makeFieldOptional();
				}
			}

			if (($field->fee_field && !$this->canChangeFeeFields) || $this->disableEdit)
			{
				// Temp code while waiting for a more proper form-api
				$controlGroupAttributes = 'id="field_' . $field->name . '" ';

				if ($field->hideOnDisplay)
				{
					$controlGroupAttributes .= ' style="display:none;" ';
				}

				$class = '';

				if ($field->isMasterField)
				{
					if ($field->suffix)
					{
						$class = ' master-field-' . $field->suffix;
					}
					else
					{
						$class = ' master-field';
					}
				}
			?>
				<div class="<?php echo $controlGroupClass . $class; ?>" <?php echo $controlGroupAttributes; ?>>
					<div class="<?php echo $controlLabelClass; ?>">
						<?php echo $field->title; ?>
						<?php
						if ($field->row->required)
						{
						?>
							<span class="star">&#160;*</span>
						<?php
						}
						?>
					</div>
					<div class="<?php echo $controlsClass; ?>">
						<?php echo $field->getDisplayValue(); ?>
					</div>
				</div>
			<?php
			}
			else
			{
				echo $field->getControlGroup($bootstrapHelper);
			}
		}

		if ($this->item->published == 2 && (int) $this->item->registration_cancel_date)
		{
		?>
			<div class="<?php echo $controlGroupClass; ?>">
				<div class="<?php echo $controlLabelClass; ?>">
					<?php echo  Text::_('EB_REGISTRATION_CANCEL_DATE'); ?>
				</div>
				<div class="<?php echo $controlsClass; ?>">
					<?php echo HTMLHelper::_('date', $this->item->registration_cancel_date, $this->config->date_format . ' H:i'); ?>
				</div>
			</div>
		<?php
		}

		if ($this->item->id)
		{
		?>
            <div class="<?php echo $controlGroupClass; ?>">
                <div class="<?php echo $controlLabelClass; ?>">
			        <?php echo Text::_('EB_REGISTRATION_DATE'); ?>
                </div>
                <div class="<?php echo $controlsClass; ?>">
					<?php echo HTMLHelper::_('date', $this->item->register_date, $this->config->date_format . ' H:i'); ?>
                </div>
            </div>
        <?php
		}
		?>
		<!-- End members information -->
		<input type="hidden" name="option" value="com_eventbooking"/>
		<input type="hidden" name="id" value="<?php echo $this->item->id; ?>"/>
		<input type="hidden" name="task" value="registrant.save"/>		
		<input type="hidden" name="return" value="<?php echo $this->return; ?>"/>
		<?php echo HTMLHelper::_('form.token'); ?>
	</form>
</div>

<?php
HTMLHelper::_('behavior.core');
Factory::getDocument()->addScriptOptions('selectedState', $selectedState)
	->addScriptOptions('rootUri', Uri::root(true))
	->addScriptDeclaration(' var siteUrl = "' . EventbookingHelper::getSiteUrl() . '";');

EventbookingHelperHtml::addOverridableScript('media/com_eventbooking/js/site-registrant-default.min.js');

Text::script('EB_CANCEL_REGISTRATION_CONFIRM', true);
Text::script('EB_REFUND_REGISTRATION_CONFIRM', true);
