<?php
/**
 * @package            Joomla
 * @subpackage         Event Booking
 * @author             Tuan Pham Ngoc
 * @copyright          Copyright (C) 2010 - 2023 Ossolution Team
 * @license            GNU/GPL, see LICENSE.php
 */

defined('_JEXEC') or die;

use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Factory;
use MBWC\Component\MBWC\Site\Helper\MBWCHelper;
use Joomla\Registry\Registry;
use Joomla\CMS\Uri\Uri;

EventbookingHelperJquery::loadjQuery();

$return=base64_encode(Uri::getInstance()->toString());

    function getFieldsData($fields,$rows)
	{
		$fieldsData = [];

		if (count($rows) && count($fields))
		{
            $db = Factory::getDbo();
			$query = $db->getQuery(true)
				->select('id, encrypt_data, fieldtype')
				->from('#__eb_fields')
				->where('id IN (' . implode(',', $fields) . ')');
			$db->setQuery($query);
			$rowFields = $db->loadObjectList('id');

			$registrantIds = [];

			foreach ($rows as $row)
			{
				$registrantIds[] = $row->id;
			}

			$query->clear()
				->select('registrant_id, field_id, field_value')
				->from('#__eb_field_values')
				->where('registrant_id IN (' . implode(',', $registrantIds) . ')')
				->where('field_id IN (' . implode(',', $fields) . ')');
			$db->setQuery($query);
			$rowFieldValues = $db->loadObjectList();

			$config = EventbookingHelper::getConfig();

			foreach ($rowFieldValues as $rowFieldValue)
			{
				$fieldValue = $rowFieldValue->field_value;
				$rowField   = $rowFields[$rowFieldValue->field_id];

				if ($rowField->fieldtype == 'Date')
				{
					try
					{
						$dateTime   = new DateTime($fieldValue);
						$fieldValue = $dateTime->format($config->date_format);
					}
					catch (Exception $e)
					{
						$fieldValue = $rowFieldValue->field_value;
					}
				}
				elseif (is_string($fieldValue) && is_array(json_decode($fieldValue)))
				{
					$fieldValue = implode(', ', json_decode($fieldValue));
				}
				elseif ($rowField->fieldtype == 'Text' && $rowField->encrypt_data && $fieldValue)
				{
					$fieldValue = EventbookingHelperCryptor::decrypt($fieldValue);
				}

				$fieldsData[$rowFieldValue->registrant_id][$rowFieldValue->field_id] = $fieldValue;
			}

			// Get data from core fields
			$query->clear()
				->select('id, name')
				->from('#__eb_fields')
				->where('id IN (' . implode(',', $fields) . ')')
				->where('is_core = 1');
			$db->setQuery($query);
			$coreFields = $db->loadObjectList();

			if (count($coreFields))
			{
				foreach ($rows as $row)
				{
					foreach ($coreFields as $coreField)
					{
						$fieldsData[$row->id][$coreField->id] = $row->{$coreField->name};
					}
				}
			}
		}

		return $fieldsData;
	}


$hiddenPhoneClass = $this->bootstrapHelper->getClassMapping('hidden-phone');
$cols = 1;
$this->state->registrant_type == 3;

if ($this->state->registrant_type == 3)
{
    $this->waitlist = 1;
	$pageHeading = Text::_('EB_WAITING_LIST');
}
else
{
    $this->waitlist = 0;
	$pageHeading = Text::_('EB_REGISTRANT_LIST');
}
$user = Factory::getUser();
$userId = $user->get('id');

$pageHeading = str_replace('[EVENT_TITLE]', $this->event->title, $pageHeading);
$db = Factory::getDbo();
$this->params = new Registry($this->event->custom_fields);

$sql = "select name from jos_eb_categories where id = " .$this->event->main_category_id;
$db->setQuery($sql);
$this->category_name=$db->loadResult();

$sql = "select name from jos_users as a join jos_eb_events as b on a.id = json_extract(b.custom_fields,'$.field_leader_id1') where b.id = " .$this->event->id;
$db->setQuery($sql);
$this->leader_name=$db->loadResult();

$sql = ' select * FROM #__eb_registrants WHERE event_id=' . $this->event->id .' AND is_group_billing=0 AND published in (2,6,7,8) order by registration_cancel_date desc';
$db->setQuery($sql);
$this->cancelled = $db->loadObjectList();

$sql = "select 1 from jos_mbwc_tripreports where event_id=".$this->event->id;
$db->setQuery($sql);
$this->hasTripReport = $db->loadResult();
?>
<script language="javascript">
    function cancelRegistration(registrantId, waitlist) {
        var form = document.adminForm ;
        var pr = prompt("The visitor will be notified of this cancellation. If you like, you can add the reason for your cancellation. This is optional. Press cancel to back out of this action.\n\nReason (Optional):");
        if (pr === null) {
            return false;
        }
        form.reason.value = pr;
        form.option.value = 'com_mbwc' ;
        form.controller.value = 'registrant' ;
        form.task.value = 'cancel_visitor' ;
        form.waitlist.value = waitlist ;
        form.id.value = registrantId ;
        form.return.value = '<?php echo $return; ?>' ;
        form.submit() ;
    }
    function leaderCancelRegistration(eventId, registrantId, waitlist) {
        var form = document.adminForm ;
        var pr="";
        pr = prompt("Add an optional reason for the cancellation. Mail is not sent for this action. \n\nReason (Optional):");
        if (pr === null) {
            return false;
        }
        form.reason.value = pr;
        form.option.value = 'com_mbwc' ;
        form.controller.value = 'registrant' ;
        form.task.value = 'delete_registrant' ;
        form.waitlist.value = waitlist ;
        form.id.value = eventId ;
        form.return.value = '<?php echo $return; ?>' ;
        form.registrant_id.value = registrantId ;
        form.submit() ;
    }

</script>
<style type="text/css" media="print">
@media print {
    a:after { content:''; }
    a[href]:after { content: none !important; }
    table td:last-child {display:none}
    table th:last-child {display:none}
   }
</style>

<form action="<?php echo JRoute::_('index.php?option=com_mbwc&Itemid=' . $this->Itemid);  ?>" method="post" name="adminForm"  id="adminForm">
    	<input type="hidden" name="task" value="" />
		<input type="hidden" name="controller" value="" />
		<input type="hidden" name="option" value="" />
		<input type="hidden" name="id" value="" />
		<input type="hidden" name="registrant_id" value="" />
		<input type="hidden" name="reason" value="" />
		<input type="hidden" name="waitlist" value="" />
		<input type="hidden" name="return" value="" />

</form>
<?php

if (!$this->input->getInt('hmvc_call'))
{
?>
<div id="eb-registrants-list-page" class="eb-container">
	<h1 class="eb_title"><?php echo $pageHeading." for ".$this->event->title. " - ". HTMLHelper::_('date', $this->event->event_date, $this->config->event_date_format, null)." - Leader: ".$this->leader_name ." - Distance: ".$this->params['field_distance']."km - Category: ".$this->category_name ; ?></h1> 
<?php
}
$this->event_owner=0;
if (count($this->items))
{
	$showNumberRegistrants = false;
	
	if (MBWCHelper::isLeader($this->event->id) || MBWCHelper::isSecretary($this->event->id) || MBWCHelper::isEventCoordinator($this->event->id))
	{
	    $this->event_owner=1;
	}
	$sql = "select 1 from jos_user_usergroup_map where (group_id = 30 or group_id = 8) and user_id = " .$userId;
	$db->setQuery($sql);
	$this->club_contact=$db->loadResult();
	$sql = "select a.name, b.cb_mobphone from jos_users a, jos_comprofiler b where a.id in (select user_id from jos_user_usergroup_map where group_id in (select id from jos_usergroups where title='President')) and b.user_id=a.id limit 1";
	$db->setQuery($sql);
	$this->president = $db->loadObject();
	$sql = "select a.name, b.cb_mobphone from jos_users a, jos_comprofiler b where a.id in (select user_id from jos_user_usergroup_map where group_id in (select id from jos_usergroups where title='Secretary')) and b.user_id=a.id limit 1";
	$db->setQuery($sql);
	$this->secretary = $db->loadObject();
	
	$sql = "select a.name, b.cb_mobphone from jos_users a, jos_comprofiler b where a.id in (select user_id from jos_user_usergroup_map where group_id in (select id from jos_usergroups where title='Trip Emergency Contact')) and b.user_id=a.id";
	$db->setQuery($sql);
	$this->club_contacts = $db->loadObjectList();


	foreach($this->items as $item)
	{
		if ($item->number_registrants > 1)
		{
			$showNumberRegistrants = true;
			$cols++;
			break;
		}
	}

	if (in_array('last_name', $this->coreFields))
	{
		$cols++;
		$showLastName = true;
	}
	else
	{
		$showLastName = false;
	}

	if ($this->config->get('public_registrants_list_show_number_registrants', '') !== '')
	{
		$showNumberRegistrants = (bool) $this->config->get('public_registrants_list_show_number_registrants');
	}

	$showTickets = $this->config->get('public_registrants_list_show_ticket_types') && count($this->tickets);
?>
	<table id="eb-registrants-list-table" class="eb-registrants-list-table <?php echo $this->bootstrapHelper->getClassMapping('table table-striped table-bordered table-condensed'); ?> eb-responsive-table">
	<thead>
		<tr>
            <?php
				if ($this->config->get('public_registrants_list_show_num', 1))
				{
				?>
                    <th width="5" class="myhidden <?php echo $hiddenPhoneClass; ?> eb-rl-num-column">
		                <?php echo Text::_('NUM'); ?>
                    </th>
                <?php
					$cols++;
				}
				if ($this->event_owner == 1)
				{ ?>
			<th class="eb-rl-status-column">
			Status
			</th>				
			<?php
				}
			?>
			<th class="eb-rl-first-name-column">
				Name
			</th>
                <?php
				if ($showNumberRegistrants)
				{
				?>
					<th class="eb-rl-number-registrants-column">
						<?php echo Text::_('EB_REGISTRANTS'); ?>
					</th>
				<?php
				}

				if ($showTickets)
				{
					$cols++;
				?>
					<th class="eb-rl-tickets-column">
						<?php echo Text::_('EB_TICKETS'); ?>
					</th>
				<?php
				}

				if ($this->config->get('public_registrants_list_show_register_date', 1))
				{
					$cols++;
				?>
					<th class="eb-rl-register-date-column <?php echo $hiddenPhoneClass; ?> d-print-none">
						<?php echo Text::_('EB_REGISTRATION_DATE'); ?>
					</th>
				<?php
				}

				if ($this->displayCustomField)
				{
					foreach($this->fields as $fieldId)
					{
   					    if ($this->fieldTitles[$fieldId] !== "Mobile Phone" && 
   					        $this->fieldTitles[$fieldId] !== "Cancel Reason" && 
   					        $this->fieldTitles[$fieldId] !== "First-aid Level" && 
   					        $this->fieldTitles[$fieldId] !== "Emergency Contact or Next of Kin Mobile Phone Number" &&
   					        $this->fieldTitles[$fieldId] !== "Emergency Contact or Next of Kin Home Phone Number" &&
   					        ($this->fieldTitles[$fieldId] === "Phone" || $this->event_owner === 1))
					    {
						    $cols++;
					?>
						<th class="eb-rl-field<?php echo $fieldId; ?>-column <?php if ($this->fieldTitles[$fieldId] != "Phone") echo "myhidden ".$hiddenPhoneClass;?>">
							<?php 
							if (strpos($this->fieldTitles[$fieldId],"medical")) { echo "Medical"; } 
							elseif (strpos($this->fieldTitles[$fieldId],"drive")) { echo "Drive?"; } 
							elseif (strpos($this->fieldTitles[$fieldId],"Kin Name")) { echo "Next of Kin"; }
							else { echo $this->fieldTitles[$fieldId] ; } ?>
						</th>
					<?php	
					    }
					}
				}

				if ($this->config->get('public_registrants_list_show_registration_status', 0))
				{
					$cols++;
				?>
					<th class="eb-rl-registration-status-column">
						<?php echo Text::_('EB_REGISTRATION_STATUS'); ?>
					</th>
				<?php
				}
			?>
					<th class="eb-rl-registration-action-column">
					Action
					</th>

		</tr>
	</thead>
		<tfoot>
			<tr>
				<?php
				if ($this->pagination->total > $this->pagination->limit)
				{
				?>
					<td colspan="<?php echo $cols; ?>">
						<div class="pagination"><?php echo $this->pagination->getPagesLinks();?></div>
					</td>
				<?php
				}
				?>
			</tr>
		</tfoot>
	<tbody>
	<?php
	for ($i = 0, $n = count($this->items); $i < $n; $i++)
	{
		$row = $this->items[$i];
		?>
		<tr>
            <?php
			if ($this->config->get('public_registrants_list_show_num', 1))
			{
			?>
                <td class="myhidden <?php echo $hiddenPhoneClass; ?>">
		            <?php echo $this->pagination->getRowOffset($i); ?>
                </td>
            <?php
			}
				if ($this->event_owner == 1)
                {?>
			<td  class="tdno<?php echo $i; ?>" data-content="Status">					
					<?php if ($row->user_id == 0 && $row->group_id == 0) {
					     if ($row->published >3) echo "Unapproved "; 
					     echo "Visitor";
					   }
					   else if ($row->group_id != 0 && $row->user_id==0) 
					     echo "Group Visitor"; 
					   else if ($row->group_id != 0 && $row->user_id!=0) echo "Group Member"; 
					   else echo "Member"; ?>					
			</td>			
			<?php
				}
			?>
			<td class="tdno<?php echo $i; ?>" data-content="<?php echo Text::_('EB_FIRST_NAME'); ?>">
					<?php echo $row->first_name.' '.$row->last_name ?>
			</td>
			<?php
				if ($showNumberRegistrants)
				{
				?>
					<td class="tdno<?php echo $i; ?>" data-content="<?php echo Text::_('EB_REGISTRANTS'); ?>">
						<?php echo $row->number_registrants ; ?>
					</td>
				<?php
				}

				if ($showTickets)
				{
					$ticketsOutput = [];

					if (!empty($this->tickets[$row->id]))
					{
						$tickets = $this->tickets[$row->id];

						foreach ($this->ticketTypes as $ticketType)
						{
							if (!empty($tickets[$ticketType->id]))
							{
								$ticketsOutput[] = Text::_($ticketType->title) . ': ' . $tickets[$ticketType->id];
							}
						}
					}

					$ticketsOutput = implode('<br />', $ticketsOutput);
				?>
					<td class="tdno<?php echo $i; ?>" data-content="<?php echo Text::_('EB_TICKETS'); ?>">
						<?php echo $ticketsOutput; ?>
					</td>
				<?php
				}

				if ($this->config->get('public_registrants_list_show_register_date', 1))
				{
				?>
					<td class="tdno<?php echo $i; ?> <?php echo $hiddenPhoneClass; ?> d-print-none" data-content="<?php echo Text::_('EB_REGISTRATION_DATE'); ?>">
						<?php echo HTMLHelper::_('date', $row->register_date, $this->config->date_format) ; ?>
					</td>
				<?php
				}

				if ($this->displayCustomField)
				{
				    $mobile="";
				    $home="";
				    $level="";
				    $nokmobile="";
				    $nokhome="";
					foreach($this->fields as $fieldId)
					{
   					    if ($this->fieldTitles[$fieldId] === "Mobile Phone")
					    {
					        if (isset($this->fieldValues[$row->id][$fieldId]) && $this->fieldValues[$row->id][$fieldId])
					        {
	                           $mobile=$this->fieldValues[$row->id][$fieldId];
					        }
	                    }
   					    if ($this->fieldTitles[$fieldId] === "Phone")
					    {
					        if (isset($this->fieldValues[$row->id][$fieldId]) && $this->fieldValues[$row->id][$fieldId])
					        {
	                           $home=$this->fieldValues[$row->id][$fieldId];
					        }
	                    }
  					    if ($this->fieldTitles[$fieldId] === "First-aid Level")
					    {
					        if (isset($this->fieldValues[$row->id][$fieldId]) && $this->fieldValues[$row->id][$fieldId])
					        {
	                            $level=$this->fieldValues[$row->id][$fieldId];
					        }
					    }
  					    if ($this->fieldTitles[$fieldId] === "Emergency Contact or Next of Kin Mobile Phone Number")
					    {
					        if (isset($this->fieldValues[$row->id][$fieldId]) && $this->fieldValues[$row->id][$fieldId])
					        {
	                            $nokmobile=$this->fieldValues[$row->id][$fieldId];
					        }
					    }
  					    if ($this->fieldTitles[$fieldId] === "Emergency Contact or Next of Kin Home Phone Number")
					    {
					        if (isset($this->fieldValues[$row->id][$fieldId]) && $this->fieldValues[$row->id][$fieldId])
					        {
	                            $nokhome=$this->fieldValues[$row->id][$fieldId];
					        }
					    }
					}
					foreach($this->fields as $fieldId)
					{
   					    if ($this->fieldTitles[$fieldId] === "Phone")
					    {
	                        if (isset($mobile) && $mobile)
	                        {
					            $this->fieldValues[$row->id][$fieldId]=$mobile;
	                        }
	                        else if (isset($home) && $home)
	                        {
	                            $this->fieldValues[$row->id][$fieldId]=$home;
	                        }
					    }
  					    if ($this->fieldTitles[$fieldId] === "First-aid")
					    {
	                        if (isset($level) && $level)
	                        {
	                            if (isset($this->fieldValues[$row->id][$fieldId]) && $this->fieldValues[$row->id][$fieldId])
	                            {
					                $this->fieldValues[$row->id][$fieldId].= " ". $level;
	                            }
	                            else
	                            {
	                                $this->fieldValues[$row->id][$fieldId] = $level;
	                            }
	                        }
					    }
 					    if ($this->fieldTitles[$fieldId] === "Emergency Contact or Next of Kin Name")
					    {
	                        if (isset($nokmobile) && $nokmobile)
	                        {
	                            if (isset($this->fieldValues[$row->id][$fieldId]) && $this->fieldValues[$row->id][$fieldId])
	                            {
					                $this->fieldValues[$row->id][$fieldId].= "<br>". $nokmobile;
	                            }
	                            else
	                            {
	                                $this->fieldValues[$row->id][$fieldId] = $nokmobile;
	                            }
	                        }
	                        else if (isset($nokhome) && $nokhome)
	                        {
	                            if (isset($this->fieldValues[$row->id][$fieldId]) && $this->fieldValues[$row->id][$fieldId])
	                            {
					                $this->fieldValues[$row->id][$fieldId].= "<br>". $nokhome;
	                            }
	                            else
	                            {
	                                $this->fieldValues[$row->id][$fieldId] = $nokhome;
	                            }
	                            
	                        }
					    }
					}
					foreach($this->fields as $fieldId)
					{
						if (isset($this->fieldValues[$row->id][$fieldId]) && $this->fieldValues[$row->id][$fieldId])
						{
							$fieldValue = $this->fieldValues[$row->id][$fieldId];
						}
						else
						{
							$fieldValue = '';
						}

   					    if ($this->fieldTitles[$fieldId] !== "Mobile Phone" && 
   					        $this->fieldTitles[$fieldId] !== "First-aid Level" && 
   					        $this->fieldTitles[$fieldId] !== "Cancel Reason" && 
   					        $this->fieldTitles[$fieldId] !== "Emergency Contact or Next of Kin Mobile Phone Number" &&
   					        $this->fieldTitles[$fieldId] !== "Emergency Contact or Next of Kin Home Phone Number" &&
   					        ($this->fieldTitles[$fieldId] === "Phone" || $this->event_owner === 1))
					    {
					?>
						<td class="tdno<?php echo $i; ?> <?php if ($this->fieldTitles[$fieldId] != 'Phone') echo $hiddenPhoneClass;?>" data-content="<?php echo $this->fieldTitles[$fieldId]; ?>">
							<?php 
							if (strpos($fieldValue,"drive direct")) { echo "Drive direct"; }
							elseif (strpos($fieldValue,"organized lift")) { echo "Organized lift"; }
							elseif (strpos($fieldValue,"drive and take")) { echo "Drive+Take"; }
							elseif (strpos($fieldValue,"convoy")) { echo "Convoy"; }
							elseif (strpos($fieldValue,"not drive")) { echo "Carpool"; }
							else { echo $fieldValue ; } 
							?>
						</td>
					<?php	
					    }
					?>
						</td>
					<?php
					}
				}

				if ($this->config->get('public_registrants_list_show_registration_status', 0))
				{
				?>
					<td class="tdno<?php echo $i; ?>" data-content="<?php echo Text::_('EB_REGISTRATION_STATUS'); ?>">
						<?php
							switch ($row->published)
							{
								case 0 :
									echo Text::_('EB_PENDING');
									break ;
								case 1 :
									echo Text::_('EB_PAID');
									break ;
								case 2 :
									echo Text::_('EB_CANCELLED');
									break;
								case 4:
									echo Text::_('EB_WAITING_LIST_CANCELLED');
									break;
								case 3:
									echo Text::_('EB_WAITING_LIST');
									break;
							}
						?>
					</td>
				<?php
				}
               ?> <td>
                    <a class="non-close-button btn btn-sm btn-outline-secondary" id="mail" title="Mail" href="<?php echo JRoute::_('index.php?option=com_mbwc&view=mailmember&tmpl=component&registrant_id='.$row->id.'&waitlist='.$this->waitlist.'&Itemid='.$this->Itemid);?>" >Mail</a>
                 <?php 
                $showUserEdit =  ($row->user_id && $userId == $row->user_id);
                if ($showUserEdit)
                { ?>
                       <a class="non-close-button btn btn-sm btn-outline-secondary" title="Edit" href="<?php echo JRoute::_('index.php?option=com_eventbooking&view=registrant&tmpl=component&id='.$row->id.'&Itemid='.$this->Itemid.'&return='.$return); ?>"><?php echo '<i class="icon-pencil"></i>' ; ?></a>
                <?php
                }
				if ($this->event_owner == 1)
                { 
                    $isSuperUser = MBWCHelper::isSuperUser();
                    if ($isSuperUser || (!$this->hasTripReport && $this->event->published == 1))
                    {
                        if ($this->waitlist && $i==0) 
                        { ?>
                            <a class="btn btn-primary non-close-button" title="Promote" href="<?php echo JRoute::_('index.php?option=com_mbwc&controller=registrant&task=promote&id='.$row->event_id.'&registrant_id='.$row->id.'&waitlist='.$this->waitlist); ?>">Promote</a>
                  <?php }
                        if ($row->published ==4) { ?>
                            <a class="btn btn-sm btn-danger non-close-button" title="Approve" href="<?php echo JRoute::_('index.php?option=com_mbwc&controller=registrant&task=approve_visitor&id='.$row->event_id.'&registrant_id='.$row->id.'&waitlist='.$this->waitlist); ?>">Approve</a>
                   <?php } 
                        if (!$showUserEdit)
                        { ?>
                        <a class="non-close-button btn btn-sm btn-outline-secondary" title="Edit" href="<?php echo JRoute::_('index.php?option=com_eventbooking&view=registrant&tmpl=component&id='.$row->id.'&Itemid='.$this->Itemid.'&return='.$return); ?>"><?php echo '<i class="icon-pencil"></i>' ; ?></a>
              <?php     } 
                    } ?>
                    <a class="non-close-button btn btn-sm btn-outline-secondary" title="View Registrants walks" href="<?php echo JRoute::_('index.php?option=com_mbwc&view=history&reg_id='.$row->id.'&tmpl=component')?>" rel="gb_page_fs[<?php echo 200; ?>, <?php echo 200; ?>]" ><i class="icon-eye-open"></i></a>                    
                    <?php if ($isSuperUser || (!$this->hasTripReport && $this->event->published == 1))
                      { 
                        if ($row->user_id !=0) {
		                    $db = Factory::getDbo();			
                          	$sql = "select 1 from jos_eb_events as a where ((json_extract(a.custom_fields,'$.field_leader_id1') = ".$row->user_id." 
                          	and (json_extract(a.custom_fields,'$.field_leader_id2') is null or json_extract(a.custom_fields,'$.field_leader_id2') = 0 or json_extract(a.custom_fields,'$.field_leader_id2') = '') 
                          	and (json_extract(a.custom_fields,'$.field_leader_id3') is null or json_extract(a.custom_fields,'$.field_leader_id3') = 0 or json_extract(a.custom_fields,'$.field_leader_id3') = '')) or 
                          	(json_extract(a.custom_fields,'$.field_leader_id2') = ".$row->user_id." and (json_extract(a.custom_fields,'$.field_leader_id1') is null or json_extract(a.custom_fields,'$.field_leader_id1') = 0 or json_extract(a.custom_fields,'$.field_leader_id1') = '') 
                          	and (json_extract(a.custom_fields,'$.field_leader_id3') is null or json_extract(a.custom_fields,'$.field_leader_id3') = 0 or json_extract(a.custom_fields,'$.field_leader_id3') = '')) or (json_extract(a.custom_fields,'$.field_leader_id3') = ".$row->user_id." 
                          	and (json_extract(a.custom_fields,'$.field_leader_id2') is null or json_extract(a.custom_fields,'$.field_leader_id2') = 0 or json_extract(a.custom_fields,'$.field_leader_id2') = '') 
                          	and (json_extract(a.custom_fields,'$.field_leader_id1') is null or json_extract(a.custom_fields,'$.field_leader_id1') = 0 or json_extract(a.custom_fields,'$.field_leader_id1') = ''))) and id = ".$row->event_id;
		                    $db->setQuery($sql);
		                    $db->setQuery($sql);
		                    $onlyLeader = $db->loadResult();

                          if (($row->user_id != $userId) && !$onlyLeader) { ?>
                           <a class="btn btn-sm btn-outline-secondary non-close-button" title="Cancel (For leaders to cleanup)" href="javascript:leaderCancelRegistration(<?php echo $row->event_id.','.$row->id.','.$this->waitlist?>)">Cancel (For leaders to cleanup)</a>
                  <?php } } else { ?>
                           <a class="btn btn-sm btn-outline-secondary non-close-button" title="Cancel" href="javascript:cancelRegistration(<?php echo $row->id.','.$this->waitlist;?>)"><?php echo 'Cancel Visitor' ; ?></a>
                  <?php } 
                      }
                     } ?>
               </td>
               <?php
				
	        } 
			?>
		</tr>
	</tbody>
</table>
    <?php
    if (count($this->cancelled) && $this->state->registrant_type != 3 && $this->event_owner == 1) 
    {
        $cols=2;
        $fields=[];
        $rowFields = EventbookingHelperRegistration::getAllPublicEventFields($this->event->id);
		foreach ($rowFields as $rowField)
		{
			if (in_array($rowField->name, ['first_name', 'last_name']))
			{
				continue;
			}

			$fields[]                   = $rowField->id;
		}
 		$this->fieldValues = getFieldsData($fields,$this->cancelled);
       

    ?>
    <h2 id="cancelheading">Cancelled Registrants</h2>
	<table id="mycancelled" class="eb-registrants-list-table <?php echo $this->bootstrapHelper->getClassMapping('table table-striped table-bordered table-condensed'); ?> eb-responsive-table">
	<thead>
		<tr>
            <?php
				if ($this->config->get('public_registrants_list_show_num', 1))
				{
				?>
                    <th width="5" class="myhidden <?php echo $hiddenPhoneClass; ?> eb-rl-num-column">
		                <?php echo Text::_('NUM'); ?>
                    </th>
                <?php
					$cols++;
				}
				if ($this->event_owner == 1)
				{ ?>
			<th width="5">
			Status
			</th>				
			<?php
				}
			?>
			<th class="eb-rl-first-name-column">
				Name
			</th>
                <?php
				if ($showNumberRegistrants)
				{
				?>
					<th class="eb-rl-number-registrants-column">
						<?php echo Text::_('EB_REGISTRANTS'); ?>
					</th>
				<?php
				}

				if ($showTickets)
				{
					$cols++;
				?>
					<th class="eb-rl-tickets-column">
						<?php echo Text::_('EB_TICKETS'); ?>
					</th>
				<?php
				}

				if ($this->config->get('public_registrants_list_show_register_date', 1))
				{
					$cols++;
				?>
					<th class="eb-rl-register-date-column <?php echo $hiddenPhoneClass; ?> d-print-none">
						<?php echo Text::_('EB_REGISTRATION_DATE'); ?>
					</th>
				<?php
				}
				$cols++;
				?>
					<th class="eb-rl-cancel-date-column">
						Cancelled Date
					</th>
				<?php

				if ($this->displayCustomField)
				{
					foreach($this->fields as $fieldId)
					{
   					    if ($this->fieldTitles[$fieldId] !== "Mobile Phone" && 
   					        $this->fieldTitles[$fieldId] !== "First-aid Level" && 
   					        $this->fieldTitles[$fieldId] !== "First-aid" && 
					        $this->fieldTitles[$fieldId] !== "Emergency Contact or Next of Kin Mobile Phone Number" &&
					        $this->fieldTitles[$fieldId] !== "Emergency Contact or Next of Kin Name" &&
					        strpos($this->fieldTitles[$fieldId],"medical") === false &&
					        $this->fieldTitles[$fieldId] !== "Are you willing to drive?" &&
   					        $this->fieldTitles[$fieldId] !== "Emergency Contact or Next of Kin Home Phone Number")
					    {
						    $cols++;
					?>
						<th class="eb-rl-field<?php echo $fieldId; ?>-column <?php if ($this->fieldTitles[$fieldId] != "Phone") echo $hiddenPhoneClass;?>">
							<?php 
							echo $this->fieldTitles[$fieldId] ; ?>
						</th>
					<?php	
					    }
					}
				}

				if ($this->config->get('public_registrants_list_show_registration_status', 0))
				{
					$cols++;
				?>
					<th class="eb-rl-registration-status-column">
						<?php echo Text::_('EB_REGISTRATION_STATUS'); ?>
					</th>
				<?php
				}
			?>
					<th class="eb-rl-registration-actions-column">
					Actions
					</th>
		</tr>
	</thead>
		<tfoot>
			<tr>
				<?php
				if ($this->pagination->total > $this->pagination->limit)
				{
				?>
					<td colspan="<?php echo $cols; ?>">
						<div class="pagination"><?php echo $this->pagination->getPagesLinks();?></div>
					</td>
				<?php
				}
				?>
			</tr>
		</tfoot>
	<tbody>
	<?php
	for ($i = 0, $n = count($this->cancelled); $i < $n; $i++)
	{
		$row = $this->cancelled[$i];
		?>
		<tr>
            <?php
			if ($this->config->get('public_registrants_list_show_num', 1))
			{
			?>
                <td class="myhidden <?php echo $hiddenPhoneClass; ?>">
		            <?php echo $this->pagination->getRowOffset($i); ?>
                </td>
            <?php
			}
				if ($this->event_owner == 1)
                {?>
			<td>					
					<?php if ($row->user_id == 0 && $row->group_id == 0) {
					     if ($row->published >3) echo "Unapproved "; 
					     echo "Visitor";
					   }
					   else if ($row->group_id != 0 && $row->user_id==0) 
					     echo "Group Visitor"; 
					   else if ($row->group_id != 0 && $row->user_id!=0) echo "Group Member"; 
					   else echo "Member"; ?>					
			</td>			
			<?php
				}
			?>
			<td class="tdno<?php echo $i; ?>" data-content="<?php echo Text::_('EB_FIRST_NAME'); ?>">
					<?php echo $row->first_name.' '.$row->last_name ?>
			</td>
			<?php
				if ($showNumberRegistrants)
				{
				?>
					<td class="tdno<?php echo $i; ?>" data-content="<?php echo Text::_('EB_REGISTRANTS'); ?>">
						<?php echo $row->number_registrants ; ?>
					</td>
				<?php
				}

				if ($showTickets)
				{
					$ticketsOutput = [];

					if (!empty($this->tickets[$row->id]))
					{
						$tickets = $this->tickets[$row->id];

						foreach ($this->ticketTypes as $ticketType)
						{
							if (!empty($tickets[$ticketType->id]))
							{
								$ticketsOutput[] = Text::_($ticketType->title) . ': ' . $tickets[$ticketType->id];
							}
						}
					}

					$ticketsOutput = implode('<br />', $ticketsOutput);
				?>
					<td class="tdno<?php echo $i; ?>" data-content="<?php echo Text::_('EB_TICKETS'); ?>">
						<?php echo $ticketsOutput; ?>
					</td>
				<?php
				}

				if ($this->config->get('public_registrants_list_show_register_date', 1))
				{
				?>
					<td class="tdno<?php echo $i; ?> d-print-none <?php echo $hiddenPhoneClass; ?>" data-content="<?php echo Text::_('EB_REGISTRATION_DATE'); ?>">
						<?php echo HTMLHelper::_('date', $row->register_date, $this->config->date_format) ; ?>
					</td>
				<?php
				}
                ?>
                		<td class="tdno<?php echo $i; ?>" data-content="Cancelled Date">
						<?php echo HTMLHelper::_('date', $row->registration_cancel_date, $this->config->date_format) ; ?>
					</td>
                <?php
                $mobile="";
                $home="";
				if ($this->displayCustomField)
				{
 					foreach($this->fields as $fieldId)
					{
   					    if ($this->fieldTitles[$fieldId] === "Mobile Phone")
					    {
					        if (isset($this->fieldValues[$row->id][$fieldId]))
					        {
	                           $mobile=$this->fieldValues[$row->id][$fieldId];
					        }
	                    }
   					    if ($this->fieldTitles[$fieldId] === "Phone")
					    {
					        if (isset($this->fieldValues[$row->id][$fieldId]))
					        {
	                           $home=$this->fieldValues[$row->id][$fieldId];
					        }
	                    }
					}
					foreach($this->fields as $fieldId)
					{
   					    if ($this->fieldTitles[$fieldId] === "Phone")
					    {
	                        if (isset($mobile))
	                        {
					            $this->fieldValues[$row->id][$fieldId]=$mobile;
	                        }
					    }
					}
					foreach($this->fields as $fieldId)
					{
   					    if ($this->fieldTitles[$fieldId] === "Mobile Phone")
					    {
	                        if (!isset($this->fieldValues[$row->id][$fieldId]) && isset($home))
	                        {
	                            $this->fieldValues[$row->id][$fieldId]=$home;
	                        }
					    }
					}
 					foreach($this->fields as $fieldId)
					{
  					    if ($this->fieldTitles[$fieldId] !== "Mobile Phone" && 
   					        $this->fieldTitles[$fieldId] !== "First-aid Level" && 
   					        $this->fieldTitles[$fieldId] !== "First-aid" && 
					        $this->fieldTitles[$fieldId] !== "Emergency Contact or Next of Kin Mobile Phone Number" &&
					        $this->fieldTitles[$fieldId] !== "Emergency Contact or Next of Kin Name" &&
					        strpos($this->fieldTitles[$fieldId],"medical") === false &&
					        $this->fieldTitles[$fieldId] !== "Are you willing to drive?" &&
   					        $this->fieldTitles[$fieldId] !== "Emergency Contact or Next of Kin Home Phone Number" )
   					     {
       					    if (isset($this->fieldValues[$row->id][$fieldId]))
    						{
    							$fieldValue = $this->fieldValues[$row->id][$fieldId];
    						}
    						else
    						{
    							$fieldValue = '';
    						}


					?>
						<td class="tdno<?php echo $i; ?> <?php if ($this->fieldTitles[$fieldId] != 'Phone') echo $hiddenPhoneClass;?>" data-content="<?php echo $this->fieldTitles[$fieldId]; ?>">
							<?php 
							echo $fieldValue ; 
							?>
						</td>
					<?php	
					    }
					}
				}

				if ($this->config->get('public_registrants_list_show_registration_status', 0))
				{
				?>
					<td class="tdno<?php echo $i; ?>" data-content="<?php echo Text::_('EB_REGISTRATION_STATUS'); ?>">
						<?php
							switch ($row->published)
							{
								case 0 :
									echo Text::_('EB_PENDING');
									break ;
								case 1 :
									echo Text::_('EB_PAID');
									break ;
								case 2 :
									echo Text::_('EB_CANCELLED');
									break;
								case 4:
									echo Text::_('EB_WAITING_LIST_CANCELLED');
									break;
								case 3:
									echo Text::_('EB_WAITING_LIST');
									break;
							}
						?>
					</td>
				<?php
				}
				?>
             		<td class="tdno<?php echo $i; ?>" data-content="Actions">
   			        <a class="non-close-button btn btn-sm btn-outline-secondary" title="View Registrants walks" href="<?php echo JRoute::_('index.php?option=com_mbwc&view=history&tmpl=component&reg_id='.$row->id.'&tmpl=component&Itemid='.$this->Itemid);?>" ><i class="icon-eye-open"></i></a>                    
               <?php
				if (MBWCHelper::canUnCancelRegistration($row->id))
				{
			?>
                    <a class="btn btn-sm btn-outline-secondary non-close-button" onclick="return confirm('Are you sure you want to uncancel?\nNOTE: Mail is not sent for this operation.')" title="Un Cancel" href="<?php echo JRoute::_('index.php?option=com_mbwc&controller=registrant&task=uncancel_registrant&id='.$row->event_id.'&registrant_id='.$row->id.'&Itemid='.$this->Itemid);  ?>"><?php echo 'Un-Cancel' ; ?></a>
				<?php } ?>
					</td>
		</tr>
		<?php
	    }
	} ?>
	</tbody>
</table>
<?php
}
else
{
?>
	<div class="eb-message"><?php echo Text::_('EB_NO_REGISTRATION_RECORDS');?></div>
<?php
}
	if ($this->event_owner == 1 && $this->state->registrant_type != 3)
	{ 
	?>
	<p style="page-break-before: always">
<h2>Trip Emergency Contacts</h2>
  <b>Your first point of contact should you require "Emergency Assistance or Search" is to contact one of the Club's Trip Emergency Contacts.</b>
<ul>
    <?php
    for ($i=0;$i<count($this->club_contacts);$i++)
    {
      echo '<li style="line-height: 1em">'.$this->club_contacts[$i]->name.' '.$this->club_contacts[$i]->cb_mobphone.'</li>';
    }
  ?>
  </ul>
  <b>Other Contacts:</b>
  <ul>
  <li style="line-height: 1em">Emergency: 000</li>
<li style="line-height: 1em">President: <?php echo $this->president->name.' '.$this->president->cb_mobphone; ?></li>
<li style="line-height: 1em">Secretary: <?php echo $this->secretary->name.' '.$this->secretary->cb_mobphone; ?></li>
</ul>
<h2>Leader Checklist before the walk</h2>
<ul>
    <li style="line-height: 1em">Conduct a Risk Assessment: Is the weather ok? Should you shorten/modify/cancel the walk?</li>
    <li style="line-height: 1em">Have you called anyone you are not familiar with (including visitors) to confirm they are up to the walk (experience, medical conditions) and have the required equipment?</li>
    <li style="line-height: 1em">Transport arrangements, meeting places, organize car pooling and determine petrol cost</li>
    <li style="line-height: 1em">If risk involved, let the Trip Emergency Contacts know location of parked vehicles and number of participants</li>
</ul>

<h2>Leader Checklist on the day</h2>
<ul>
    <li style="line-height: 1em">Have temporary members completed the M3 Activity Participation Form - Temporary Member</li>
    <li style="line-height: 1em">Number and name off</li>
    <li style="line-height: 1em">Remind everyone of Standard Procedures - Stop at intersections, Leave pack on track if you need to go to loo</li>
    <li style="line-height: 1em">Appoint/Introduce Whip(s)</li>
    <li style="line-height: 1em">Petrol Costs (for car pooling) if required</li>
    <li style="line-height: 1em">Coffee afterwards?</li>
    <li style="line-height: 1em">Any Announcements?</li>
    <li style="line-height: 1em">After the walk, ensure all vehicles start, including your own, before everyone leaves</li>
</ul>
<h2>After walk</h2>
<ul>
    <li style="line-height: 1em">If the Trip Emergency Contact has been notified, let them know of your safe return</li>
    <li style="line-height: 1em">Complete Trip Report</li>
</ul>
</p>
<?php
	}

				if ($this->event_owner == 1)
				{ 
?>
<a class="btn btn-primary d-print-none non-close-button" href="#" onclick=" 
  jQuery('.myhidden').removeClass('d-none'); jQuery('#eb-registrants-list-table').removeClass('eb-responsive-table'); jQuery('#help').hide(); 
 jQuery('#mycancelled').hide(); jQuery('#cancelheading').hide(); window.print();  jQuery('.myhidden').addClass('d-none'); jQuery('#eb-registrants-list-table').addClass('eb-responsive-table'); jQuery('#help').show(); 
jQuery('#mycancelled').show(); jQuery('#cancelheading').show(); return false;">Print</a>

<a class="btn btn-primary d-print-none non-close-button" id="printwith" href="#" onclick="jQuery('.myhidden').removeClass('d-none');  jQuery('#help').hide();  
jQuery('#eb-registrants-list-table').removeClass('eb-responsive-table'); jQuery('#mycancelled').removeClass('eb-responsive-table'); window.print(); 
jQuery('.myhidden').addClass('d-none'); jQuery('#eb-registrants-list-table').addClass('eb-responsive-table'); jQuery('#myhidden').addClass('eb-responsive-table'); jQuery('#mail').show(); jQuery('#help').show(); 
 return false;">Print with Cancelled</a>
<?php
				}
				if ($this->event_owner == 1 && !$this->waitlist)
				{ 
?>
<a class="btn d-print-none non-close-button" id="mail" title="Mail Registrants" href="index.php?option=com_mbwc&view=mailregistrants&tmpl=component&from=registrants&waitlist=<?php echo $this->waitlist ?>&event_id=<?php echo $row->event_id ?>" >Mail Registrants</a>
<?php
				}

if (!$this->input->getInt('hmvc_call'))
{
?>
	</div>
<?php
} ?>

<script>
    function refresh() {
      window.parent.location.reload();
    }
    
    jQuery( document ).ready(function() {
        window.addEventListener("unload", refresh);
        let btns = document.getElementsByClassName('non-close-button');
        Array.prototype.forEach.call(btns, function(i) {
           i.addEventListener('click', function() {
            window.removeEventListener("unload", refresh);
          });
        });        
     });
</script>
<!--
<script language="JavaScript">
    jQuery(window).on("unload",function () {
    window.parent.location.reload();
    return true;
  });
</script> -->
<!-- <script language="JavaScript">
    jQuery( document ).ready(function() {
      jQuery('#tingle-modal-box').on("unload", function() {
          window.parent.location.reload();
        });       
  });    
</script>-->

